=== modified file 'Makefile'
--- Makefile	2018-07-17 18:06:19 +0000
+++ Makefile	2018-08-07 00:40:18 +0000
@@ -52,7 +52,7 @@
 	-$(RM) -f selftest.log
 	echo `date` ": selftest starts" 1>&2
 	set -o pipefail; BRZ_PLUGIN_PATH=$(BRZ_PLUGIN_PATH) $(PYTHON3) -Werror -Wignore::ImportWarning -Wignore::PendingDeprecationWarning -Wignore::DeprecationWarning -O \
-	  ./brz selftest -Oselftest.timeout=120 --load-list=python3.passing \
+	  ./brz selftest -Oselftest.timeout=120 --load-list=python3.passing --strict \
 	  --subunit2 $(tests) | tee selftest.log | subunit-2to1
 	echo `date` ": selftest ends" 1>&2
 	# An empty log file should catch errors in the $(PYTHON3)
@@ -66,7 +66,7 @@
 	# Generate a stream for PQM to watch.
 	-$(RM) -f selftest.log
 	-BRZ_PLUGIN_PATH=$(BRZ_PLUGIN_PATH) $(PYTHON3) -Werror -Wignore::ImportWarning -Wignore::DeprecationWarning -O \
-	  ./brz selftest -Oselftest.timeout=120 \
+	  ./brz selftest -Oselftest.timeout=120 --strict \
 	  --subunit2 $(tests) > selftest.log
 	grep -v "^#" python3.passing > python3.passing.new
 	cat selftest.log | \

=== modified file 'breezy/bzr/btree_index.py'
--- breezy/bzr/btree_index.py	2018-06-25 20:47:38 +0000
+++ breezy/bzr/btree_index.py	2018-08-02 01:10:26 +0000
@@ -708,8 +708,7 @@
 
     def __lt__(self, other):
         if isinstance(other, type(self)):
-            return ((self._transport, self._name, self._size) <
-                    (other._transport, other._name, other._size))
+            return ((self._name, self._size) < (other._name, other._size))
         # Always sort existing indexes before ones that are still being built.
         if isinstance(other, BTreeBuilder):
             return True

=== modified file 'breezy/bzr/bzrdir.py'
--- breezy/bzr/bzrdir.py	2018-06-30 14:54:27 +0000
+++ breezy/bzr/bzrdir.py	2018-08-07 20:43:32 +0000
@@ -64,6 +64,7 @@
 from breezy.i18n import gettext
 """)
 
+from ..sixish import viewitems
 from ..trace import (
     mutter,
     note,
@@ -1157,7 +1158,7 @@
 
     def check_support_status(self, allow_unsupported, recommend_upgrade=True,
             basedir=None):
-        for name, necessity in self.features.items():
+        for name, necessity in viewitems(self.features):
             if name in self._present_features:
                 continue
             if necessity == b"optional":
@@ -1196,7 +1197,7 @@
         """
         lines = [self.get_format_string()]
         lines.extend([(item[1] + b" " + item[0] + b"\n")
-                      for item in self.features.items()])
+                      for item in sorted(viewitems(self.features))])
         return b"".join(lines)
 
     @classmethod

=== modified file 'breezy/bzr/inventory.py'
--- breezy/bzr/inventory.py	2018-08-01 19:37:37 +0000
+++ breezy/bzr/inventory.py	2018-08-07 19:00:14 +0000
@@ -32,12 +32,8 @@
 from ..lazy_import import lazy_import
 lazy_import(globals(), """
 import collections
-import copy
-import re
-import tarfile
 
 from breezy import (
-    errors,
     generate_ids,
     osutils,
     )
@@ -47,6 +43,7 @@
 """)
 
 from .. import (
+    errors,
     lazy_regex,
     trace,
     )

=== modified file 'breezy/bzr/remote.py'
--- breezy/bzr/remote.py	2018-07-24 19:02:16 +0000
+++ breezy/bzr/remote.py	2018-08-02 01:10:26 +0000
@@ -2767,7 +2767,7 @@
         self.refresh_data()
         if response[0] != b'ok':
             raise errors.UnexpectedSmartServerResponse(response)
-        self._write_group_tokens = response[1:]
+        self._write_group_tokens = [token.decode('utf-8') for token in response[1:]]
 
     def has_signature_for_revision_id(self, revision_id):
         path = self.controldir._path_for_remote_call(self._client)

=== modified file 'breezy/bzr/workingtree_4.py'
--- breezy/bzr/workingtree_4.py	2018-07-26 22:37:49 +0000
+++ breezy/bzr/workingtree_4.py	2018-08-05 21:31:40 +0000
@@ -2088,7 +2088,7 @@
             # push the user specified dirs from dirblock
             for dir in reversed(dirblock):
                 if dir[2] == _directory:
-                    pending.append((dir[0].decode('utf-8'), dir[4]))
+                    pending.append((dir[0], dir[4]))
 
 
 class InterDirStateTree(InterTree):

=== modified file 'breezy/bzr/xml_serializer.py'
--- breezy/bzr/xml_serializer.py	2018-06-17 20:17:39 +0000
+++ breezy/bzr/xml_serializer.py	2018-08-05 02:42:06 +0000
@@ -129,7 +129,7 @@
     # aren't listed in the XML specification
     # (http://www.w3.org/TR/REC-xml/#NT-Char).
     return re.subn(u'[^\x09\x0A\x0D\u0020-\uD7FF\uE000-\uFFFD]+',
-            lambda match: match.group(0).encode('unicode_escape'),
+            lambda match: match.group(0).encode('unicode_escape').decode('ascii'),
             message)
 
 

=== modified file 'breezy/delta.py'
--- breezy/delta.py	2017-11-12 13:53:51 +0000
+++ breezy/delta.py	2018-08-03 02:26:35 +0000
@@ -170,6 +170,7 @@
     #       since we added them in alphabetical order.
     delta.modified.sort()
     delta.unchanged.sort()
+    delta.unversioned.sort()
 
     return delta
 
@@ -303,6 +304,7 @@
         self.output("%s%s%s %s%s", rename, self.modified_map[modified], exe,
                     old_path, path)
 
+
 def report_changes(change_iterator, reporter):
     """Report the changes from a change iterator.
 
@@ -319,8 +321,14 @@
         (False, True): 'added',
         (False, False): 'unversioned',
         }
+    def path_key(change):
+        if change[1][0] is not None:
+            path = change[1][0]
+        else:
+            path = change[1][1]
+        return osutils.splitpath(path)
     for (file_id, path, content_change, versioned, parent_id, name, kind,
-         executable) in change_iterator:
+         executable) in sorted(change_iterator, key=path_key):
         exe_change = False
         # files are "renamed" if they are moved or if name changes, as long
         # as it had a value

=== modified file 'breezy/generate_ids.py'
--- breezy/generate_ids.py	2018-06-22 02:22:23 +0000
+++ breezy/generate_ids.py	2018-08-06 02:31:37 +0000
@@ -32,11 +32,12 @@
     errors,
     lazy_regex,
     )
+from .sixish import text_type
 
 # the regex removes any weird characters; we don't escape them
 # but rather just pull them out
-_file_id_chars_re = lazy_regex.lazy_compile('[^\\w.]')
-_rev_id_chars_re = lazy_regex.lazy_compile('[^-\\w.+@]')
+_file_id_chars_re = lazy_regex.lazy_compile(b'[^\\w.]')
+_rev_id_chars_re = lazy_regex.lazy_compile(b'[^-\\w.+@]')
 _gen_file_id_suffix = None
 _gen_file_id_serial = 0
 
@@ -71,6 +72,8 @@
 
     The uniqueness is supplied from _next_id_suffix.
     """
+    if isinstance(name, text_type):
+        name = name.encode('ascii', 'replace')
     # The real randomness is in the _next_id_suffix, the
     # rest of the identifier is just to be nice.
     # So we:
@@ -82,7 +85,7 @@
     #    filesystems
     # 4) Removing starting '.' characters to prevent the file ids from
     #    being considered hidden.
-    ascii_word_only = _file_id_chars_re.sub('', name.lower()).encode('ascii', 'replace')
+    ascii_word_only = _file_id_chars_re.sub(b'', name.lower())
     short_no_dots = ascii_word_only.lstrip(b'.')[:20]
     return short_no_dots + _next_id_suffix()
 
@@ -108,15 +111,15 @@
 
     user_or_email = user_or_email.lower()
     user_or_email = user_or_email.replace(' ', '_')
-    user_or_email = _rev_id_chars_re.sub('', user_or_email)
+    user_or_email = _rev_id_chars_re.sub(b'', user_or_email.encode('utf-8'))
 
     # This gives 36^16 ~= 2^82.7 ~= 83 bits of entropy
-    unique_chunk = osutils.rand_chars(16)
+    unique_chunk = osutils.rand_chars(16).encode('utf-8')
 
     if timestamp is None:
         timestamp = time.time()
 
-    rev_id = u'-'.join((user_or_email,
-                        osutils.compact_date(timestamp),
+    rev_id = b'-'.join((user_or_email,
+                        osutils.compact_date(timestamp).encode('utf-8'),
                         unique_chunk))
-    return rev_id.encode('utf8')
+    return rev_id

=== modified file 'breezy/i18n.py'
--- breezy/i18n.py	2017-11-12 13:53:51 +0000
+++ breezy/i18n.py	2018-08-05 20:05:45 +0000
@@ -28,6 +28,8 @@
 import os
 import sys
 
+from .sixish import text_type
+
 
 _translations = None
 
@@ -208,8 +210,7 @@
 
     :param domain: Gettext domain name (usually 'brz-PLUGINNAME')
     """
-    locale_base = os.path.dirname(
-        unicode(__file__, sys.getfilesystemencoding()))
+    locale_base = os.path.dirname(__file__)
     translation = install_translations(domain=domain,
         locale_base=locale_base)
     add_fallback(translation)

=== modified file 'breezy/log.py'
--- breezy/log.py	2018-07-25 21:22:37 +0000
+++ breezy/log.py	2018-08-06 01:37:23 +0000
@@ -464,7 +464,7 @@
         for revs in revision_iterator:
             for (rev_id, revno, merge_depth), rev, delta in revs:
                 # 0 levels means show everything; merge_depth counts from 0
-                if levels != 0 and merge_depth >= levels:
+                if levels != 0 and merge_depth is not None and merge_depth >= levels:
                     continue
                 if omit_merges and len(rev.parent_ids) > 1:
                     continue

=== modified file 'breezy/merge.py'
--- breezy/merge.py	2018-07-15 18:45:17 +0000
+++ breezy/merge.py	2018-08-06 02:19:03 +0000
@@ -58,12 +58,10 @@
 
 
 def transform_tree(from_tree, to_tree, interesting_files=None):
-    from_tree.lock_tree_write()
-    operation = cleanup.OperationWithCleanups(merge_inner)
-    operation.add_cleanup(from_tree.unlock)
-    operation.run_simple(from_tree.branch, to_tree, from_tree,
-        ignore_zero=True, this_tree=from_tree,
-        interesting_files=interesting_files)
+    with from_tree.lock_tree_write():
+        merge_inner(from_tree.branch, to_tree, from_tree,
+            ignore_zero=True, this_tree=from_tree,
+            interesting_files=interesting_files)
 
 
 class MergeHooks(hooks.Hooks):
@@ -788,17 +786,10 @@
             pass
 
     def make_preview_transform(self):
-        operation = cleanup.OperationWithCleanups(self._make_preview_transform)
-        self.base_tree.lock_read()
-        operation.add_cleanup(self.base_tree.unlock)
-        self.other_tree.lock_read()
-        operation.add_cleanup(self.other_tree.unlock)
-        return operation.run_simple()
-
-    def _make_preview_transform(self):
-        self.tt = transform.TransformPreview(self.working_tree)
-        self._compute_transform()
-        return self.tt
+        with self.base_tree.lock_read(), self.other_tree.lock_read():
+            self.tt = transform.TransformPreview(self.working_tree)
+            self._compute_transform()
+            return self.tt
 
     def _compute_transform(self):
         if self._lca_trees is None:

=== modified file 'breezy/plugins/upload/README'
--- breezy/plugins/upload/README	2017-06-02 00:04:01 +0000
+++ breezy/plugins/upload/README	2018-08-04 17:36:12 +0000
@@ -1,21 +1,18 @@
-Bazaar Upload
+Breezy Upload
 =============
 
 Overview
 --------
 
-bzr-upload is a plugin for Bazaar which lets you upload your working tree to
+upload is a plugin for Breezy which lets you upload your working tree to
 a remote location using ftp/sftp.
 
 The main target audience is web developers who keep their web pages version
-controlled with bzr.
-
-Please report any bugs to: http://bugs.launchpad.net/bzr-upload/
-
-Our home page is located at: https://launchpad.net/bzr-upload/
+controlled with breezy.
+
 The original authors are:
 
 Vincent Ladeuil <v.ladeuil+lp@free.fr>
 Martin Albisetti <argentina@gmail.com>
 
-Use bzr help plugins/upload to get more info.
+Use brz help plugins/upload to get more info.

=== modified file 'breezy/plugins/upload/__init__.py'
--- breezy/plugins/upload/__init__.py	2018-04-02 22:07:12 +0000
+++ breezy/plugins/upload/__init__.py	2018-08-04 17:36:12 +0000
@@ -123,16 +123,6 @@
 but only applies to bzr-upload.
 
 
-Collaborating
--------------
-
-While we don't have any platform setup, you can branch from trunk:
-
-    brz branch lp:bzr-upload
-
-And change anything you'd like, and file a merge proposal on Launchpad.
-
-
 Known Issues
 ------------
 

=== modified file 'breezy/plugins/weave_fmt/test_bzrdir.py'
--- breezy/plugins/weave_fmt/test_bzrdir.py	2018-07-24 21:21:21 +0000
+++ breezy/plugins/weave_fmt/test_bzrdir.py	2018-08-05 00:34:23 +0000
@@ -402,7 +402,7 @@
         self.addCleanup(repo.unlock)
         text_keys = repo.texts.keys()
         dir_keys = [key for key in text_keys if key[0] ==
-                'dir-20051005095101-da1441ea3fa6917a']
+                b'dir-20051005095101-da1441ea3fa6917a']
         self.assertNotEqual([], dir_keys)
 
     def test_upgrade_to_meta_sets_workingtree_last_revision(self):

=== modified file 'breezy/status.py'
--- breezy/status.py	2018-07-22 17:06:14 +0000
+++ breezy/status.py	2018-08-02 01:10:26 +0000
@@ -316,7 +316,7 @@
         for num, sub_merge, depth, eom in rev_id_iterator:
             rev = revisions[sub_merge]
             if rev is None:
-                to_file.write(sub_prefix + '(ghost) ' + sub_merge + '\n')
+                to_file.write(sub_prefix + '(ghost) ' + sub_merge.decode('utf-8') + '\n')
                 continue
             show_log_message(revisions[sub_merge], sub_prefix)
 

=== modified file 'breezy/tests/__init__.py'
--- breezy/tests/__init__.py	2018-08-04 17:32:58 +0000
+++ breezy/tests/__init__.py	2018-08-08 02:14:32 +0000
@@ -3286,7 +3286,7 @@
                 stream.write("%s\n" % (t.id()))
         return True
     result = runner.run(suite)
-    if strict:
+    if strict and getattr(result, 'wasStrictlySuccessful', False):
         return result.wasStrictlySuccessful()
     else:
         return result.wasSuccessful()

=== modified file 'breezy/tests/blackbox/test_filtered_view_ops.py'
--- breezy/tests/blackbox/test_filtered_view_ops.py	2018-07-17 00:56:50 +0000
+++ breezy/tests/blackbox/test_filtered_view_ops.py	2018-08-04 22:42:09 +0000
@@ -86,8 +86,9 @@
         err_lines = err.splitlines()
         self.assertEqual('Ignoring files outside view. View is a, b', err_lines[0])
         self.assertStartsWith(err_lines[1], 'Committing to:')
-        self.assertEqual('added a', err_lines[2])
-        self.assertEqual('added b', err_lines[3])
+        # TODO(jelmer): Should 'added ' output for commit be sorted?
+        self.assertIn('added a', [err_lines[2], err_lines[3]])
+        self.assertIn('added b', [err_lines[2], err_lines[3]])
         self.assertEqual('Committed revision 1.', err_lines[4])
         self.assertEqual('', out)
 

=== modified file 'breezy/tests/blackbox/test_status.py'
--- breezy/tests/blackbox/test_status.py	2018-07-27 01:17:23 +0000
+++ breezy/tests/blackbox/test_status.py	2018-08-03 02:26:35 +0000
@@ -236,8 +236,8 @@
         self.assertStatus([
                 '?   bye.c\n',
                 '?   dir2/\n',
+                '?   directory/hello.c\n',
                 '+!  missing.c\n',
-                '?   directory/hello.c\n'
                 ],
                 wt, short=True)
 
@@ -401,9 +401,9 @@
                               r'.*ERROR: Path\(s\) do not exist: '
                               'NONEXISTENT.*')
         expected = [
+          ' M  FILE_B\n',
+          ' M  FILE_C\n',
           ' D  FILE_E\n',
-          ' M  FILE_C\n',
-          ' M  FILE_B\n',
           'X   NONEXISTENT\n',
           ]
         out, err = self.run_bzr('status --short NONEXISTENT '
@@ -435,9 +435,9 @@
                               r'.*ERROR: Path\(s\) do not exist: '
                               'ANOTHER_NONEXISTENT NONEXISTENT.*')
         expected = [
+          ' M  FILE_B\n',
+          ' M  FILE_C\n',
           ' D  FILE_E\n',
-          ' M  FILE_C\n',
-          ' M  FILE_B\n',
           'X   ANOTHER_NONEXISTENT\n',
           'X   NONEXISTENT\n',
           ]

=== modified file 'breezy/tests/per_intertree/test_compare.py'
--- breezy/tests/per_intertree/test_compare.py	2018-07-19 22:55:15 +0000
+++ breezy/tests/per_intertree/test_compare.py	2018-08-02 01:10:26 +0000
@@ -1427,7 +1427,7 @@
         expected = [
             self.unchanged(tree1, tree1.path2id('')),
             self.added(tree2, b'added'),
-            self.content_changed(tree2, 'changed'),
+            self.content_changed(tree2, b'changed'),
             self.kind_changed(tree1, tree2, b'fromdir'),
             self.kind_changed(tree1, tree2, b'fromfile'),
             self.deleted(tree1, b'removed'),
@@ -1448,7 +1448,7 @@
         root_id = tree1.path2id('')
         expected = [
             self.added(tree2, b'added'),
-            self.content_changed(tree2, 'changed'),
+            self.content_changed(tree2, b'changed'),
             self.kind_changed(tree1, tree2, b'fromdir'),
             self.kind_changed(tree1, tree2, b'fromfile'),
             self.deleted(tree1, b'removed'),

=== modified file 'breezy/tests/per_repository/test_repository.py'
--- breezy/tests/per_repository/test_repository.py	2018-07-27 18:57:21 +0000
+++ breezy/tests/per_repository/test_repository.py	2018-08-05 02:42:06 +0000
@@ -411,7 +411,7 @@
             # roundtrip xml invalid characters in the xml-based serializers.
             escaped_message, escape_count = re.subn(
                 u'[^\x09\x0A\x0D\u0020-\uD7FF\uE000-\uFFFD]+',
-                lambda match: match.group(0).encode('unicode_escape'),
+                lambda match: match.group(0).encode('unicode_escape').decode('ascii'),
                 message)
             self.assertEqual(rev.message, escaped_message)
         else:

=== modified file 'breezy/tests/per_repository_reference/test_get_record_stream.py'
--- breezy/tests/per_repository_reference/test_get_record_stream.py	2018-07-07 19:27:38 +0000
+++ breezy/tests/per_repository_reference/test_get_record_stream.py	2018-08-05 16:06:20 +0000
@@ -140,10 +140,15 @@
         # Topological ordering allows B & C and D & E to be returned with
         # either one first, so the required ordering is:
         # [A (B C) (D E) G]
+        #
+        # or, because E can be returned before B:
+        #
+        # A C E B D G
         keys = [(b'f-id', int2byte(r)) for r in bytearray(b'ABCDEG')]
         alt_1 = [(b'f-id', int2byte(r)) for r in bytearray(b'ACBDEG')]
         alt_2 = [(b'f-id', int2byte(r)) for r in bytearray(b'ABCEDG')]
         alt_3 = [(b'f-id', int2byte(r)) for r in bytearray(b'ACBEDG')]
+        alt_4 = [(b'f-id', int2byte(r)) for r in bytearray(b'ACEBDG')]
         self.stacked_repo.lock_read()
         self.addCleanup(self.stacked_repo.unlock)
         stream = self.stacked_repo.texts.get_record_stream(
@@ -153,7 +158,7 @@
             if record.storage_kind == 'absent':
                 raise ValueError('absent record: %s' % (record.key,))
             record_keys.append(record.key)
-        self.assertTrue(record_keys in (keys, alt_1, alt_2, alt_3))
+        self.assertIn(record_keys, (keys, alt_1, alt_2, alt_3, alt_4))
 
     def test_ordered_fulltext_simple(self):
         self.make_simple_split()
@@ -174,17 +179,22 @@
             if record.storage_kind == 'absent':
                 raise ValueError('absent record: %s' % (record.key,))
             record_keys.append(record.key)
-        self.assertTrue(record_keys in (keys, alt_1))
+        self.assertIn(record_keys, (keys, alt_1))
 
     def test_ordered_fulltext_complex(self):
         self.make_complex_split()
         # Topological ordering allows B & C and D & E to be returned with
         # either one first, so the required ordering is:
         # [A (B C) (D E) G]
+        #
+        # or, because E can be returned before B:
+        #
+        # A C E B D G
         keys = [(b'f-id', int2byte(r)) for r in bytearray(b'ABCDEG')]
         alt_1 = [(b'f-id', int2byte(r)) for r in bytearray(b'ACBDEG')]
         alt_2 = [(b'f-id', int2byte(r)) for r in bytearray(b'ABCEDG')]
         alt_3 = [(b'f-id', int2byte(r)) for r in bytearray(b'ACBEDG')]
+        alt_4 = [(b'f-id', int2byte(r)) for r in bytearray(b'ACEBDG')]
         self.stacked_repo.lock_read()
         self.addCleanup(self.stacked_repo.unlock)
         stream = self.stacked_repo.texts.get_record_stream(
@@ -200,5 +210,5 @@
             # See https://bugs.launchpad.net/bzr/+bug/399884
             self.expectFailure('KVF does not weave fulltexts from fallback'
                 ' repositories to preserve perfect order',
-                self.assertTrue, record_keys in (keys, alt_1, alt_2, alt_3))
-        self.assertTrue(record_keys in (keys, alt_1, alt_2, alt_3))
+                self.assertTrue, record_keys in (keys, alt_1, alt_2, alt_3, alt_4))
+        self.assertIn(record_keys, (keys, alt_1, alt_2, alt_3, alt_4))

=== modified file 'breezy/tests/per_transport.py'
--- breezy/tests/per_transport.py	2018-07-24 21:21:21 +0000
+++ breezy/tests/per_transport.py	2018-08-04 18:44:34 +0000
@@ -1020,8 +1020,6 @@
         except TransportNotPossible:
             raise TestSkipped("Transport %s does not support symlinks." %
                               self._server.__class__)
-        except IOError:
-            self.knownFailure("Paramiko fails to create symlinks during tests")
 
     def test_list_dir(self):
         # TODO: Test list_dir, just try once, and if it throws, stop testing

=== modified file 'breezy/tests/per_workingtree/test_paths2ids.py'
--- breezy/tests/per_workingtree/test_paths2ids.py	2018-07-02 23:41:13 +0000
+++ breezy/tests/per_workingtree/test_paths2ids.py	2018-08-02 01:10:26 +0000
@@ -166,12 +166,12 @@
         tree.unversion(['dir/child-goes'])
         tree.rename_one('dir/child-moves', 'child-moves')
         self.build_tree(['tree/newdir/'])
-        tree.add(['newdir'], ['newdir'])
+        tree.add(['newdir'], [b'newdir'])
         tree.rename_one('dir/child-stays', 'child-stays')
         tree.rename_one('dir', 'newdir/dir')
         tree.rename_one('child-stays', 'newdir/dir/child-stays')
         self.build_tree(['tree/newdir/dir/new-child'])
-        tree.add(['newdir/dir/new-child'], ['new-child'])
+        tree.add(['newdir/dir/new-child'], [b'new-child'])
         self.assertExpectedIds(
             [b'newdir', b'dir', b'child-moves', b'child-stays', b'child-goes',
              b'new-child'], tree, ['newdir'], [basis])

=== modified file 'breezy/tests/per_workingtree/test_workingtree.py'
--- breezy/tests/per_workingtree/test_workingtree.py	2018-07-24 21:44:05 +0000
+++ breezy/tests/per_workingtree/test_workingtree.py	2018-08-05 01:44:58 +0000
@@ -1207,7 +1207,7 @@
         self.build_tree(['tree/subdir/', 'tree/subdir/somefile'])
         tree.add(['subdir', 'subdir/somefile'])
 
-        with open('tree/subdir/m\xb5', 'wb') as f:
+        with open(b'tree/subdir/m\xb5', 'wb') as f:
             f.write(b'trivial\n')
 
         tree.lock_read()
@@ -1220,7 +1220,7 @@
                                   tree.iter_changes, tree.basis_tree(),
                                   want_unversioned=True)
         # We should display the relative path
-        self.assertEqual('subdir/m\xb5', e.filename)
+        self.assertEqual(b'subdir/m\xb5', e.filename)
         self.assertEqual(osutils._fs_enc, e.fs_encoding)
 
 

=== modified file 'breezy/tests/stub_sftp.py'
--- breezy/tests/stub_sftp.py	2018-03-24 17:54:01 +0000
+++ breezy/tests/stub_sftp.py	2018-08-04 18:44:34 +0000
@@ -216,6 +216,14 @@
             return paramiko.SFTPServer.convert_errno(e.errno)
         return paramiko.SFTP_OK
 
+    def symlink(self, target_path, path):
+        path = self._realpath(path)
+        try:
+            os.symlink(target_path, path)
+        except OSError as e:
+            return paramiko.SFTPServer.convert_errno(e.errno)
+        return paramiko.SFTP_OK
+
     def mkdir(self, path, attr):
         path = self._realpath(path)
         try:

=== modified file 'breezy/tests/test_bundle.py'
--- breezy/tests/test_bundle.py	2018-07-19 23:46:16 +0000
+++ breezy/tests/test_bundle.py	2018-08-04 17:17:45 +0000
@@ -1173,7 +1173,7 @@
         # rev2 is present in bundle, and done by fetch
         # having file1 in the bunle causes file1's versionedfile to be opened.
         self.tree1.add('file3', b'file3-id')
-        self.tree1.commit('rev2')
+        rev2 = self.tree1.commit('rev2')
         # Updating file2 should not cause an attempt to add to file1's vf
         target = self.tree1.controldir.sprout('target').open_workingtree()
         self.build_tree_contents([('tree/file2', b'contents3')])
@@ -1181,11 +1181,10 @@
         bundle = self.get_valid_bundle(b'reva', b'rev3')
         if getattr(bundle, 'get_bundle_reader', None) is None:
             raise tests.TestSkipped('Bundle format cannot provide reader')
-        # be sure that file1 comes before file2
-        for b, m, k, r, f in bundle.get_bundle_reader().iter_records():
-            if f == b'file3-id':
-                break
-            self.assertNotEqual(f, b'file2-id')
+        file_ids = set(
+            (f, r) for b, m, k, r, f in bundle.get_bundle_reader().iter_records()
+            if f is not None)
+        self.assertEqual({(b'file2-id', b'rev3'), (b'file3-id', rev2)}, file_ids)
         bundle.install_revisions(target.branch.repository)
 
 

=== modified file 'breezy/tests/test_bzrdir.py'
--- breezy/tests/test_bzrdir.py	2018-07-15 18:45:17 +0000
+++ breezy/tests/test_bzrdir.py	2018-08-07 20:43:32 +0000
@@ -1227,14 +1227,14 @@
             raise TestSkipped('unable to make file hidden without pywin32 library')
         b = bzrdir.BzrDir.create('.')
         self.build_tree(['a'])
-        self.assertEqual(['a'], self.get_ls())
+        self.assertEqual([b'a'], self.get_ls())
 
     def test_dot_bzr_hidden_with_url(self):
         if sys.platform == 'win32' and not win32utils.has_win32file:
             raise TestSkipped('unable to make file hidden without pywin32 library')
         b = bzrdir.BzrDir.create(urlutils.local_path_to_url('.'))
         self.build_tree(['a'])
-        self.assertEqual(['a'], self.get_ls())
+        self.assertEqual([b'a'], self.get_ls())
 
 
 class _TestBzrDirFormat(bzrdir.BzrDirMetaFormat1):
@@ -1404,7 +1404,7 @@
         self.assertEqual("a.~1~", self._bzrdir._available_backup_name("a"))
 
     def test_exiting(self):
-        self._transport.put_bytes("a.~1~", "some content")
+        self._transport.put_bytes("a.~1~", b"some content")
         self.assertEqual("a.~2~", self._bzrdir._available_backup_name("a"))
 
 
@@ -1474,11 +1474,11 @@
         self.assertEqual(format.as_string(),
             b"First line\n"
             b"required foo\n")
-        format.features["another"] = "optional"
+        format.features[b"another"] = b"optional"
         self.assertEqual(format.as_string(),
             b"First line\n"
-            b"required foo\n"
-            b"optional another\n")
+            b"optional another\n"
+            b"required foo\n")
 
     def test_network_name(self):
         # The network string should include the feature info

=== modified file 'breezy/tests/test_chk_map.py'
--- breezy/tests/test_chk_map.py	2018-07-12 00:59:12 +0000
+++ breezy/tests/test_chk_map.py	2018-08-06 01:42:32 +0000
@@ -407,20 +407,20 @@
         map_two = CHKMap(store, None)
         map_two._root_node.set_maximum_size(20)
         self.assertMapLayoutEqual(map_one, map_two)
-        map_one.map(b'aaa', b'value')
+        map_one.map((b'aaa', ), b'value')
         self.assertRaises(AssertionError,
             self.assertMapLayoutEqual, map_one, map_two)
-        map_two.map(b'aaa', b'value')
+        map_two.map((b'aaa', ), b'value')
         self.assertMapLayoutEqual(map_one, map_two)
         # Split the tree, so we ensure that internal nodes and leaf nodes are
         # properly checked
-        map_one.map(b'aab', b'value')
+        map_one.map((b'aab', ), b'value')
         self.assertIsInstance(map_one._root_node, InternalNode)
         self.assertRaises(AssertionError,
             self.assertMapLayoutEqual, map_one, map_two)
-        map_two.map(b'aab', b'value')
+        map_two.map((b'aab', ), b'value')
         self.assertMapLayoutEqual(map_one, map_two)
-        map_one.map(b'aac', b'value')
+        map_one.map((b'aac', ), b'value')
         self.assertRaises(AssertionError,
             self.assertMapLayoutEqual, map_one, map_two)
         self.assertCanonicalForm(map_one)
@@ -434,7 +434,7 @@
 
     def test_from_dict_ab(self):
         chk_bytes = self.get_chk_bytes()
-        root_key = CHKMap.from_dict(chk_bytes, {b"a": b"b"})
+        root_key = CHKMap.from_dict(chk_bytes, {(b"a", ): b"b"})
         # Check the data was saved and inserted correctly.
         expected_root_key = self.assertHasABMap(chk_bytes)
         self.assertEqual(expected_root_key, root_key)
@@ -445,7 +445,7 @@
         chk_bytes = self.get_chk_bytes()
         root_key = CHKMap.from_dict(chk_bytes, {})
         chkmap = CHKMap(chk_bytes, root_key)
-        new_root = chkmap.apply_delta([(None, b"a", b"b")])
+        new_root = chkmap.apply_delta([(None, (b"a", ), b"b")])
         # Check the data was saved and inserted correctly.
         expected_root_key = self.assertHasABMap(chk_bytes)
         self.assertEqual(expected_root_key, new_root)
@@ -1143,7 +1143,7 @@
     def test_iteritems_two_items(self):
         chk_bytes = self.get_chk_bytes()
         root_key = CHKMap.from_dict(chk_bytes,
-            {b"a": b"content here", b"b": b"more content"})
+            {(b"a", ): b"content here", (b"b", ): b"more content"})
         chkmap = CHKMap(chk_bytes, root_key)
         self.assertEqual([((b"a",), b"content here"), ((b"b",), b"more content")],
             sorted(list(chkmap.iteritems())))
@@ -1561,8 +1561,8 @@
         self.assertEqual(None, node.key())
 
     def test_key_after_map(self):
-        node = LeafNode.deserialise("chkleaf:\n10\n1\n0\n\n", ("sha1:1234",))
-        node.map(None, ("foo bar",), "baz quux")
+        node = LeafNode.deserialise(b"chkleaf:\n10\n1\n0\n\n", (b"sha1:1234",))
+        node.map(None, (b"foo bar",), b"baz quux")
         self.assertEqual(None, node.key())
 
     def test_key_after_unmap(self):

=== modified file 'breezy/tests/test_commit.py'
--- breezy/tests/test_commit.py	2018-08-01 19:37:07 +0000
+++ breezy/tests/test_commit.py	2018-08-02 01:10:26 +0000
@@ -117,7 +117,7 @@
         with open('hello', 'w') as f: f.write('hello world')
         wt.add('hello')
         revid = wt.commit(message='add hello', rev_id=b'revid', lossy=True)
-        self.assertEqual('revid', revid)
+        self.assertEqual(b'revid', revid)
 
     def test_commit_lossy_foreign(self):
         """Attempt a lossy commit to a foreign branch."""
@@ -129,7 +129,7 @@
         wt.add('hello')
         revid = wt.commit(message='add hello', lossy=True,
             timestamp=1302659388, timezone=0)
-        self.assertEqual(b'dummy-v1:1302659388.0-0-UNKNOWN', revid)
+        self.assertEqual(b'dummy-v1:1302659388-0-UNKNOWN', revid)
 
     def test_commit_bound_lossy_foreign(self):
         """Attempt a lossy commit to a bzr branch bound to a foreign branch."""
@@ -142,10 +142,10 @@
         wt.add('hello')
         revid = wt.commit(message='add hello', lossy=True,
             timestamp=1302659388, timezone=0)
-        self.assertEqual(b'dummy-v1:1302659388.0-0-0', revid)
-        self.assertEqual(b'dummy-v1:1302659388.0-0-0',
+        self.assertEqual(b'dummy-v1:1302659388-0-0', revid)
+        self.assertEqual(b'dummy-v1:1302659388-0-0',
             foreign_branch.last_revision())
-        self.assertEqual(b'dummy-v1:1302659388.0-0-0',
+        self.assertEqual(b'dummy-v1:1302659388-0-0',
             wt.branch.last_revision())
 
     def test_missing_commit(self):
@@ -357,7 +357,7 @@
             with open('hello', 'w') as f: f.write((str(i) * 4) + '\n')
             if i == 0:
                 wt.add(['hello'], [b'hello-id'])
-            rev_id = 'test@rev-%d' % (i+1)
+            rev_id = b'test@rev-%d' % (i+1)
             rev_ids.append(rev_id)
             wt.commit(message='rev %d' % (i+1),
                      rev_id=rev_id)
@@ -423,7 +423,7 @@
         wt = self.make_branch_and_tree('.')
         branch = wt.branch
         wt.commit("base", allow_pointless=True, rev_id=b'A')
-        self.assertFalse(branch.repository.has_signature_for_revision_id('A'))
+        self.assertFalse(branch.repository.has_signature_for_revision_id(b'A'))
         try:
             from ..testament import Testament
             # monkey patch gpg signing mechanism
@@ -438,8 +438,8 @@
                 return breezy.gpg.LoopbackGPGStrategy(None).sign(
                         text, breezy.gpg.MODE_CLEAR)
             self.assertEqual(sign(Testament.from_revision(branch.repository,
-                                                          'B').as_short_text()),
-                             branch.repository.get_signature_text('B'))
+                                                          b'B').as_short_text()),
+                             branch.repository.get_signature_text(b'B'))
         finally:
             breezy.gpg.GPGStrategy = oldstrategy
 

=== modified file 'breezy/tests/test_config.py'
--- breezy/tests/test_config.py	2018-06-22 01:50:22 +0000
+++ breezy/tests/test_config.py	2018-08-05 20:37:33 +0000
@@ -1495,9 +1495,9 @@
         self.assertEqual('/environ-bzr', my_config.get_bzr_remote_path())
 
 
-precedence_global = 'option = global'
-precedence_branch = 'option = branch'
-precedence_location = """
+precedence_global = b'option = global'
+precedence_branch = b'option = branch'
+precedence_location = b"""
 [http://]
 recurse = true
 option = recurse

=== modified file 'breezy/tests/test_conflicts.py'
--- breezy/tests/test_conflicts.py	2018-08-01 19:37:07 +0000
+++ breezy/tests/test_conflicts.py	2018-08-07 20:43:32 +0000
@@ -43,22 +43,22 @@
 # '\xc3\xae' == u'\xee' == i with hat
 # So these are u'path' and 'id' only with a circle and a hat. (shappo?)
 example_conflicts = conflicts.ConflictList(
-    [conflicts.MissingParent('Not deleting', u'p\xe5thg', '\xc3\xaedg'),
-     conflicts.ContentsConflict(u'p\xe5tha', None, '\xc3\xaeda'),
+    [conflicts.MissingParent('Not deleting', u'p\xe5thg', b'\xc3\xaedg'),
+     conflicts.ContentsConflict(u'p\xe5tha', None, b'\xc3\xaeda'),
      conflicts.TextConflict(u'p\xe5tha'),
-     conflicts.PathConflict(u'p\xe5thb', u'p\xe5thc', '\xc3\xaedb'),
+     conflicts.PathConflict(u'p\xe5thb', u'p\xe5thc', b'\xc3\xaedb'),
      conflicts.DuplicateID('Unversioned existing file',
                            u'p\xe5thc', u'p\xe5thc2',
-                           '\xc3\xaedc', '\xc3\xaedc'),
+                           b'\xc3\xaedc', b'\xc3\xaedc'),
     conflicts.DuplicateEntry('Moved existing file to',
                              u'p\xe5thdd.moved', u'p\xe5thd',
-                             '\xc3\xaedd', None),
+                             b'\xc3\xaedd', None),
     conflicts.ParentLoop('Cancelled move', u'p\xe5the', u'p\xe5th2e',
-                         None, '\xc3\xaed2e'),
+                         None, b'\xc3\xaed2e'),
     conflicts.UnversionedParent('Versioned directory',
-                                u'p\xe5thf', '\xc3\xaedf'),
+                                u'p\xe5thf', b'\xc3\xaedf'),
     conflicts.NonDirectoryParent('Created directory',
-                                 u'p\xe5thg', '\xc3\xaedg'),
+                                 u'p\xe5thg', b'\xc3\xaedg'),
 ])
 
 
@@ -933,18 +933,18 @@
             (dict(_base_actions='create_dir1_dir2'),
              ('dir1_into_dir2',
               dict(actions='move_dir1_into_dir2', check='dir1_moved',
-                   dir_id=b'dir1-id', target_id='dir2-id', xfail=False)),
+                   dir_id=b'dir1-id', target_id=b'dir2-id', xfail=False)),
              ('dir2_into_dir1',
               dict(actions='move_dir2_into_dir1', check='dir2_moved',
-                   dir_id=b'dir2-id', target_id='dir1-id', xfail=False))),
+                   dir_id=b'dir2-id', target_id=b'dir1-id', xfail=False))),
             # Subdirs moved into each other
             (dict(_base_actions='create_dir1_4'),
              ('dir1_into_dir4',
               dict(actions='move_dir1_into_dir4', check='dir1_2_moved',
-                   dir_id=b'dir1-id', target_id='dir4-id', xfail=True)),
+                   dir_id=b'dir1-id', target_id=b'dir4-id', xfail=True)),
              ('dir3_into_dir2',
               dict(actions='move_dir3_into_dir2', check='dir3_4_moved',
-                   dir_id=b'dir3-id', target_id='dir2-id', xfail=True))),
+                   dir_id=b'dir3-id', target_id=b'dir2-id', xfail=True))),
             ])
 
     def do_create_dir1_dir2(self):
@@ -1025,8 +1025,8 @@
 $ echo "Boo!" >foo
 $ brz commit -q -m 'foo is now a file'
 $ brz merge ../trunk
+2>RK  foo => foo.new/
 2>+N  foo.new/bar
-2>RK  foo => foo.new/
 # FIXME: The message is misleading, foo.new *is* a directory when the message
 # is displayed -- vila 090916
 2>Conflict: foo.new is not a directory, but has files in it.  Created directory.

=== modified file 'breezy/tests/test_email_message.py'
--- breezy/tests/test_email_message.py	2018-08-01 19:37:07 +0000
+++ breezy/tests/test_email_message.py	2018-08-07 02:10:52 +0000
@@ -23,6 +23,7 @@
 from .. import __version__ as _breezy_version
 from ..email_message import EmailMessage
 from ..errors import BzrBadParameterNotUnicode
+from ..sixish import text_type
 from ..smtp_connection import SMTPConnection
 from .. import tests
 
@@ -110,10 +111,10 @@
 
     def test_simple_message(self):
         pairs = {
-            'body': SIMPLE_MESSAGE_ASCII,
+            b'body': SIMPLE_MESSAGE_ASCII,
             u'b\xf3dy': SIMPLE_MESSAGE_UTF8,
-            'b\xc3\xb3dy': SIMPLE_MESSAGE_UTF8,
-            'b\xf4dy': SIMPLE_MESSAGE_8BIT,
+            b'b\xc3\xb3dy': SIMPLE_MESSAGE_UTF8,
+            b'b\xf4dy': SIMPLE_MESSAGE_8BIT,
         }
         for body, expected in pairs.items():
             msg = EmailMessage('from@from.com', 'to@to.com', 'subject', body)
@@ -205,10 +206,9 @@
     def test_string_with_encoding(self):
         pairs = {
                 u'Pepe':        (b'Pepe', 'ascii'),
-                u'P\xe9rez':    ('P\xc3\xa9rez', 'utf-8'),
-                'Perez':         ('Perez', 'ascii'), # u'Pepe' == 'Pepe'
-                'P\xc3\xa9rez': ('P\xc3\xa9rez', 'utf-8'),
-                'P\xe8rez':     ('P\xe8rez', '8-bit'),
+                u'P\xe9rez':    (b'P\xc3\xa9rez', 'utf-8'),
+                b'P\xc3\xa9rez': (b'P\xc3\xa9rez', 'utf-8'),
+                b'P\xe8rez':     (b'P\xe8rez', '8-bit'),
         }
         for string_, pair in pairs.items():
             self.assertEqual(pair, EmailMessage.string_with_encoding(string_))

=== modified file 'breezy/tests/test_foreign.py'
--- breezy/tests/test_foreign.py	2018-07-22 17:06:14 +0000
+++ breezy/tests/test_foreign.py	2018-08-02 01:10:26 +0000
@@ -129,7 +129,7 @@
         mapping = DummyForeignVcsMapping(DummyForeignVcs())
         if self._lossy:
             self._new_revision_id = mapping.revision_id_foreign_to_bzr(
-                (str(self._timestamp).encode('ascii'),
+                (b'%d' % self._timestamp,
                  str(self._timezone).encode('ascii'), b"UNKNOWN"))
             self.random_revid = False
         elif revid is not None:
@@ -198,7 +198,7 @@
                     return (tree.get_file(path, file_id), None)
                 tree.get_file_with_stat = get_file_with_stat
                 new_revid = self.target.mapping.revision_id_foreign_to_bzr(
-                    (str(rev.timestamp).encode('ascii'), str(rev.timezone).encode('ascii'),
+                    (b'%d' % rev.timestamp, str(rev.timezone).encode('ascii'),
                         str(self.target.revno()).encode('ascii')))
                 parent_revno, parent_revid= self.target.last_revision_info()
                 if parent_revid == revision.NULL_REVISION:

=== modified file 'breezy/tests/test_generate_ids.py'
--- breezy/tests/test_generate_ids.py	2018-08-01 19:37:07 +0000
+++ breezy/tests/test_generate_ids.py	2018-08-05 21:21:51 +0000
@@ -33,7 +33,7 @@
         file_id = generate_ids.gen_file_id(filename)
         self.assertContainsRe(file_id, b'^'+regex+b'$')
         # It should be a utf8 file_id, not a unicode one
-        self.assertIsInstance(file_id, str)
+        self.assertIsInstance(file_id, bytes)
         # gen_file_id should always return ascii file ids.
         file_id.decode('ascii')
 
@@ -41,14 +41,14 @@
         gen_file_id = generate_ids.gen_file_id
 
         # We try to use the filename if possible
-        self.assertStartsWith(gen_file_id(b'bar'), b'bar-')
+        self.assertStartsWith(gen_file_id('bar'), b'bar-')
 
         # but we squash capitalization, and remove non word characters
-        self.assertStartsWith(gen_file_id(b'Mwoo oof\t m'), b'mwoooofm-')
+        self.assertStartsWith(gen_file_id('Mwoo oof\t m'), b'mwoooofm-')
 
         # We also remove leading '.' characters to prevent hidden file-ids
-        self.assertStartsWith(gen_file_id(b'..gam.py'), b'gam.py-')
-        self.assertStartsWith(gen_file_id(b'..Mwoo oof\t m'), b'mwoooofm-')
+        self.assertStartsWith(gen_file_id('..gam.py'), b'gam.py-')
+        self.assertStartsWith(gen_file_id('..Mwoo oof\t m'), b'mwoooofm-')
 
         # we remove unicode characters, and still don't end up with a
         # hidden file id
@@ -61,18 +61,18 @@
 
         # Test both case squashing and length restriction
         fid = gen_file_id('A'*50 + '.txt')
-        self.assertStartsWith(fid, 'a'*20 + '-')
+        self.assertStartsWith(fid, b'a'*20 + b'-')
         self.assertTrue(len(fid) < 60)
 
         # restricting length happens after the other actions, so
         # we preserve as much as possible
         fid = gen_file_id('\xe5\xb5..aBcd\tefGhijKLMnop\tqrstuvwxyz')
-        self.assertStartsWith(fid, 'abcdefghijklmnopqrst-')
+        self.assertStartsWith(fid, b'abcdefghijklmnopqrst-')
         self.assertTrue(len(fid) < 60)
 
     def test_file_ids_are_ascii(self):
         tail = br'-\d{14}-[a-z0-9]{16}-\d+'
-        self.assertGenFileId(b'foo' + tail, b'foo')
+        self.assertGenFileId(b'foo' + tail, 'foo')
         self.assertGenFileId(b'foo' + tail, u'foo')
         self.assertGenFileId(b'bar' + tail, u'bar')
         self.assertGenFileId(b'br' + tail, u'b\xe5r')

=== modified file 'breezy/tests/test_http.py'
--- breezy/tests/test_http.py	2018-08-01 19:37:07 +0000
+++ breezy/tests/test_http.py	2018-08-02 01:57:42 +0000
@@ -2159,7 +2159,7 @@
 
     def setUp(self):
         super(TestNoReportActivity, self).setUp()
-        self._transport =HttpTransport
+        self._transport = HttpTransport
         TestActivityMixin.setUp(self)
 
     def assertActivitiesMatch(self):

=== modified file 'breezy/tests/test_i18n.py'
--- breezy/tests/test_i18n.py	2018-08-01 19:37:07 +0000
+++ breezy/tests/test_i18n.py	2018-08-05 20:05:45 +0000
@@ -24,6 +24,7 @@
     errors,
     workingtree,
     )
+from ..sixish import PY3
 
 
 class ZzzTranslations(object):
@@ -40,6 +41,9 @@
     def gettext(self, s):
         return self.zzz(self._null_translation.gettext(s))
 
+    def ngettext(self, s, p, n):
+        return self.zzz(self._null_translation.ngettext(s, p, n))
+
     def ugettext(self, s):
         return self.zzz(self._null_translation.ugettext(s))
 
@@ -59,16 +63,28 @@
         t = trans.zzz('msg')
         self._check_exact(u'zz\xe5{{msg}}', t)
 
-        t = trans.ugettext('msg')
-        self._check_exact(u'zz\xe5{{msg}}', t)
-
-        t = trans.ungettext('msg1', 'msg2', 0)
-        self._check_exact(u'zz\xe5{{msg2}}', t)
-        t = trans.ungettext('msg1', 'msg2', 2)
-        self._check_exact(u'zz\xe5{{msg2}}', t)
-
-        t = trans.ungettext('msg1', 'msg2', 1)
-        self._check_exact(u'zz\xe5{{msg1}}', t)
+        if PY3:
+            t = trans.gettext('msg')
+            self._check_exact(u'zz\xe5{{msg}}', t)
+
+            t = trans.ngettext('msg1', 'msg2', 0)
+            self._check_exact(u'zz\xe5{{msg2}}', t)
+            t = trans.ngettext('msg1', 'msg2', 2)
+            self._check_exact(u'zz\xe5{{msg2}}', t)
+
+            t = trans.ngettext('msg1', 'msg2', 1)
+            self._check_exact(u'zz\xe5{{msg1}}', t)
+        else:
+            t = trans.ugettext('msg')
+            self._check_exact(u'zz\xe5{{msg}}', t)
+
+            t = trans.ungettext('msg1', 'msg2', 0)
+            self._check_exact(u'zz\xe5{{msg2}}', t)
+            t = trans.ungettext('msg1', 'msg2', 2)
+            self._check_exact(u'zz\xe5{{msg2}}', t)
+
+            t = trans.ungettext('msg1', 'msg2', 1)
+            self._check_exact(u'zz\xe5{{msg1}}', t)
 
 
 class TestGetText(tests.TestCase):
@@ -148,8 +164,11 @@
             workingtree.WorkingTree.open('./foo')
         except errors.NotBranchError as e:
             err = str(e)
-        self.assertContainsRe(err, 
-                              u"zz\xe5{{Not a branch: .*}}".encode("utf-8"))
+        if PY3:
+            self.assertContainsRe(err, u"zz\xe5{{Not a branch: .*}}")
+        else:
+            self.assertContainsRe(
+                    err, u"zz\xe5{{Not a branch: .*}}".encode('utf-8'))
 
     def test_topic_help_translation(self):
         """does topic help get translated?"""

=== modified file 'breezy/tests/test_import_tariff.py'
--- breezy/tests/test_import_tariff.py	2017-06-11 20:15:04 +0000
+++ breezy/tests/test_import_tariff.py	2018-08-07 20:43:32 +0000
@@ -27,6 +27,7 @@
     )
 from ..controldir import ControlDir
 from ..bzr.smart import medium
+from ..sixish import PY3
 from ..transport import remote
 
 from . import (
@@ -97,14 +98,18 @@
         :param err: Standard error
         :param forbidden_imports: List of forbidden modules
         """
+        err = err.decode('utf-8')
         self.addDetail('subprocess_stderr',
-            content.Content(content.ContentType("text", "plain"),
-                lambda:[err]))
+            content.text_content(err))
 
         bad_modules = []
         for module_name in forbidden_imports:
-            if err.find("\nimport %s " % module_name) != -1:
-                bad_modules.append(module_name)
+            if PY3:
+                if err.find("\nimport '%s' " % module_name) != -1:
+                    bad_modules.append(module_name)
+            else:
+                if err.find("\nimport %s " % module_name) != -1:
+                    bad_modules.append(module_name)
 
         if bad_modules:
             self.fail("command loaded forbidden modules %r"
@@ -185,6 +190,7 @@
             'breezy.bzr.xml8',
             'getpass',
             'kerberos',
+            'shutil',
             'ssl',
             'socket',
             'smtplib',
@@ -192,7 +198,6 @@
             'tempfile',
             'termios',
             'tty',
-            'urllib',
             ] + old_format_modules)
         # TODO: similar test for repository-only operations, checking we avoid
         # loading wt-specific stuff
@@ -225,7 +230,7 @@
         (out, err) = self.finish_bzr_subprocess(process,
             universal_newlines=False)
         stderr_file.close()
-        with open('bzr-serve.stderr', 'r') as stderr_file:
+        with open('bzr-serve.stderr', 'rb') as stderr_file:
             err = stderr_file.read()
         self.check_forbidden_modules(err,
             ['breezy.annotate',

=== modified file 'breezy/tests/test_index.py'
--- breezy/tests/test_index.py	2018-07-22 17:06:14 +0000
+++ breezy/tests/test_index.py	2018-08-04 13:00:08 +0000
@@ -1336,8 +1336,8 @@
         index, reload_counter = self.make_combined_index_with_missing()
         result = list(index.iter_entries([(b'1',), (b'2',), (b'3',)]))
         index3 = index._indices[0]
-        self.assertEqual([(index3, (b'1',), b''), (index3, (b'2',), b'')],
-                         result)
+        self.assertEqual({(index3, (b'1',), b''), (index3, (b'2',), b'')},
+                         set(result))
         self.assertEqual([1, 1, 0], reload_counter)
 
     def test_iter_entries_reloads_midway(self):
@@ -1369,8 +1369,8 @@
         index, reload_counter = self.make_combined_index_with_missing()
         result = list(index.iter_all_entries())
         index3 = index._indices[0]
-        self.assertEqual([(index3, (b'1',), b''), (index3, (b'2',), b'')],
-                         result)
+        self.assertEqual({(index3, (b'1',), b''), (index3, (b'2',), b'')},
+                         set(result))
         self.assertEqual([1, 1, 0], reload_counter)
 
     def test_iter_all_entries_reloads_midway(self):

=== modified file 'breezy/tests/test_merge.py'
--- breezy/tests/test_merge.py	2018-07-15 18:45:17 +0000
+++ breezy/tests/test_merge.py	2018-08-02 01:10:26 +0000
@@ -3080,7 +3080,7 @@
         builder = self.make_builder()
         builder.add_file(b'bar-id', builder.tree_root, 'bar', b'text1', True,
                          this=False)
-        builder.add_dir(b'bar-dir', builder.tree_root, b'bar-id',
+        builder.add_dir(b'bar-dir', builder.tree_root, 'bar-id',
                         base=False, other=False)
         return builder
 

=== modified file 'breezy/tests/test_options.py'
--- breezy/tests/test_options.py	2018-07-31 00:06:59 +0000
+++ breezy/tests/test_options.py	2018-08-05 20:13:41 +0000
@@ -81,7 +81,7 @@
 
     def test_unknown_short_opt(self):
         out, err = self.run_bzr('help -r', retcode=3)
-        self.assertContainsRe(err, br'no such option')
+        self.assertContainsRe(err, r'no such option')
 
     def test_set_short_name(self):
         o = option.Option('wiggle')

=== modified file 'breezy/tests/test_reconfigure.py'
--- breezy/tests/test_reconfigure.py	2018-06-18 02:13:57 +0000
+++ breezy/tests/test_reconfigure.py	2018-08-02 01:10:26 +0000
@@ -385,7 +385,7 @@
         tree = workingtree.WorkingTree.open('root/tree')
         repo = tree.branch.repository
         self.assertRaises(errors.NoSuchRevision, repo.get_revision,
-                          'dead-head-id')
+                          b'dead-head-id')
 
     def test_standalone_to_standalone(self):
         tree = self.make_branch_and_tree('tree')

=== modified file 'breezy/tests/test_remote.py'
--- breezy/tests/test_remote.py	2018-07-25 21:49:15 +0000
+++ breezy/tests/test_remote.py	2018-08-02 01:10:26 +0000
@@ -1045,7 +1045,7 @@
         # XXX: It would be better to call fmt.initialize_on_transport_ex, but
         # it's currently hard to test that without supplying a real remote
         # transport connected to a real server.
-        result = fmt._initialize_on_transport_ex_rpc(client, 'path',
+        result = fmt._initialize_on_transport_ex_rpc(client, b'path',
             transport, False, False, False, None, None, None, None, False)
         self.assertFinished(client)
 
@@ -1067,7 +1067,7 @@
         # it's currently hard to test that without supplying a real remote
         # transport connected to a real server.
         err = self.assertRaises(errors.PermissionDenied,
-            fmt._initialize_on_transport_ex_rpc, client, 'path', transport,
+            fmt._initialize_on_transport_ex_rpc, client, b'path', transport,
             False, False, False, None, None, None, None, False)
         self.assertEqual('path', err.path)
         self.assertEqual(': extra info', err.extra)
@@ -1596,8 +1596,8 @@
         client = FakeClient(self.get_url())
         branch_network_name = self.get_branch_format().network_name()
         client.add_expected_call(
-            b'BzrDir.open_branchV3', ('stacked/',),
-            b'success', ('branch', branch_network_name))
+            b'BzrDir.open_branchV3', (b'stacked/',),
+            b'success', (b'branch', branch_network_name))
         client.add_expected_call(
             b'BzrDir.find_repositoryV3', (b'stacked/',),
             b'success', (b'ok', b'', b'yes', b'no', b'yes', network_name))
@@ -1994,7 +1994,7 @@
         client.add_expected_call(
             b'Branch.lock_write', (b'memory:///', b'', b''),
             b'success', (b'ok', b'branch token', b'repo token'))
-        encoded_dict_value = 'd5:ascii1:a11:unicode \xe2\x8c\x9a3:\xe2\x80\xbde'
+        encoded_dict_value = b'd5:ascii1:a11:unicode \xe2\x8c\x9a3:\xe2\x80\xbde'
         client.add_expected_call(
             b'Branch.set_config_option_dict', (b'memory:///', b'branch token',
             b'repo token', encoded_dict_value, b'foo', b''),

=== modified file 'breezy/tests/test_rename_map.py'
--- breezy/tests/test_rename_map.py	2018-07-24 21:44:05 +0000
+++ breezy/tests/test_rename_map.py	2018-08-05 20:32:23 +0000
@@ -46,8 +46,8 @@
         tree.add('a', b'a')
         rn = RenameMap(tree)
         rn.add_file_edge_hashes(tree, [b'a'])
-        self.assertEqual({'a'}, rn.edge_hashes[myhash(('a\n', 'b\n'))])
-        self.assertEqual({'a'}, rn.edge_hashes[myhash(('b\n', 'c\n'))])
+        self.assertEqual({b'a'}, rn.edge_hashes[myhash(('a\n', 'b\n'))])
+        self.assertEqual({b'a'}, rn.edge_hashes[myhash(('b\n', 'c\n'))])
         self.assertIs(None, rn.edge_hashes.get(myhash(('c\n', 'd\n'))))
 
     def test_hitcounts(self):
@@ -63,8 +63,8 @@
         rn = RenameMap(tree)
         rn.add_edge_hashes(self.a_lines, 'aid')
         rn.add_edge_hashes(self.b_lines, 'bid')
-        self.build_tree_contents([('tree/a', ''.join(self.a_lines))])
-        self.build_tree_contents([('tree/b', ''.join(self.b_lines))])
+        self.build_tree_contents([('tree/a', b''.join(self.a_lines))])
+        self.build_tree_contents([('tree/b', b''.join(self.b_lines))])
         self.assertEqual({'a': 'aid', 'b': 'bid'},
                          rn.file_match(['a', 'b']))
 

=== modified file 'breezy/tests/test_repository.py'
--- breezy/tests/test_repository.py	2018-07-27 01:17:23 +0000
+++ breezy/tests/test_repository.py	2018-08-07 20:43:32 +0000
@@ -255,7 +255,7 @@
         tree.add(['foo'], [b'Nasty-IdC:'], ['file'])
         tree.put_file_bytes_non_atomic('foo', b'')
         tree.commit('1st post', rev_id=b'foo')
-        self.assertHasKnit(t, b'knits/e8/%254easty-%2549d%2543%253a',
+        self.assertHasKnit(t, 'knits/e8/%254easty-%2549d%2543%253a',
             b'\nfoo fulltext 0 81  :')
 
     def assertHasKnit(self, t, knit_name, extra_content=b''):
@@ -265,9 +265,9 @@
 
     def check_knits(self, t):
         """check knit content for a repository."""
-        self.assertHasKnit(t, b'inventory')
-        self.assertHasKnit(t, b'revisions')
-        self.assertHasKnit(t, b'signatures')
+        self.assertHasKnit(t, 'inventory')
+        self.assertHasKnit(t, 'revisions')
+        self.assertHasKnit(t, 'signatures')
 
     def test_shared_disk_layout(self):
         control = bzrdir.BzrDirMetaFormat1().initialize(self.get_url())
@@ -724,31 +724,31 @@
         # would only get the newly created chk pages
         search = vf_search.SearchResult({b'rev-2'}, {b'rev-1'}, 1,
                                     {b'rev-2'})
-        simple_chk_records = []
+        simple_chk_records = set()
         for vf_name, substream in source.get_stream(search):
             if vf_name == 'chk_bytes':
                 for record in substream:
-                    simple_chk_records.append(record.key)
+                    simple_chk_records.add(record.key)
             else:
                 for _ in substream:
                     continue
         # 3 pages, the root (InternalNode), + 2 pages which actually changed
-        self.assertEqual([(b'sha1:91481f539e802c76542ea5e4c83ad416bf219f73',),
+        self.assertEqual({(b'sha1:91481f539e802c76542ea5e4c83ad416bf219f73',),
                           (b'sha1:4ff91971043668583985aec83f4f0ab10a907d3f',),
                           (b'sha1:81e7324507c5ca132eedaf2d8414ee4bb2226187',),
-                          (b'sha1:b101b7da280596c71a4540e9a1eeba8045985ee0',)],
-                         simple_chk_records)
+                          (b'sha1:b101b7da280596c71a4540e9a1eeba8045985ee0',)},
+                         set(simple_chk_records))
         # Now, when we do a similar call using 'get_stream_for_missing_keys'
         # we should get a much larger set of pages.
         missing = [('inventories', b'rev-2')]
-        full_chk_records = []
+        full_chk_records = set()
         for vf_name, substream in source.get_stream_for_missing_keys(missing):
             if vf_name == 'inventories':
                 for record in substream:
                     self.assertEqual((b'rev-2',), record.key)
             elif vf_name == 'chk_bytes':
                 for record in substream:
-                    full_chk_records.append(record.key)
+                    full_chk_records.add(record.key)
             else:
                 self.fail('Should not be getting a stream of %s' % (vf_name,))
         # We have 257 records now. This is because we have 1 root page, and 256
@@ -956,13 +956,15 @@
 
     def add_file(self, repo, inv, filename, revision, parents):
         file_id = filename.encode('utf-8') + b'-id'
+        content = [b'line\n']
         entry = inventory.InventoryFile(file_id, filename, b'TREE_ROOT')
         entry.revision = revision
+        entry.text_sha1 = osutils.sha_strings(content)
         entry.text_size = 0
         inv.add(entry)
         text_key = (file_id, revision)
         parent_keys = [(file_id, parent) for parent in parents]
-        repo.texts.add_lines(text_key, parent_keys, [b'line\n'])
+        repo.texts.add_lines(text_key, parent_keys, content)
 
     def test_insert_from_broken_repo(self):
         """Inserting a data stream from a broken repository won't silently

=== modified file 'breezy/tests/test_revert.py'
--- breezy/tests/test_revert.py	2018-07-07 19:27:38 +0000
+++ breezy/tests/test_revert.py	2018-08-05 21:18:15 +0000
@@ -103,7 +103,8 @@
         self.addCleanup(tree.unlock)
         self.assertTrue(tree.is_executable('newfile'))
         transform.revert(tree, tree.basis_tree(), None, backups=True)
-        self.assertEqual('helooo!', tree.get_file('newfile').read())
+        with tree.get_file('newfile', 'rb') as f:
+            self.assertEqual(b'helooo!', f.read())
         self.assertTrue(tree.is_executable('newfile'))
 
     def test_revert_executable(self):

=== modified file 'breezy/tests/test_selftest.py'
--- breezy/tests/test_selftest.py	2018-07-31 17:39:09 +0000
+++ breezy/tests/test_selftest.py	2018-08-02 23:52:07 +0000
@@ -18,6 +18,7 @@
 
 import gc
 import doctest
+from functools import reduce
 import os
 import signal
 import sys
@@ -790,8 +791,8 @@
 
         This is used to exercise the test framework.
         """
-        self.time(text_type, 'hello', errors='replace')
-        self.time(text_type, 'world', errors='replace')
+        self.time(text_type, b'hello', errors='replace')
+        self.time(text_type, b'world', errors='replace')
 
     def test_lsprofiling(self):
         """Verbose test result prints lsprof statistics from test cases."""
@@ -821,14 +822,20 @@
         # and then repeated but with 'world', rather than 'hello'.
         # this should appear in the output stream of our test result.
         output = result_stream.getvalue()
-        self.assertContainsRe(output,
-            r"LSProf output for <type 'unicode'>\(\('hello',\), {'errors': 'replace'}\)")
+        if PY3:
+            self.assertContainsRe(output,
+                r"LSProf output for <class 'str'>\(\(b'hello',\), {'errors': 'replace'}\)")
+            self.assertContainsRe(output,
+                r"LSProf output for <class 'str'>\(\(b'world',\), {'errors': 'replace'}\)")
+        else:
+            self.assertContainsRe(output,
+                r"LSProf output for <type 'unicode'>\(\('hello',\), {'errors': 'replace'}\)")
+            self.assertContainsRe(output,
+                r"LSProf output for <type 'unicode'>\(\('world',\), {'errors': 'replace'}\)\n")
         self.assertContainsRe(output,
             r" *CallCount *Recursive *Total\(ms\) *Inline\(ms\) *module:lineno\(function\)\n")
         self.assertContainsRe(output,
             r"( +1 +0 +0\.\d+ +0\.\d+ +<method 'disable' of '_lsprof\.Profiler' objects>\n)?")
-        self.assertContainsRe(output,
-            r"LSProf output for <type 'unicode'>\(\('world',\), {'errors': 'replace'}\)\n")
 
     def test_uses_time_from_testtools(self):
         """Test case timings in verbose results should use testtools times"""
@@ -1912,9 +1919,14 @@
         self.assertRaises(AssertionError, self.assertIsInstance, 23.3, int)
         e = self.assertRaises(AssertionError,
             self.assertIsInstance, None, int, "it's just not")
-        self.assertEqual(str(e),
-            "None is an instance of <type 'NoneType'> rather than <type 'int'>"
-            ": it's just not")
+        if PY3:
+            self.assertEqual(str(e),
+                "None is an instance of <class 'NoneType'> rather than <class 'int'>: it's "
+                "just not")
+        else:
+            self.assertEqual(str(e),
+                "None is an instance of <type 'NoneType'> rather than <type 'int'>"
+                ": it's just not")
 
     def test_assertEndsWith(self):
         self.assertEndsWith('foo', 'oo')
@@ -2174,7 +2186,7 @@
 
     def test_load_list(self):
         # Provide a list with one test - this test.
-        test_id_line = b'%s\n' % self.id()
+        test_id_line = '%s\n' % self.id()
         self.build_tree_contents([('test.list', test_id_line)])
         # And generate a list of the tests in  the suite.
         stream = self.run_selftest(load_list='test.list', list_only=True)
@@ -2862,7 +2874,7 @@
         out, err = self.run_bzr(["log", "%s/nonexistantpath" % url], retcode=3)
         self.assertEqual(out, '')
         self.assertContainsRe(err,
-            b'brz: ERROR: Not a branch: ".*nonexistantpath/".\n')
+            'brz: ERROR: Not a branch: ".*nonexistantpath/".\n')
 
 
 class TestTestLoader(tests.TestCase):

=== modified file 'breezy/tests/test_transform.py'
--- breezy/tests/test_transform.py	2018-07-26 02:19:13 +0000
+++ breezy/tests/test_transform.py	2018-08-05 20:20:29 +0000
@@ -62,6 +62,7 @@
 from ..mutabletree import MutableTree
 from ..sixish import (
     BytesIO,
+    PY3,
     text_type,
     )
 from . import (
@@ -2548,8 +2549,12 @@
         new_globals.update(globals)
         new_func = types.FunctionType(func.__code__, new_globals,
             func.__name__, func.__defaults__)
-        setattr(instance, method_name,
-            types.MethodType(new_func, instance, instance.__class__))
+        if PY3:
+            setattr(instance, method_name,
+                types.MethodType(new_func, instance))
+        else:
+            setattr(instance, method_name,
+                types.MethodType(new_func, instance, instance.__class__))
         self.addCleanup(delattr, instance, method_name)
 
     @staticmethod

=== modified file 'breezy/tests/test_upstream_import.py'
--- breezy/tests/test_upstream_import.py	2018-07-19 22:29:27 +0000
+++ breezy/tests/test_upstream_import.py	2018-08-06 02:24:28 +0000
@@ -66,11 +66,11 @@
         existing = fileobj.read()
         fileobj.seek(0)
         path = tempfile.mkdtemp(dir=os.getcwd())
-        if existing != '':
+        if existing != b'':
             # copytree requires the directory not to exist
             os.rmdir(path)
             copytree(existing, path)
-        fileobj.write(path)
+        fileobj.write(path.encode('utf-8'))
         self.root = path
 
     def add(self, path):
@@ -223,8 +223,7 @@
     def archive_test(self, builder, importer, subdir=False):
         archive_file = self.make_archive(builder, subdir)
         tree = BzrDir.create_standalone_workingtree('tree')
-        tree.lock_write()
-        try:
+        with tree.lock_write():
             importer(tree, archive_file)
             self.assertTrue(tree.is_versioned('README'))
             self.assertTrue(tree.is_versioned('FEEDME'))
@@ -242,9 +241,6 @@
             # Ensure the second version of the file is used.
             self.assertEqual(tree.get_file_text('README'), b'Wow?')
             self.assertTrue(not os.path.exists(tree.abspath('FEEDME')))
-        finally:
-            tree.unlock()
-
 
     def test_untar2(self):
         tar_file = self.make_messed_tar()

=== modified file 'breezy/tests/test_urlutils.py'
--- breezy/tests/test_urlutils.py	2018-07-22 21:59:42 +0000
+++ breezy/tests/test_urlutils.py	2018-08-05 22:33:53 +0000
@@ -415,7 +415,7 @@
             raise TestSkipped("local encoding cannot handle unicode")
 
         self.assertEqual('file:///D:/path/to/r%C3%A4ksm%C3%B6rg%C3%A5s', result)
-        self.assertFalse(isinstance(result, text_type))
+        self.assertIsInstance(result, str)
 
     def test_win32_unc_path_to_url(self):
         self.requireFeature(features.win32_feature)
@@ -654,7 +654,7 @@
     def test_escape(self):
         self.assertEqual('%25', urlutils.escape('%'))
         self.assertEqual('%C3%A5', urlutils.escape(u'\xe5'))
-        self.assertFalse(isinstance(urlutils.escape(u'\xe5'), text_type))
+        self.assertIsInstance(urlutils.escape(u'\xe5'), str)
 
     def test_escape_tildes(self):
         self.assertEqual('~foo', urlutils.escape('~foo'))
@@ -1050,5 +1050,12 @@
 
     def test_unquote(self):
         self.assertEqual('%', urlutils.unquote('%25'))
-        self.assertEqual('\xc3\xa5', urlutils.unquote('%C3%A5'))
+        if PY3:
+            self.assertEqual('\xe5', urlutils.unquote('%C3%A5'))
+        else:
+            self.assertEqual('\xc3\xa5', urlutils.unquote('%C3%A5'))
         self.assertEqual(u"\xe5", urlutils.unquote(u'\xe5'))
+
+    def test_unquote_to_bytes(self):
+        self.assertEqual(b'%', urlutils.unquote_to_bytes('%25'))
+        self.assertEqual(b'\xc3\xa5', urlutils.unquote_to_bytes('%C3%A5'))

=== modified file 'breezy/tests/test_version.py'
--- breezy/tests/test_version.py	2018-07-15 18:45:17 +0000
+++ breezy/tests/test_version.py	2018-08-05 20:11:23 +0000
@@ -25,8 +25,8 @@
     workingtree,
     )
 from ..sixish import (
-    BytesIO,
     PY3,
+    StringIO,
     )
 from .scenarios import load_tests_apply_scenarios
 
@@ -53,7 +53,7 @@
 
     def test_python_binary_path(self):
         self.permit_source_tree_branch_repo()
-        sio = BytesIO()
+        sio = StringIO()
         version.show_version(show_config=False, show_copyright=False,
             to_file=sio)
         out = sio.getvalue()

=== modified file 'breezy/tests/test_vf_search.py'
--- breezy/tests/test_vf_search.py	2018-06-29 15:36:29 +0000
+++ breezy/tests/test_vf_search.py	2018-08-02 01:10:26 +0000
@@ -35,8 +35,8 @@
 #   rev3  /
 #     |  /
 #   rev4
-ancestry_1 = {'rev1': [NULL_REVISION], 'rev2a': ['rev1'], 'rev2b': ['rev1'],
-              'rev3': ['rev2a'], 'rev4': ['rev3', 'rev2b']}
+ancestry_1 = {b'rev1': [NULL_REVISION], b'rev2a': [b'rev1'], b'rev2b': [b'rev1'],
+              b'rev3': [b'rev2a'], b'rev4': [b'rev3', b'rev2b']}
 
 # Ancestry 2:
 #
@@ -49,8 +49,8 @@
 # rev3a
 #   |
 # rev4a
-ancestry_2 = {'rev1a': [NULL_REVISION], 'rev2a': ['rev1a'],
-              'rev1b': [NULL_REVISION], 'rev3a': ['rev2a'], 'rev4a': ['rev3a']}
+ancestry_2 = {b'rev1a': [NULL_REVISION], b'rev2a': [b'rev1a'],
+              b'rev1b': [NULL_REVISION], b'rev3a': [b'rev2a'], b'rev4a': [b'rev3a']}
 
 
 # Extended history shortcut
@@ -65,12 +65,12 @@
 #       d |
 #       |\|
 #       e f
-extended_history_shortcut = {'a': [NULL_REVISION],
-                             'b': ['a'],
-                             'c': ['b'],
-                             'd': ['c'],
-                             'e': ['d'],
-                             'f': ['a', 'd'],
+extended_history_shortcut = {b'a': [NULL_REVISION],
+                             b'b': [b'a'],
+                             b'c': [b'b'],
+                             b'd': [b'c'],
+                             b'e': [b'd'],
+                             b'f': [b'a', b'd'],
                             }
 
 
@@ -83,18 +83,18 @@
         # Used when pulling from a stacked repository, so test some revisions
         # being satisfied from the stacking branch.
         g = self.make_graph(
-            {"tip":["mid"], "mid":["base"], "tag":["base"],
-             "base":[NULL_REVISION], NULL_REVISION:[]})
-        result = vf_search.SearchResult({'tip', 'tag'},
-            {NULL_REVISION}, 4, {'tip', 'mid', 'tag', 'base'})
-        result = result.refine({'tip'}, {'mid'})
+            {b"tip": [b"mid"], b"mid": [b"base"], b"tag": [b"base"],
+             b"base": [NULL_REVISION], NULL_REVISION:[]})
+        result = vf_search.SearchResult({b'tip', b'tag'},
+            {NULL_REVISION}, 4, {b'tip', b'mid', b'tag', b'base'})
+        result = result.refine({b'tip'}, {b'mid'})
         recipe = result.get_recipe()
         # We should be starting from tag (original head) and mid (seen ref)
-        self.assertEqual({'mid', 'tag'}, recipe[1])
+        self.assertEqual({b'mid', b'tag'}, recipe[1])
         # We should be stopping at NULL (original stop) and tip (seen head)
-        self.assertEqual({NULL_REVISION, 'tip'}, recipe[2])
+        self.assertEqual({NULL_REVISION, b'tip'}, recipe[2])
         self.assertEqual(3, recipe[3])
-        result = result.refine({'mid', 'tag', 'base'},
+        result = result.refine({b'mid', b'tag', b'base'},
             {NULL_REVISION})
         recipe = result.get_recipe()
         # We should be starting from nothing (NULL was known as a cut point)
@@ -103,7 +103,7 @@
         # tag (seen head) and mid(seen mid-point head). We could come back and
         # define this as not including mid, for minimal results, but it is
         # still 'correct' to include mid, and simpler/easier.
-        self.assertEqual({NULL_REVISION, 'tip', 'tag', 'mid'}, recipe[2])
+        self.assertEqual({NULL_REVISION, b'tip', b'tag', b'mid'}, recipe[2])
         self.assertEqual(0, recipe[3])
         self.assertTrue(result.is_empty())
 
@@ -122,30 +122,30 @@
         self.assertSearchResult([], [], 0, None)
 
     def test_ancestry_1(self):
-        self.assertSearchResult(['rev4'], [NULL_REVISION], len(ancestry_1),
+        self.assertSearchResult([b'rev4'], [NULL_REVISION], len(ancestry_1),
                                 ancestry_1)
 
     def test_ancestry_2(self):
-        self.assertSearchResult(['rev1b', 'rev4a'], [NULL_REVISION],
+        self.assertSearchResult([b'rev1b', b'rev4a'], [NULL_REVISION],
                                 len(ancestry_2), ancestry_2)
-        self.assertSearchResult(['rev1b', 'rev4a'], [],
+        self.assertSearchResult([b'rev1b', b'rev4a'], [],
                                 len(ancestry_2)+1, ancestry_2,
                                 missing_keys=[NULL_REVISION])
 
     def test_partial_search(self):
         parent_map = dict((k, extended_history_shortcut[k])
-                          for k in ['e', 'f'])
-        self.assertSearchResult(['e', 'f'], ['d', 'a'], 2,
+                          for k in [b'e', b'f'])
+        self.assertSearchResult([b'e', b'f'], [b'd', b'a'], 2,
                                 parent_map)
         parent_map.update((k, extended_history_shortcut[k])
-                          for k in ['d', 'a'])
-        self.assertSearchResult(['e', 'f'], ['c', NULL_REVISION], 4,
+                          for k in [b'd', b'a'])
+        self.assertSearchResult([b'e', b'f'], [b'c', NULL_REVISION], 4,
                                 parent_map)
-        parent_map['c'] = extended_history_shortcut['c']
-        self.assertSearchResult(['e', 'f'], ['b'], 6,
+        parent_map[b'c'] = extended_history_shortcut[b'c']
+        self.assertSearchResult([b'e', b'f'], [b'b'], 6,
                                 parent_map, missing_keys=[NULL_REVISION])
-        parent_map['b'] = extended_history_shortcut['b']
-        self.assertSearchResult(['e', 'f'], [], 7,
+        parent_map[b'b'] = extended_history_shortcut[b'b']
+        self.assertSearchResult([b'e', b'f'], [], 7,
                                 parent_map, missing_keys=[NULL_REVISION])
 
 
@@ -159,24 +159,24 @@
                          (sorted(start), sorted(stop), count))
 
     def test_empty_ancestry(self):
-        self.assertSearchResult([], [], 0, {}, (), ['tip-rev-id'], 10)
+        self.assertSearchResult([], [], 0, {}, (), [b'tip-rev-id'], 10)
 
     def test_ancestry_1(self):
-        self.assertSearchResult(['rev4'], ['rev1'], 4,
-                                ancestry_1, (), ['rev1'], 10)
-        self.assertSearchResult(['rev2a', 'rev2b'], ['rev1'], 2,
-                                ancestry_1, (), ['rev1'], 1)
+        self.assertSearchResult([b'rev4'], [b'rev1'], 4,
+                                ancestry_1, (), [b'rev1'], 10)
+        self.assertSearchResult([b'rev2a', b'rev2b'], [b'rev1'], 2,
+                                ancestry_1, (), [b'rev1'], 1)
 
 
     def test_multiple_heads(self):
-        self.assertSearchResult(['e', 'f'], ['a'], 5,
-                                extended_history_shortcut, (), ['a'], 10)
+        self.assertSearchResult([b'e', b'f'], [b'a'], 5,
+                                extended_history_shortcut, (), [b'a'], 10)
         # Note that even though we only take 1 step back, we find 'f', which
         # means the described search will still find d and c.
-        self.assertSearchResult(['f'], ['a'], 4,
-                                extended_history_shortcut, (), ['a'], 1)
-        self.assertSearchResult(['f'], ['a'], 4,
-                                extended_history_shortcut, (), ['a'], 2)
+        self.assertSearchResult([b'f'], [b'a'], 4,
+                                extended_history_shortcut, (), [b'a'], 1)
+        self.assertSearchResult([b'f'], [b'a'], 4,
+                                extended_history_shortcut, (), [b'a'], 2)
 
 
 class TestPendingAncestryResultRefine(tests.TestCase):
@@ -188,12 +188,12 @@
         # Used when pulling from a stacked repository, so test some revisions
         # being satisfied from the stacking branch.
         g = self.make_graph(
-            {"tip":["mid"], "mid":["base"], "tag":["base"],
-             "base":[NULL_REVISION], NULL_REVISION:[]})
-        result = vf_search.PendingAncestryResult(['tip', 'tag'], None)
-        result = result.refine({'tip'}, {'mid'})
-        self.assertEqual({'mid', 'tag'}, result.heads)
-        result = result.refine({'mid', 'tag', 'base'},
+            {b"tip": [b"mid"], b"mid": [b"base"], b"tag": [b"base"],
+             b"base":[NULL_REVISION], NULL_REVISION:[]})
+        result = vf_search.PendingAncestryResult([b'tip', b'tag'], None)
+        result = result.refine({b'tip'}, {b'mid'})
+        self.assertEqual({b'mid', b'tag'}, result.heads)
+        result = result.refine({b'mid', b'tag', b'base'},
             {NULL_REVISION})
         self.assertEqual({NULL_REVISION}, result.heads)
         self.assertTrue(result.is_empty())
@@ -236,8 +236,8 @@
         # ancestries.
         class StubGraph(object):
             def iter_ancestry(self, keys):
-                return [(NULL_REVISION, ()), ('foo', (NULL_REVISION,))]
-        result = vf_search.PendingAncestryResult(['rev-3'], None)
+                return [(NULL_REVISION, ()), (b'foo', (NULL_REVISION,))]
+        result = vf_search.PendingAncestryResult([b'rev-3'], None)
         result_keys = result._get_keys(StubGraph())
         # Only the non-null keys from the ancestry appear.
-        self.assertEqual({'foo'}, set(result_keys))
+        self.assertEqual({b'foo'}, set(result_keys))

=== modified file 'breezy/transform.py'
--- breezy/transform.py	2018-07-24 19:02:16 +0000
+++ breezy/transform.py	2018-08-07 20:43:32 +0000
@@ -1003,7 +1003,11 @@
                    (from_name, to_name),
                    (from_kind, to_kind),
                    (from_executable, to_executable)))
-        return iter(sorted(results, key=lambda x:x[1]))
+
+        def path_key(t):
+            paths = t[1]
+            return (paths[0] or '', paths[1] or '')
+        return iter(sorted(results, key=path_key))
 
     def get_preview_tree(self):
         """Return a tree representing the result of the transform.
@@ -1128,7 +1132,7 @@
             }
         yield serializer.bytes_record(bencode.bencode(attribs),
                                       ((b'attribs',),))
-        for trans_id, kind in viewitems(self._new_contents):
+        for trans_id, kind in sorted(viewitems(self._new_contents)):
             if kind == 'file':
                 with open(self._limbo_name(trans_id), 'rb') as cur_file:
                     lines = cur_file.readlines()

=== modified file 'breezy/transport/http/response.py'
--- breezy/transport/http/response.py	2018-08-01 19:37:07 +0000
+++ breezy/transport/http/response.py	2018-08-02 01:57:42 +0000
@@ -209,7 +209,7 @@
                     % (self._boundary, boundary_line))
 
     def _unquote_boundary(self, b):
-        return b[:2] + email_utils.unquote(b[2:-2]) + b[-2:]
+        return b[:2] + email_utils.unquote(b[2:-2].decode('ascii')).encode('ascii') + b[-2:]
 
     def read_range_definition(self):
         """Read a new range definition in a multi parts message.

=== modified file 'breezy/transport/sftp.py'
--- breezy/transport/sftp.py	2018-06-15 13:10:28 +0000
+++ breezy/transport/sftp.py	2018-08-04 18:44:34 +0000
@@ -80,7 +80,7 @@
 else:
     from paramiko.sftp import (SFTP_FLAG_WRITE, SFTP_FLAG_CREATE,
                                SFTP_FLAG_EXCL, SFTP_FLAG_TRUNC,
-                               SFTP_OK, CMD_HANDLE, CMD_OPEN)
+                               CMD_HANDLE, CMD_OPEN)
     from paramiko.sftp_attr import SFTPAttributes
     from paramiko.sftp_file import SFTPFile
 
@@ -852,11 +852,6 @@
         try:
             conn = self._get_sftp()
             sftp_retval = conn.symlink(source, link_name)
-            if SFTP_OK != sftp_retval:
-                raise TransportError(
-                    '%r: unable to create symlink to %r' % (link_name, source),
-                    sftp_retval
-                )
         except (IOError, paramiko.SSHException) as e:
             self._translate_io_exception(e, link_name,
                                          ': unable to create symlink to %r' % (source))

=== modified file 'breezy/upstream_import.py'
--- breezy/upstream_import.py	2018-07-22 17:06:14 +0000
+++ breezy/upstream_import.py	2018-08-07 02:57:10 +0000
@@ -107,7 +107,7 @@
         if mode != 'r':
             raise AssertionError(
                 'only readonly supported')
-        self.root = os.path.realpath(fileobj.read())
+        self.root = os.path.realpath(fileobj.read().decode('utf-8'))
 
     def __repr__(self):
         return 'DirWrapper(%r)' % self.root
@@ -331,7 +331,7 @@
             archive, external_compressor = get_archive_type(source)
         except NotArchiveType:
             if file_kind(source) == 'directory':
-                s = StringIO(source)
+                s = BytesIO(source.encode('utf-8'))
                 s.seek(0)
                 import_dir(tree, s)
             else:

=== modified file 'breezy/urlutils.py'
--- breezy/urlutils.py	2018-07-23 22:25:11 +0000
+++ breezy/urlutils.py	2018-08-02 01:10:26 +0000
@@ -422,7 +422,7 @@
         if path_chars[i] not in _url_safe_characters:
             chars = path_chars[i].encode('utf-8')
             path_chars[i] = ''.join(
-                ['%%%02X' % ord(c) for c in path_chars[i].encode('utf-8')])
+                ['%%%02X' % c for c in bytearray(path_chars[i].encode('utf-8'))])
     path = ''.join(path_chars)
     path = _url_hex_escapes_re.sub(_unescape_safe_chars, path)
     return str(prefix + path)

=== modified file 'breezy/workingtree.py'
--- breezy/workingtree.py	2018-07-15 18:45:17 +0000
+++ breezy/workingtree.py	2018-08-07 19:23:46 +0000
@@ -32,13 +32,13 @@
 import errno
 import os
 import re
-import shutil
 import sys
 
 import breezy
 
 from .lazy_import import lazy_import
 lazy_import(globals(), """
+import shutil
 import stat
 
 from breezy import (

=== modified file 'python3.flapping'
--- python3.flapping	2018-08-01 19:37:37 +0000
+++ python3.flapping	2018-08-07 20:43:32 +0000
@@ -4,39 +4,17 @@
 breezy.tests.per_repository_chk.test_supported.TestCommitWriteGroupIntegrityCheck.test_missing_chk_leaf_for_inventory(RemoteRepositoryFormat-v2(Supported))
 breezy.tests.per_repository_chk.test_supported.TestCommitWriteGroupIntegrityCheck.test_missing_chk_leaf_for_inventory(RepositoryFormat2a)
 breezy.tests.per_repository_chk.test_supported.TestCommitWriteGroupIntegrityCheck.test_missing_chk_leaf_for_inventory(RepositoryFormat2aSubtree)
-breezy.tests.per_repository_reference.test_get_record_stream.TestGetRecordStream.test_ordered_no_closure(RepositoryFormatKnitPack5)
-breezy.tests.per_repository_reference.test_get_record_stream.TestGetRecordStream.test_ordered_no_closure(RepositoryFormatKnitPack5RichRoot)
-breezy.tests.per_repository_reference.test_get_record_stream.TestGetRecordStream.test_ordered_no_closure(RepositoryFormatKnitPack5RichRootBroken)
-breezy.tests.per_repository_reference.test_get_record_stream.TestGetRecordStream.test_ordered_no_closure(RepositoryFormatKnitPack6)
-breezy.tests.per_repository_reference.test_get_record_stream.TestGetRecordStream.test_ordered_no_closure(RepositoryFormatKnitPack6RichRoot)
-breezy.tests.per_repository_reference.test_get_record_stream.TestGetRecordStream.test_ordered_no_closure(RepositoryFormatPackDevelopment2Subtree)
-breezy.tests.test_conflicts.TestResolveMissingParent.test_resolve_taking_this
-breezy.tests.test_import_tariff.TestImportTariffs.test_simple_serve
-breezy.tests.test_index.TestCombinedGraphIndex.test_iter_all_entries_reloads
-breezy.tests.test_index.TestCombinedGraphIndex.test_iter_entries_reloads
 breezy.plugins.git.tests.test_blackbox.TestGitBlackBox.test_branch_ls
 breezy.plugins.git.tests.test_blackbox.TestGitBlackBox.test_checkout
 breezy.plugins.git.tests.test_fetch.LocalRepositoryFetchTests.test_symlink_becomes_dir
-breezy.plugins.weave_fmt.test_bzrdir.V4WeaveBundleTester.test_skip_file
-breezy.tests.blackbox.test_filtered_view_ops.TestViewFileOperations.test_view_on_commit
-breezy.tests.blackbox.test_filtered_view_ops.TestViewFileOperations.test_view_on_commit_selected
-breezy.tests.blackbox.test_filtered_view_ops.TestViewFileOperations.test_view_on_status
-breezy.tests.blackbox.test_filtered_view_ops.TestViewFileOperations.test_view_on_status_selected
+breezy.plugins.git.tests.test_fetch.LocalRepositoryFetchTests.test_dir_becomes_symlink
 breezy.tests.blackbox.test_shared_repository.TestSharedRepo.test_init_repo_without_username
 breezy.tests.blackbox.test_shared_repository.TestSharedRepo.test_make_repository
 breezy.tests.blackbox.test_shared_repository.TestSharedRepo.test_make_repository_quiet
-breezy.tests.test_bundle.V4_2aBundleTester.test_skip_file
 breezy.tests.test_smart_transport.TestSmartTCPServer.test_graceful_shutdown_waits_for_clients_to_stop
 breezy.plugins.git.tests.test_remote.FetchFromRemoteToBzrTests.test_sprout_with_annotated_tag
 breezy.plugins.git.tests.test_remote.FetchFromRemoteToGitTests.test_sprout_with_annotated_tag
 breezy.plugins.git.tests.test_remote.RemoteControlDirTests.test_annotated_tag
-breezy.tests.test_knit.TestPackKnitAccess.test_get_record_stream_retries
 breezy.tests.test_sftp_transport.SFTPNonServerTest.test_get_paramiko_vendor
 breezy.tests.test_sftp_transport.SSHVendorBadConnection.test_bad_connection_ssh
-breezy.tests.blackbox.test_status.CheckoutStatus.test_status_nonexistent_file_with_others
-breezy.tests.blackbox.test_status.CheckoutStatus.test_status_multiple_nonexistent_files
-breezy.tests.blackbox.test_status.BranchStatus.test_status_multiple_nonexistent_files
-breezy.tests.blackbox.test_status.BranchStatus.test_status_nonexistent_file_with_others
-breezy.tests.test_transform.TestSerializeTransform.test_serialize_creation
-breezy.tests.test_bundle.V4BundleTester.test_skip_file
-breezy.plugins.git.tests.test_fetch.LocalRepositoryFetchTests.test_dir_becomes_symlink
+breezy.tests.test_repository.TestPacker.test_pack_optimizes_pack_order

=== modified file 'python3.passing'
--- python3.passing	2018-08-01 22:01:36 +0000
+++ python3.passing	2018-08-07 20:43:32 +0000
@@ -1,13 +1,5 @@
 # This is the list of tests that are known to pass with Python3.
 # "make check-nodocs3" verifies that these pass.
-breezy.decorators.cachedproperty
-breezy.doc.api.DocFileTest(transport_txt)
-breezy._format_version_tuple
-breezy.iterablefile.IterableFile.close
-breezy.iterablefile.IterableFile.flush
-breezy.lockdir
-breezy.merge3.intersect
-breezy.option._parse_revision_str
 breezy.plugins.bash_completion.tests.test_bashcomp.BlackboxTests.test_bash_completion
 breezy.plugins.bash_completion.tests.test_bashcomp.TestBashCodeGen.test_brz_version
 breezy.plugins.bash_completion.tests.test_bashcomp.TestBashCodeGen.test_command_case
@@ -379,6 +371,9 @@
 breezy.plugins.fastimport.tests.test_generic_processor.TestImportToPackRenameTricky.test_rename_symlink_becomes_directory(1.9-rich-root)
 breezy.plugins.fastimport.tests.test_generic_processor.TestImportToPackRenameTricky.test_rename_symlink_becomes_directory(2a)
 breezy.plugins.fastimport.tests.test_generic_processor.TestImportToPackRenameTricky.test_rename_symlink_becomes_directory(pack-0.92)
+breezy.plugins.fastimport.tests.test_generic_processor.TestImportToPackTag.test_tag(1.9-rich-root)
+breezy.plugins.fastimport.tests.test_generic_processor.TestImportToPackTag.test_tag(2a)
+breezy.plugins.fastimport.tests.test_generic_processor.TestImportToPackTag.test_tag(pack-0.92)
 breezy.plugins.fastimport.tests.test_generic_processor.TestImportZeroMarker.test_tag(1.9-rich-root)
 breezy.plugins.fastimport.tests.test_generic_processor.TestImportZeroMarker.test_tag(2a)
 breezy.plugins.fastimport.tests.test_generic_processor.TestImportZeroMarker.test_tag(pack-0.92)
@@ -392,6 +387,7 @@
 breezy.plugins.fastimport.tests.test_revision_store.Test_TreeShim.test_id2path_no_delta
 breezy.plugins.fastimport.tests.test_revision_store.Test_TreeShim.test_id2path_with_delta
 breezy.plugins.fastimport.tests.test_revision_store.Test_TreeShim.test_path2id
+breezy.plugins.git.tests.test_blackbox.ShallowTests.test_log_shallow
 breezy.plugins.git.tests.test_blackbox.ShallowTests.test_version_info_custom_without_revno
 breezy.plugins.git.tests.test_blackbox.ShallowTests.test_version_info_custom_with_revno
 breezy.plugins.git.tests.test_blackbox.ShallowTests.test_version_info_python
@@ -452,8 +448,6 @@
 breezy.plugins.git.tests.test_builder.TestGitBranchBuilder.test_set_file_executable
 breezy.plugins.git.tests.test_builder.TestGitBranchBuilder.test_set_file_newline
 breezy.plugins.git.tests.test_builder.TestGitBranchBuilder.test_set_file_unicode
-breezy.plugins.git.tests.test_builder.TestGitBranchBuilder.test_set_link
-breezy.plugins.git.tests.test_builder.TestGitBranchBuilder.test_set_link_newline
 breezy.plugins.git.tests.test_builder.TestGitBranchBuilder.test_set_symlink
 breezy.plugins.git.tests.test_builder.TestGitBranchBuilder.test_set_symlink_newline
 breezy.plugins.git.tests.test_cache.DictGitShaMapTests.test_blob
@@ -509,7 +503,6 @@
 breezy.plugins.git.tests.test_git_remote_helper.OpenLocalDirTests.test_from_dir
 breezy.plugins.git.tests.test_git_remote_helper.OpenLocalDirTests.test_from_env_dir
 breezy.plugins.git.tests.test_git_remote_helper.RemoteHelperTests.test_capabilities
-breezy.plugins.git.tests.test_git_remote_helper.RemoteHelperTests.test_import
 breezy.plugins.git.tests.test_git_remote_helper.RemoteHelperTests.test_list_basic
 breezy.plugins.git.tests.test_git_remote_helper.RemoteHelperTests.test_option
 breezy.plugins.git.tests.test_mapping.FileidTests.test_escape_control_l
@@ -1230,6 +1223,7 @@
 breezy.plugins.weave_fmt.test_bzrdir.TestFormat6.test_same_lockfiles_between_tree_repo_branch
 breezy.plugins.weave_fmt.test_bzrdir.TestInfo.test_info_locking_oslocks
 breezy.plugins.weave_fmt.test_bzrdir.TestInit.test_init_weave
+breezy.plugins.weave_fmt.test_bzrdir.TestUpgrade.test_upgrade_makes_dir_weaves
 breezy.plugins.weave_fmt.test_bzrdir.TestUpgrade.test_upgrade_simple
 breezy.plugins.weave_fmt.test_bzrdir.TestUpgrade.test_upgrade_to_meta_sets_workingtree_last_revision
 breezy.plugins.weave_fmt.test_bzrdir.TestUpgrade.test_upgrade_v6_to_meta_no_workingtree
@@ -1257,6 +1251,7 @@
 breezy.plugins.weave_fmt.test_bzrdir.V4WeaveBundleTester.test_malformed
 breezy.plugins.weave_fmt.test_bzrdir.V4WeaveBundleTester.test_non_bundle
 breezy.plugins.weave_fmt.test_bzrdir.V4WeaveBundleTester.test_revision_id_with_slash
+breezy.plugins.weave_fmt.test_bzrdir.V4WeaveBundleTester.test_skip_file
 breezy.plugins.weave_fmt.test_bzrdir.V4WeaveBundleTester.test_symlink_bundle
 breezy.plugins.weave_fmt.test_bzrdir.V4WeaveBundleTester.test_unicode_bundle
 breezy.plugins.weave_fmt.test_bzrdir.V4WeaveBundleTester.test_unicode_symlink_bundle
@@ -1326,8 +1321,6 @@
 breezy.plugins.weave_fmt.test_store.TestVersionFileStore.test___iter__escaped
 breezy.plugins.weave_fmt.test_workingtree.TestFormat2WorkingTree.test_conflicts
 breezy.plugins.weave_fmt.test_workingtree.TestFormat2WorkingTree.test_detect_conflicts
-breezy.pyutils.get_named_object
-breezy.symbol_versioning.deprecated_in
 breezy.tests.blackbox.test_added.TestAdded.test_added
 breezy.tests.blackbox.test_added.TestAdded.test_added_directory
 breezy.tests.blackbox.test_added.TestAdded.test_added_null_separator
@@ -1747,12 +1740,16 @@
 breezy.tests.blackbox.test_filesystem_cicp.TestMove.test_mv_newname_root_after
 breezy.tests.blackbox.test_filtered_view_ops.TestViewFileOperations.test_view_on_add
 breezy.tests.blackbox.test_filtered_view_ops.TestViewFileOperations.test_view_on_add_selected
+breezy.tests.blackbox.test_filtered_view_ops.TestViewFileOperations.test_view_on_commit
+breezy.tests.blackbox.test_filtered_view_ops.TestViewFileOperations.test_view_on_commit_selected
 breezy.tests.blackbox.test_filtered_view_ops.TestViewFileOperations.test_view_on_diff
 breezy.tests.blackbox.test_filtered_view_ops.TestViewFileOperations.test_view_on_diff_selected
 breezy.tests.blackbox.test_filtered_view_ops.TestViewFileOperations.test_view_on_ls
 breezy.tests.blackbox.test_filtered_view_ops.TestViewFileOperations.test_view_on_remove_selected
 breezy.tests.blackbox.test_filtered_view_ops.TestViewFileOperations.test_view_on_revert
 breezy.tests.blackbox.test_filtered_view_ops.TestViewFileOperations.test_view_on_revert_selected
+breezy.tests.blackbox.test_filtered_view_ops.TestViewFileOperations.test_view_on_status
+breezy.tests.blackbox.test_filtered_view_ops.TestViewFileOperations.test_view_on_status_selected
 breezy.tests.blackbox.test_filtered_view_ops.TestViewTreeOperations.test_view_on_merge
 breezy.tests.blackbox.test_filtered_view_ops.TestViewTreeOperations.test_view_on_pull
 breezy.tests.blackbox.test_filtered_view_ops.TestViewTreeOperations.test_view_on_update
@@ -2568,6 +2565,7 @@
 breezy.tests.blackbox.test_sign_my_commits.SignMyCommits.test_sign_dry_run
 breezy.tests.blackbox.test_sign_my_commits.SignMyCommits.test_sign_my_commits
 breezy.tests.blackbox.test_sign_my_commits.SignMyCommits.test_sign_my_commits_location
+breezy.tests.blackbox.test_sign_my_commits.TestSmartServerSignMyCommits.test_sign_single_commit
 breezy.tests.blackbox.test_split.TestSplit.test_split
 breezy.tests.blackbox.test_split.TestSplit.test_split_repo_failure
 breezy.tests.blackbox.test_split.TestSplit.test_split_rich_root
@@ -2576,7 +2574,9 @@
 breezy.tests.blackbox.test_status.BranchStatus.test_branch_status
 breezy.tests.blackbox.test_status.BranchStatus.test_branch_status_revisions
 breezy.tests.blackbox.test_status.BranchStatus.test_pending
+breezy.tests.blackbox.test_status.BranchStatus.test_status_multiple_nonexistent_files
 breezy.tests.blackbox.test_status.BranchStatus.test_status_nonexistent_file
+breezy.tests.blackbox.test_status.BranchStatus.test_status_nonexistent_file_with_others
 breezy.tests.blackbox.test_status.BranchStatus.test_status_nonexistent_file_with_unversioned
 breezy.tests.blackbox.test_status.BranchStatus.test_status_on_ignored
 breezy.tests.blackbox.test_status.BranchStatus.test_status_out_of_date
@@ -2587,7 +2587,9 @@
 breezy.tests.blackbox.test_status.CheckoutStatus.test_branch_status
 breezy.tests.blackbox.test_status.CheckoutStatus.test_branch_status_revisions
 breezy.tests.blackbox.test_status.CheckoutStatus.test_pending
+breezy.tests.blackbox.test_status.CheckoutStatus.test_status_multiple_nonexistent_files
 breezy.tests.blackbox.test_status.CheckoutStatus.test_status_nonexistent_file
+breezy.tests.blackbox.test_status.CheckoutStatus.test_status_nonexistent_file_with_others
 breezy.tests.blackbox.test_status.CheckoutStatus.test_status_nonexistent_file_with_unversioned
 breezy.tests.blackbox.test_status.CheckoutStatus.test_status_on_ignored
 breezy.tests.blackbox.test_status.CheckoutStatus.test_status_out_of_date
@@ -2747,6 +2749,7 @@
 breezy.tests.blackbox.test_upgrade.UpgradeRecommendedTests.test_no_upgrade_recommendation_from_bzrdir
 breezy.tests.blackbox.test_upgrade.UpgradeRecommendedTests.test_recommend_upgrade_wt4
 breezy.tests.blackbox.test_upgrade.UpgradeRecommendedTests.test_upgrade_shared_repo
+breezy.tests.blackbox.test_verify_signatures.TestSmartServerVerifySignatures.test_verify_signatures
 breezy.tests.blackbox.test_verify_signatures.TestVerifySignatures.test_verify_signatures
 breezy.tests.blackbox.test_verify_signatures.TestVerifySignatures.test_verify_signatures_acceptable_key
 breezy.tests.blackbox.test_verify_signatures.TestVerifySignatures.test_verify_signatures_verbose
@@ -2809,8 +2812,6 @@
 breezy.tests.commands.test_push.TestPush.test_push_onto_stacked
 breezy.tests.commands.test_revert.TestRevert.test_revert_tree_write_lock_and_branch_read_lock
 breezy.tests.commands.test_update.TestUpdate.test_update
-breezy.tests.fixtures.generate_unicode_encodings
-breezy.tests.multiply_tests
 breezy.tests.per_branch.test_branch.ChrootedTests.test_open_containing(BranchReferenceFormat)
 breezy.tests.per_branch.test_branch.ChrootedTests.test_open_containing(BzrBranchFormat4)
 breezy.tests.per_branch.test_branch.ChrootedTests.test_open_containing(BzrBranchFormat5)
@@ -3421,8 +3422,6 @@
 breezy.tests.per_branch.test_branch.TestReferenceLocation.test_set_null_reference_info_when_null(RemoteBranchFormat-default)
 breezy.tests.per_branch.test_branch.TestReferenceLocation.test_set_null_reference_info_when_null(RemoteBranchFormat-v2)
 breezy.tests.per_branch.test_branch.TestReferenceLocation.test_set_null_reference_info_when_null(RemoteGitBranchFormat)
-breezy.tests.per_branch.test_branch.TestReferenceLocation.test_set_null_requires_two_nones(BranchReferenceFormat)
-breezy.tests.per_branch.test_branch.TestReferenceLocation.test_set_null_requires_two_nones(BzrBranchFormat7)
 breezy.tests.per_branch.test_branch.TestReferenceLocation.test_set_reference_info(BranchReferenceFormat)
 breezy.tests.per_branch.test_branch.TestReferenceLocation.test_set_reference_info(BzrBranchFormat4)
 breezy.tests.per_branch.test_branch.TestReferenceLocation.test_set_reference_info(BzrBranchFormat5)
@@ -8393,6 +8392,10 @@
 breezy.tests.per_intertree.test_compare.TestIterChanges.test_versioned_symlinks(InterDirStateTree(C))
 breezy.tests.per_intertree.test_compare.TestIterChanges.test_versioned_symlinks(InterTree(CHKInventory))
 breezy.tests.per_intertree.test_compare.TestIterChanges.test_versioned_symlinks_specific_files(InterDirStateTree(C))
+breezy.tests.per_intertree.test_compare.TestIterChanges.test_versioned_symlinks_specific_files(InterDirStateTree(PY))
+breezy.tests.per_intertree.test_compare.TestIterChanges.test_versioned_symlinks_specific_files(InterTree)
+breezy.tests.per_intertree.test_compare.TestIterChanges.test_versioned_symlinks_specific_files(InterTree(CHKInventory))
+breezy.tests.per_intertree.test_compare.TestIterChanges.test_versioned_symlinks_specific_files(InterTree(PreviewTree))
 breezy.tests.per_intertree.test_file_content_matches.TestFileContentMatches.test_different_contents_and_same_verifier(InterDirStateTree(C))
 breezy.tests.per_intertree.test_file_content_matches.TestFileContentMatches.test_different_contents_and_same_verifier(InterDirStateTree(PY))
 breezy.tests.per_intertree.test_file_content_matches.TestFileContentMatches.test_different_contents_and_same_verifier(InterTree)
@@ -9109,6 +9112,10 @@
 breezy.tests.per_repository_reference.test_fetch.TestFetch.test_sprout_from_stacked_with_short_history(RepositoryFormatKnitPack6)
 breezy.tests.per_repository_reference.test_fetch.TestFetch.test_sprout_from_stacked_with_short_history(RepositoryFormatKnitPack6RichRoot)
 breezy.tests.per_repository_reference.test_fetch.TestFetch.test_sprout_from_stacked_with_short_history(RepositoryFormatPackDevelopment2Subtree)
+breezy.tests.per_repository_reference.test_get_record_stream.TestGetRecordStream.test_ordered_fulltext_complex(RemoteRepositoryFormat-default)
+breezy.tests.per_repository_reference.test_get_record_stream.TestGetRecordStream.test_ordered_fulltext_complex(RemoteRepositoryFormat-v2)
+breezy.tests.per_repository_reference.test_get_record_stream.TestGetRecordStream.test_ordered_fulltext_complex(RepositoryFormat2a)
+breezy.tests.per_repository_reference.test_get_record_stream.TestGetRecordStream.test_ordered_fulltext_complex(RepositoryFormat2aSubtree)
 breezy.tests.per_repository_reference.test_get_record_stream.TestGetRecordStream.test_ordered_fulltext_simple(RemoteRepositoryFormat-default)
 breezy.tests.per_repository_reference.test_get_record_stream.TestGetRecordStream.test_ordered_fulltext_simple(RemoteRepositoryFormat-v2)
 breezy.tests.per_repository_reference.test_get_record_stream.TestGetRecordStream.test_ordered_fulltext_simple(RepositoryFormat2a)
@@ -9119,6 +9126,20 @@
 breezy.tests.per_repository_reference.test_get_record_stream.TestGetRecordStream.test_ordered_fulltext_simple(RepositoryFormatKnitPack6)
 breezy.tests.per_repository_reference.test_get_record_stream.TestGetRecordStream.test_ordered_fulltext_simple(RepositoryFormatKnitPack6RichRoot)
 breezy.tests.per_repository_reference.test_get_record_stream.TestGetRecordStream.test_ordered_fulltext_simple(RepositoryFormatPackDevelopment2Subtree)
+breezy.tests.per_repository_reference.test_get_record_stream.TestGetRecordStream.test_ordered_no_closure(RemoteRepositoryFormat-default)
+breezy.tests.per_repository_reference.test_get_record_stream.TestGetRecordStream.test_ordered_no_closure(RemoteRepositoryFormat-v2)
+breezy.tests.per_repository_reference.test_get_record_stream.TestGetRecordStream.test_ordered_no_closure(RepositoryFormat2a)
+breezy.tests.per_repository_reference.test_get_record_stream.TestGetRecordStream.test_ordered_no_closure(RepositoryFormat2aSubtree)
+breezy.tests.per_repository_reference.test_get_record_stream.TestGetRecordStream.test_unordered_fetch_complex_split(RemoteRepositoryFormat-default)
+breezy.tests.per_repository_reference.test_get_record_stream.TestGetRecordStream.test_unordered_fetch_complex_split(RemoteRepositoryFormat-v2)
+breezy.tests.per_repository_reference.test_get_record_stream.TestGetRecordStream.test_unordered_fetch_complex_split(RepositoryFormat2a)
+breezy.tests.per_repository_reference.test_get_record_stream.TestGetRecordStream.test_unordered_fetch_complex_split(RepositoryFormat2aSubtree)
+breezy.tests.per_repository_reference.test_get_record_stream.TestGetRecordStream.test_ordered_no_closure(RepositoryFormatKnitPack5)
+breezy.tests.per_repository_reference.test_get_record_stream.TestGetRecordStream.test_ordered_no_closure(RepositoryFormatKnitPack5RichRoot)
+breezy.tests.per_repository_reference.test_get_record_stream.TestGetRecordStream.test_ordered_no_closure(RepositoryFormatKnitPack5RichRootBroken)
+breezy.tests.per_repository_reference.test_get_record_stream.TestGetRecordStream.test_ordered_no_closure(RepositoryFormatKnitPack6)
+breezy.tests.per_repository_reference.test_get_record_stream.TestGetRecordStream.test_ordered_no_closure(RepositoryFormatKnitPack6RichRoot)
+breezy.tests.per_repository_reference.test_get_record_stream.TestGetRecordStream.test_ordered_no_closure(RepositoryFormatPackDevelopment2Subtree)
 breezy.tests.per_repository_reference.test_get_record_stream.TestGetRecordStream.test_unordered_fetch_complex_split(RepositoryFormatKnitPack5)
 breezy.tests.per_repository_reference.test_get_record_stream.TestGetRecordStream.test_unordered_fetch_complex_split(RepositoryFormatKnitPack5RichRoot)
 breezy.tests.per_repository_reference.test_get_record_stream.TestGetRecordStream.test_unordered_fetch_complex_split(RepositoryFormatKnitPack5RichRootBroken)
@@ -12129,6 +12150,21 @@
 breezy.tests.per_repository.test_repository.TestRepository.test_commit_unicode_control_characters(RepositoryFormat2a)
 breezy.tests.per_repository.test_repository.TestRepository.test_commit_unicode_control_characters(RepositoryFormat2aSubtree)
 breezy.tests.per_repository.test_repository.TestRepository.test_commit_unicode_control_characters(RepositoryFormat4)
+breezy.tests.per_repository.test_repository.TestRepository.test_commit_unicode_control_characters(RepositoryFormat5)
+breezy.tests.per_repository.test_repository.TestRepository.test_commit_unicode_control_characters(RepositoryFormat6)
+breezy.tests.per_repository.test_repository.TestRepository.test_commit_unicode_control_characters(RepositoryFormat7)
+breezy.tests.per_repository.test_repository.TestRepository.test_commit_unicode_control_characters(RepositoryFormatKnit1)
+breezy.tests.per_repository.test_repository.TestRepository.test_commit_unicode_control_characters(RepositoryFormatKnit3)
+breezy.tests.per_repository.test_repository.TestRepository.test_commit_unicode_control_characters(RepositoryFormatKnit4)
+breezy.tests.per_repository.test_repository.TestRepository.test_commit_unicode_control_characters(RepositoryFormatKnitPack1)
+breezy.tests.per_repository.test_repository.TestRepository.test_commit_unicode_control_characters(RepositoryFormatKnitPack3)
+breezy.tests.per_repository.test_repository.TestRepository.test_commit_unicode_control_characters(RepositoryFormatKnitPack4)
+breezy.tests.per_repository.test_repository.TestRepository.test_commit_unicode_control_characters(RepositoryFormatKnitPack5)
+breezy.tests.per_repository.test_repository.TestRepository.test_commit_unicode_control_characters(RepositoryFormatKnitPack5RichRoot)
+breezy.tests.per_repository.test_repository.TestRepository.test_commit_unicode_control_characters(RepositoryFormatKnitPack5RichRootBroken)
+breezy.tests.per_repository.test_repository.TestRepository.test_commit_unicode_control_characters(RepositoryFormatKnitPack6)
+breezy.tests.per_repository.test_repository.TestRepository.test_commit_unicode_control_characters(RepositoryFormatKnitPack6RichRoot)
+breezy.tests.per_repository.test_repository.TestRepository.test_commit_unicode_control_characters(RepositoryFormatPackDevelopment2Subtree)
 breezy.tests.per_repository.test_repository.TestRepository.test_commit_unicode_message(GitRepositoryFormat)
 breezy.tests.per_repository.test_repository.TestRepository.test_commit_unicode_message(RemoteRepositoryFormat-default)
 breezy.tests.per_repository.test_repository.TestRepository.test_commit_unicode_message(RemoteRepositoryFormat-v2)
@@ -12991,6 +13027,7 @@
 breezy.tests.per_repository.test_signatures.TestSignatures.test_sign_existing_revision(RepositoryFormatKnitPack6RichRoot)
 breezy.tests.per_repository.test_signatures.TestSignatures.test_sign_existing_revision(RepositoryFormatPackDevelopment2Subtree)
 breezy.tests.per_repository.test_signatures.TestSignatures.test_store_signature(GitRepositoryFormat)
+breezy.tests.per_repository.test_signatures.TestSignatures.test_store_signature(RemoteRepositoryFormat-default)
 breezy.tests.per_repository.test_signatures.TestSignatures.test_store_signature(RemoteRepositoryFormat-v2)
 breezy.tests.per_repository.test_signatures.TestSignatures.test_store_signature(RepositoryFormat2a)
 breezy.tests.per_repository.test_signatures.TestSignatures.test_store_signature(RepositoryFormat2aSubtree)
@@ -15608,7 +15645,6 @@
 breezy.tests.per_transport.TransportTests.test_abspath_at_root(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_abspath_at_root(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_abspath_at_root(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_abspath_at_root(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_abspath_at_root(HTTPS_transport,HTTPSServer)
 breezy.tests.per_transport.TransportTests.test_abspath_at_root(HttpTransport,HttpServer)
 breezy.tests.per_transport.TransportTests.test_abspath_at_root(LocalTransport,LocalURLServer)
@@ -15626,7 +15662,6 @@
 breezy.tests.per_transport.TransportTests.test_abspath(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_abspath(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_abspath(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_abspath(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_abspath(HTTPS_transport,HTTPSServer)
 breezy.tests.per_transport.TransportTests.test_abspath(HttpTransport,HttpServer)
 breezy.tests.per_transport.TransportTests.test_abspath(LocalTransport,LocalURLServer)
@@ -15644,7 +15679,6 @@
 breezy.tests.per_transport.TransportTests.test_abspath_url_unquote_unreserved(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_abspath_url_unquote_unreserved(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_abspath_url_unquote_unreserved(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_abspath_url_unquote_unreserved(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_abspath_url_unquote_unreserved(HTTPS_transport,HTTPSServer)
 breezy.tests.per_transport.TransportTests.test_abspath_url_unquote_unreserved(HttpTransport,HttpServer)
 breezy.tests.per_transport.TransportTests.test_abspath_url_unquote_unreserved(LocalTransport,LocalURLServer)
@@ -15662,7 +15696,6 @@
 breezy.tests.per_transport.TransportTests.test_append_bytes(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_append_bytes(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_append_bytes(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_append_bytes(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_append_bytes(HTTPS_transport,HTTPSServer)
 breezy.tests.per_transport.TransportTests.test_append_bytes(HttpTransport,HttpServer)
 breezy.tests.per_transport.TransportTests.test_append_bytes(LocalTransport,LocalURLServer)
@@ -15670,7 +15703,6 @@
 breezy.tests.per_transport.TransportTests.test_append_bytes_mode(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_append_bytes_mode(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_append_bytes_mode(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_append_bytes_mode(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_append_bytes_mode(HTTPS_transport,HTTPSServer)
 breezy.tests.per_transport.TransportTests.test_append_bytes_mode(HttpTransport,HttpServer)
 breezy.tests.per_transport.TransportTests.test_append_bytes_mode(LocalTransport,LocalURLServer)
@@ -15698,21 +15730,15 @@
 breezy.tests.per_transport.TransportTests.test_append_file(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_append_file(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_append_file(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_append_file(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_append_file(HTTPS_transport,HTTPSServer)
-breezy.tests.per_transport.TransportTests.test_append_file(HTTPS_urllib_transport,HTTPSServer_urllib)
 breezy.tests.per_transport.TransportTests.test_append_file(HttpTransport,HttpServer)
-breezy.tests.per_transport.TransportTests.test_append_file(HttpTransport_urllib,HttpServer_urllib)
 breezy.tests.per_transport.TransportTests.test_append_file(LocalTransport,LocalURLServer)
 breezy.tests.per_transport.TransportTests.test_append_file(MemoryTransport,MemoryServer)
 breezy.tests.per_transport.TransportTests.test_append_file_mode(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_append_file_mode(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_append_file_mode(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_append_file_mode(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_append_file_mode(HTTPS_transport,HTTPSServer)
-breezy.tests.per_transport.TransportTests.test_append_file_mode(HTTPS_urllib_transport,HTTPSServer_urllib)
 breezy.tests.per_transport.TransportTests.test_append_file_mode(HttpTransport,HttpServer)
-breezy.tests.per_transport.TransportTests.test_append_file_mode(HttpTransport_urllib,HttpServer_urllib)
 breezy.tests.per_transport.TransportTests.test_append_file_mode(LocalTransport,LocalURLServer)
 breezy.tests.per_transport.TransportTests.test_append_file_mode(MemoryTransport,MemoryServer)
 breezy.tests.per_transport.TransportTests.test_append_file_mode(NoSmartTransportDecorator,NoSmartTransportServer)
@@ -15735,18 +15761,11 @@
 breezy.tests.per_transport.TransportTests.test_append_file(TransportLogDecorator,LogDecoratorServer)
 breezy.tests.per_transport.TransportTests.test_append_file(TransportTraceDecorator,TraceServer)
 breezy.tests.per_transport.TransportTests.test_append_file(UnlistableTransportDecorator,UnlistableServer)
-breezy.tests.per_transport.TransportTests.test_append_multi(FtpTransport,UnavailableFTPTestServer)
-breezy.tests.per_transport.TransportTests.test_append_multi(HTTPS_urllib_transport,HTTPSServer_urllib)
-breezy.tests.per_transport.TransportTests.test_append_multi(HttpTransport_urllib,HttpServer_urllib)
-breezy.tests.per_transport.TransportTests.test_append_multi(ReadonlyTransportDecorator,ReadonlyServer)
 breezy.tests.per_transport.TransportTests.test_base_url(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_base_url(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_base_url(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_base_url(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_base_url(HTTPS_transport,HTTPSServer)
-breezy.tests.per_transport.TransportTests.test_base_url(HTTPS_urllib_transport,HTTPSServer_urllib)
 breezy.tests.per_transport.TransportTests.test_base_url(HttpTransport,HttpServer)
-breezy.tests.per_transport.TransportTests.test_base_url(HttpTransport_urllib,HttpServer_urllib)
 breezy.tests.per_transport.TransportTests.test_base_url(LocalTransport,LocalURLServer)
 breezy.tests.per_transport.TransportTests.test_base_url(MemoryTransport,MemoryServer)
 breezy.tests.per_transport.TransportTests.test_base_url(NoSmartTransportDecorator,NoSmartTransportServer)
@@ -15765,7 +15784,6 @@
 breezy.tests.per_transport.TransportTests.test_clone_from_root(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_clone_from_root(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_clone_from_root(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_clone_from_root(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_clone_from_root(HTTPS_transport,HTTPSServer)
 breezy.tests.per_transport.TransportTests.test_clone_from_root(HttpTransport,HttpServer)
 breezy.tests.per_transport.TransportTests.test_clone_from_root(LocalTransport,LocalURLServer)
@@ -15780,7 +15798,6 @@
 breezy.tests.per_transport.TransportTests.test_clone_from_root(TransportLogDecorator,LogDecoratorServer)
 breezy.tests.per_transport.TransportTests.test_clone_from_root(TransportTraceDecorator,TraceServer)
 breezy.tests.per_transport.TransportTests.test_clone_from_root(UnlistableTransportDecorator,UnlistableServer)
-breezy.tests.per_transport.TransportTests.test_clone(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_clone(HTTPS_transport,HTTPSServer)
 breezy.tests.per_transport.TransportTests.test_clone(HttpTransport,HttpServer)
 breezy.tests.per_transport.TransportTests.test_clone(LocalTransport,LocalURLServer)
@@ -15790,7 +15807,6 @@
 breezy.tests.per_transport.TransportTests.test_clone_preserve_info(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_clone_preserve_info(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_clone_preserve_info(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_clone_preserve_info(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_clone_preserve_info(HTTPS_transport,HTTPSServer)
 breezy.tests.per_transport.TransportTests.test_clone_preserve_info(HttpTransport,HttpServer)
 breezy.tests.per_transport.TransportTests.test_clone_preserve_info(LocalTransport,LocalURLServer)
@@ -15813,7 +15829,6 @@
 breezy.tests.per_transport.TransportTests.test_clone_to_root(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_clone_to_root(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_clone_to_root(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_clone_to_root(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_clone_to_root(HTTPS_transport,HTTPSServer)
 breezy.tests.per_transport.TransportTests.test_clone_to_root(HttpTransport,HttpServer)
 breezy.tests.per_transport.TransportTests.test_clone_to_root(LocalTransport,LocalURLServer)
@@ -15834,7 +15849,6 @@
 breezy.tests.per_transport.TransportTests.test_clone_url_unquote_unreserved(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_clone_url_unquote_unreserved(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_clone_url_unquote_unreserved(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_clone_url_unquote_unreserved(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_clone_url_unquote_unreserved(HTTPS_transport,HTTPSServer)
 breezy.tests.per_transport.TransportTests.test_clone_url_unquote_unreserved(HttpTransport,HttpServer)
 breezy.tests.per_transport.TransportTests.test_clone_url_unquote_unreserved(LocalTransport,LocalURLServer)
@@ -15852,7 +15866,6 @@
 breezy.tests.per_transport.TransportTests.test_connection_error(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_connection_error(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_connection_error(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_connection_error(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_connection_error(LocalTransport,LocalURLServer)
 breezy.tests.per_transport.TransportTests.test_connection_error(MemoryTransport,MemoryServer)
 breezy.tests.per_transport.TransportTests.test_connection_error(NoSmartTransportDecorator,NoSmartTransportServer)
@@ -15868,7 +15881,6 @@
 breezy.tests.per_transport.TransportTests.test_connection_sharing(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_connection_sharing(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_connection_sharing(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_connection_sharing(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_connection_sharing(HTTPS_transport,HTTPSServer)
 breezy.tests.per_transport.TransportTests.test_connection_sharing(HttpTransport,HttpServer)
 breezy.tests.per_transport.TransportTests.test_connection_sharing(LocalTransport,LocalURLServer)
@@ -15886,11 +15898,8 @@
 breezy.tests.per_transport.TransportTests.test_connect_twice_is_same_content(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_connect_twice_is_same_content(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_connect_twice_is_same_content(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_connect_twice_is_same_content(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_connect_twice_is_same_content(HTTPS_transport,HTTPSServer)
-breezy.tests.per_transport.TransportTests.test_connect_twice_is_same_content(HTTPS_urllib_transport,HTTPSServer_urllib)
 breezy.tests.per_transport.TransportTests.test_connect_twice_is_same_content(HttpTransport,HttpServer)
-breezy.tests.per_transport.TransportTests.test_connect_twice_is_same_content(HttpTransport_urllib,HttpServer_urllib)
 breezy.tests.per_transport.TransportTests.test_connect_twice_is_same_content(LocalTransport,LocalURLServer)
 breezy.tests.per_transport.TransportTests.test_connect_twice_is_same_content(MemoryTransport,MemoryServer)
 breezy.tests.per_transport.TransportTests.test_connect_twice_is_same_content(NoSmartTransportDecorator,NoSmartTransportServer)
@@ -15906,11 +15915,8 @@
 breezy.tests.per_transport.TransportTests.test_copy(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_copy(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_copy(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_copy(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_copy(HTTPS_transport,HTTPSServer)
-breezy.tests.per_transport.TransportTests.test_copy(HTTPS_urllib_transport,HTTPSServer_urllib)
 breezy.tests.per_transport.TransportTests.test_copy(HttpTransport,HttpServer)
-breezy.tests.per_transport.TransportTests.test_copy(HttpTransport_urllib,HttpServer_urllib)
 breezy.tests.per_transport.TransportTests.test_copy(LocalTransport,LocalURLServer)
 breezy.tests.per_transport.TransportTests.test_copy(MemoryTransport,MemoryServer)
 breezy.tests.per_transport.TransportTests.test_copy(NoSmartTransportDecorator,NoSmartTransportServer)
@@ -15923,7 +15929,6 @@
 breezy.tests.per_transport.TransportTests.test_copy_to(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_copy_to(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_copy_to(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_copy_to(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_copy_to(HTTPS_transport,HTTPSServer)
 breezy.tests.per_transport.TransportTests.test_copy_to(HttpTransport,HttpServer)
 breezy.tests.per_transport.TransportTests.test_copy_to(LocalTransport,LocalURLServer)
@@ -15943,11 +15948,8 @@
 breezy.tests.per_transport.TransportTests.test_copy_tree(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_copy_tree(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_copy_tree(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_copy_tree(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_copy_tree(HTTPS_transport,HTTPSServer)
-breezy.tests.per_transport.TransportTests.test_copy_tree(HTTPS_urllib_transport,HTTPSServer_urllib)
 breezy.tests.per_transport.TransportTests.test_copy_tree(HttpTransport,HttpServer)
-breezy.tests.per_transport.TransportTests.test_copy_tree(HttpTransport_urllib,HttpServer_urllib)
 breezy.tests.per_transport.TransportTests.test_copy_tree(LocalTransport,LocalURLServer)
 breezy.tests.per_transport.TransportTests.test_copy_tree(MemoryTransport,MemoryServer)
 breezy.tests.per_transport.TransportTests.test_copy_tree(NoSmartTransportDecorator,NoSmartTransportServer)
@@ -15960,11 +15962,8 @@
 breezy.tests.per_transport.TransportTests.test_copy_tree_to_transport(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_copy_tree_to_transport(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_copy_tree_to_transport(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_copy_tree_to_transport(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_copy_tree_to_transport(HTTPS_transport,HTTPSServer)
-breezy.tests.per_transport.TransportTests.test_copy_tree_to_transport(HTTPS_urllib_transport,HTTPSServer_urllib)
 breezy.tests.per_transport.TransportTests.test_copy_tree_to_transport(HttpTransport,HttpServer)
-breezy.tests.per_transport.TransportTests.test_copy_tree_to_transport(HttpTransport_urllib,HttpServer_urllib)
 breezy.tests.per_transport.TransportTests.test_copy_tree_to_transport(LocalTransport,LocalURLServer)
 breezy.tests.per_transport.TransportTests.test_copy_tree_to_transport(MemoryTransport,MemoryServer)
 breezy.tests.per_transport.TransportTests.test_copy_tree_to_transport(NoSmartTransportDecorator,NoSmartTransportServer)
@@ -15984,7 +15983,6 @@
 breezy.tests.per_transport.TransportTests.test_create_prefix(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_create_prefix(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_create_prefix(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_create_prefix(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_create_prefix(HTTPS_transport,HTTPSServer)
 breezy.tests.per_transport.TransportTests.test_create_prefix(HttpTransport,HttpServer)
 breezy.tests.per_transport.TransportTests.test_create_prefix(LocalTransport,LocalURLServer)
@@ -16002,11 +16000,8 @@
 breezy.tests.per_transport.TransportTests.test_delete(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_delete(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_delete(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_delete(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_delete(HTTPS_transport,HTTPSServer)
-breezy.tests.per_transport.TransportTests.test_delete(HTTPS_urllib_transport,HTTPSServer_urllib)
 breezy.tests.per_transport.TransportTests.test_delete(HttpTransport,HttpServer)
-breezy.tests.per_transport.TransportTests.test_delete(HttpTransport_urllib,HttpServer_urllib)
 breezy.tests.per_transport.TransportTests.test_delete(LocalTransport,LocalURLServer)
 breezy.tests.per_transport.TransportTests.test_delete(MemoryTransport,MemoryServer)
 breezy.tests.per_transport.TransportTests.test_delete(NoSmartTransportDecorator,NoSmartTransportServer)
@@ -16021,7 +16016,6 @@
 breezy.tests.per_transport.TransportTests.test_delete_tree(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_delete_tree(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_delete_tree(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_delete_tree(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_delete_tree(HTTPS_transport,HTTPSServer)
 breezy.tests.per_transport.TransportTests.test_delete_tree(HttpTransport,HttpServer)
 breezy.tests.per_transport.TransportTests.test_delete_tree(LocalTransport,LocalURLServer)
@@ -16040,11 +16034,8 @@
 breezy.tests.per_transport.TransportTests.test_ensure_base_exists(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_ensure_base_exists(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_ensure_base_exists(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_ensure_base_exists(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_ensure_base_exists(HTTPS_transport,HTTPSServer)
-breezy.tests.per_transport.TransportTests.test_ensure_base_exists(HTTPS_urllib_transport,HTTPSServer_urllib)
 breezy.tests.per_transport.TransportTests.test_ensure_base_exists(HttpTransport,HttpServer)
-breezy.tests.per_transport.TransportTests.test_ensure_base_exists(HttpTransport_urllib,HttpServer_urllib)
 breezy.tests.per_transport.TransportTests.test_ensure_base_exists(LocalTransport,LocalURLServer)
 breezy.tests.per_transport.TransportTests.test_ensure_base_exists(MemoryTransport,MemoryServer)
 breezy.tests.per_transport.TransportTests.test_ensure_base_exists(NoSmartTransportDecorator,NoSmartTransportServer)
@@ -16060,7 +16051,6 @@
 breezy.tests.per_transport.TransportTests.test_ensure_base_missing(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_ensure_base_missing(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_ensure_base_missing(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_ensure_base_missing(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_ensure_base_missing(HTTPS_transport,HTTPSServer)
 breezy.tests.per_transport.TransportTests.test_ensure_base_missing(HttpTransport,HttpServer)
 breezy.tests.per_transport.TransportTests.test_ensure_base_missing(LocalTransport,LocalURLServer)
@@ -16069,11 +16059,8 @@
 breezy.tests.per_transport.TransportTests.test_ensure_base_missing_parent(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_ensure_base_missing_parent(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_ensure_base_missing_parent(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_ensure_base_missing_parent(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_ensure_base_missing_parent(HTTPS_transport,HTTPSServer)
-breezy.tests.per_transport.TransportTests.test_ensure_base_missing_parent(HTTPS_urllib_transport,HTTPSServer_urllib)
 breezy.tests.per_transport.TransportTests.test_ensure_base_missing_parent(HttpTransport,HttpServer)
-breezy.tests.per_transport.TransportTests.test_ensure_base_missing_parent(HttpTransport_urllib,HttpServer_urllib)
 breezy.tests.per_transport.TransportTests.test_ensure_base_missing_parent(LocalTransport,LocalURLServer)
 breezy.tests.per_transport.TransportTests.test_ensure_base_missing_parent(MemoryTransport,MemoryServer)
 breezy.tests.per_transport.TransportTests.test_ensure_base_missing_parent(NoSmartTransportDecorator,NoSmartTransportServer)
@@ -16098,11 +16085,8 @@
 breezy.tests.per_transport.TransportTests.test_external_url(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_external_url(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_external_url(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_external_url(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_external_url(HTTPS_transport,HTTPSServer)
-breezy.tests.per_transport.TransportTests.test_external_url(HTTPS_urllib_transport,HTTPSServer_urllib)
 breezy.tests.per_transport.TransportTests.test_external_url(HttpTransport,HttpServer)
-breezy.tests.per_transport.TransportTests.test_external_url(HttpTransport_urllib,HttpServer_urllib)
 breezy.tests.per_transport.TransportTests.test_external_url(LocalTransport,LocalURLServer)
 breezy.tests.per_transport.TransportTests.test_external_url(MemoryTransport,MemoryServer)
 breezy.tests.per_transport.TransportTests.test_external_url(NoSmartTransportDecorator,NoSmartTransportServer)
@@ -16118,7 +16102,6 @@
 breezy.tests.per_transport.TransportTests.test_get_bytes(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_get_bytes(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_get_bytes(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_get_bytes(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_get_bytes(HTTPS_transport,HTTPSServer)
 breezy.tests.per_transport.TransportTests.test_get_bytes(HttpTransport,HttpServer)
 breezy.tests.per_transport.TransportTests.test_get_bytes(LocalTransport,LocalURLServer)
@@ -16135,7 +16118,6 @@
 breezy.tests.per_transport.TransportTests.test_get_bytes_unknown_file(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_get_bytes_unknown_file(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_get_bytes_unknown_file(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_get_bytes_unknown_file(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_get_bytes_unknown_file(HTTPS_transport,HTTPSServer)
 breezy.tests.per_transport.TransportTests.test_get_bytes_unknown_file(HttpTransport,HttpServer)
 breezy.tests.per_transport.TransportTests.test_get_bytes_unknown_file(LocalTransport,LocalURLServer)
@@ -16154,11 +16136,8 @@
 breezy.tests.per_transport.TransportTests.test_get_bytes_with_open_write_stream_sees_all_content(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_get_bytes_with_open_write_stream_sees_all_content(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_get_bytes_with_open_write_stream_sees_all_content(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_get_bytes_with_open_write_stream_sees_all_content(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_get_bytes_with_open_write_stream_sees_all_content(HTTPS_transport,HTTPSServer)
-breezy.tests.per_transport.TransportTests.test_get_bytes_with_open_write_stream_sees_all_content(HTTPS_urllib_transport,HTTPSServer_urllib)
 breezy.tests.per_transport.TransportTests.test_get_bytes_with_open_write_stream_sees_all_content(HttpTransport,HttpServer)
-breezy.tests.per_transport.TransportTests.test_get_bytes_with_open_write_stream_sees_all_content(HttpTransport_urllib,HttpServer_urllib)
 breezy.tests.per_transport.TransportTests.test_get_bytes_with_open_write_stream_sees_all_content(LocalTransport,LocalURLServer)
 breezy.tests.per_transport.TransportTests.test_get_bytes_with_open_write_stream_sees_all_content(MemoryTransport,MemoryServer)
 breezy.tests.per_transport.TransportTests.test_get_bytes_with_open_write_stream_sees_all_content(NoSmartTransportDecorator,NoSmartTransportServer)
@@ -16175,11 +16154,8 @@
 breezy.tests.per_transport.TransportTests.test_get_directory_read_gives_ReadError(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_get_directory_read_gives_ReadError(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_get_directory_read_gives_ReadError(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_get_directory_read_gives_ReadError(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_get_directory_read_gives_ReadError(HTTPS_transport,HTTPSServer)
-breezy.tests.per_transport.TransportTests.test_get_directory_read_gives_ReadError(HTTPS_urllib_transport,HTTPSServer_urllib)
 breezy.tests.per_transport.TransportTests.test_get_directory_read_gives_ReadError(HttpTransport,HttpServer)
-breezy.tests.per_transport.TransportTests.test_get_directory_read_gives_ReadError(HttpTransport_urllib,HttpServer_urllib)
 breezy.tests.per_transport.TransportTests.test_get_directory_read_gives_ReadError(LocalTransport,LocalURLServer)
 breezy.tests.per_transport.TransportTests.test_get_directory_read_gives_ReadError(MemoryTransport,MemoryServer)
 breezy.tests.per_transport.TransportTests.test_get_directory_read_gives_ReadError(NoSmartTransportDecorator,NoSmartTransportServer)
@@ -16194,7 +16170,6 @@
 breezy.tests.per_transport.TransportTests.test_get_directory_read_gives_ReadError(UnlistableTransportDecorator,UnlistableServer)
 breezy.tests.per_transport.TransportTests.test_get(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_get(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_get(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_get(HTTPS_transport,HTTPSServer)
 breezy.tests.per_transport.TransportTests.test_get(HttpTransport,HttpServer)
 breezy.tests.per_transport.TransportTests.test_get(LocalTransport,LocalURLServer)
@@ -16209,11 +16184,8 @@
 breezy.tests.per_transport.TransportTests.test_get_smart_medium(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_get_smart_medium(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_get_smart_medium(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_get_smart_medium(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_get_smart_medium(HTTPS_transport,HTTPSServer)
-breezy.tests.per_transport.TransportTests.test_get_smart_medium(HTTPS_urllib_transport,HTTPSServer_urllib)
 breezy.tests.per_transport.TransportTests.test_get_smart_medium(HttpTransport,HttpServer)
-breezy.tests.per_transport.TransportTests.test_get_smart_medium(HttpTransport_urllib,HttpServer_urllib)
 breezy.tests.per_transport.TransportTests.test_get_smart_medium(LocalTransport,LocalURLServer)
 breezy.tests.per_transport.TransportTests.test_get_smart_medium(MemoryTransport,MemoryServer)
 breezy.tests.per_transport.TransportTests.test_get_smart_medium(NoSmartTransportDecorator,NoSmartTransportServer)
@@ -16231,7 +16203,6 @@
 breezy.tests.per_transport.TransportTests.test_get_unknown_file(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_get_unknown_file(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_get_unknown_file(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_get_unknown_file(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_get_unknown_file(HTTPS_transport,HTTPSServer)
 breezy.tests.per_transport.TransportTests.test_get_unknown_file(HttpTransport,HttpServer)
 breezy.tests.per_transport.TransportTests.test_get_unknown_file(LocalTransport,LocalURLServer)
@@ -16250,11 +16221,8 @@
 breezy.tests.per_transport.TransportTests.test_get_with_open_write_stream_sees_all_content(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_get_with_open_write_stream_sees_all_content(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_get_with_open_write_stream_sees_all_content(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_get_with_open_write_stream_sees_all_content(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_get_with_open_write_stream_sees_all_content(HTTPS_transport,HTTPSServer)
-breezy.tests.per_transport.TransportTests.test_get_with_open_write_stream_sees_all_content(HTTPS_urllib_transport,HTTPSServer_urllib)
 breezy.tests.per_transport.TransportTests.test_get_with_open_write_stream_sees_all_content(HttpTransport,HttpServer)
-breezy.tests.per_transport.TransportTests.test_get_with_open_write_stream_sees_all_content(HttpTransport_urllib,HttpServer_urllib)
 breezy.tests.per_transport.TransportTests.test_get_with_open_write_stream_sees_all_content(LocalTransport,LocalURLServer)
 breezy.tests.per_transport.TransportTests.test_get_with_open_write_stream_sees_all_content(MemoryTransport,MemoryServer)
 breezy.tests.per_transport.TransportTests.test_get_with_open_write_stream_sees_all_content(NoSmartTransportDecorator,NoSmartTransportServer)
@@ -16270,11 +16238,8 @@
 breezy.tests.per_transport.TransportTests.test_hardlink(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_hardlink(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_hardlink(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_hardlink(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_hardlink(HTTPS_transport,HTTPSServer)
-breezy.tests.per_transport.TransportTests.test_hardlink(HTTPS_urllib_transport,HTTPSServer_urllib)
 breezy.tests.per_transport.TransportTests.test_hardlink(HttpTransport,HttpServer)
-breezy.tests.per_transport.TransportTests.test_hardlink(HttpTransport_urllib,HttpServer_urllib)
 breezy.tests.per_transport.TransportTests.test_hardlink(LocalTransport,LocalURLServer)
 breezy.tests.per_transport.TransportTests.test_hardlink(MemoryTransport,MemoryServer)
 breezy.tests.per_transport.TransportTests.test_hardlink(NoSmartTransportDecorator,NoSmartTransportServer)
@@ -16290,7 +16255,6 @@
 breezy.tests.per_transport.TransportTests.test_has(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_has(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_has(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_has(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_has(HTTPS_transport,HTTPSServer)
 breezy.tests.per_transport.TransportTests.test_has(HttpTransport,HttpServer)
 breezy.tests.per_transport.TransportTests.test_has(LocalTransport,LocalURLServer)
@@ -16302,7 +16266,6 @@
 breezy.tests.per_transport.TransportTests.test_has_root_works(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_has_root_works(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_has_root_works(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_has_root_works(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_has_root_works(HTTPS_transport,HTTPSServer)
 breezy.tests.per_transport.TransportTests.test_has_root_works(HttpTransport,HttpServer)
 breezy.tests.per_transport.TransportTests.test_has_root_works(LocalTransport,LocalURLServer)
@@ -16326,7 +16289,6 @@
 breezy.tests.per_transport.TransportTests.test_hook_post_connection_multi(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_hook_post_connection_multi(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_hook_post_connection_multi(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_hook_post_connection_multi(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_hook_post_connection_multi(HTTPS_transport,HTTPSServer)
 breezy.tests.per_transport.TransportTests.test_hook_post_connection_multi(HttpTransport,HttpServer)
 breezy.tests.per_transport.TransportTests.test_hook_post_connection_multi(LocalTransport,LocalURLServer)
@@ -16344,7 +16306,6 @@
 breezy.tests.per_transport.TransportTests.test_hook_post_connection_one(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_hook_post_connection_one(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_hook_post_connection_one(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_hook_post_connection_one(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_hook_post_connection_one(HTTPS_transport,HTTPSServer)
 breezy.tests.per_transport.TransportTests.test_hook_post_connection_one(HttpTransport,HttpServer)
 breezy.tests.per_transport.TransportTests.test_hook_post_connection_one(LocalTransport,LocalURLServer)
@@ -16362,11 +16323,8 @@
 breezy.tests.per_transport.TransportTests.test_iter_files_recursive(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_iter_files_recursive(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_iter_files_recursive(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_iter_files_recursive(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_iter_files_recursive(HTTPS_transport,HTTPSServer)
-breezy.tests.per_transport.TransportTests.test_iter_files_recursive(HTTPS_urllib_transport,HTTPSServer_urllib)
 breezy.tests.per_transport.TransportTests.test_iter_files_recursive(HttpTransport,HttpServer)
-breezy.tests.per_transport.TransportTests.test_iter_files_recursive(HttpTransport_urllib,HttpServer_urllib)
 breezy.tests.per_transport.TransportTests.test_iter_files_recursive(LocalTransport,LocalURLServer)
 breezy.tests.per_transport.TransportTests.test_iter_files_recursive(MemoryTransport,MemoryServer)
 breezy.tests.per_transport.TransportTests.test_iter_files_recursive(NoSmartTransportDecorator,NoSmartTransportServer)
@@ -16382,11 +16340,8 @@
 breezy.tests.per_transport.TransportTests.test_list_dir(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_list_dir(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_list_dir(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_list_dir(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_list_dir(HTTPS_transport,HTTPSServer)
-breezy.tests.per_transport.TransportTests.test_list_dir(HTTPS_urllib_transport,HTTPSServer_urllib)
 breezy.tests.per_transport.TransportTests.test_list_dir(HttpTransport,HttpServer)
-breezy.tests.per_transport.TransportTests.test_list_dir(HttpTransport_urllib,HttpServer_urllib)
 breezy.tests.per_transport.TransportTests.test_list_dir(LocalTransport,LocalURLServer)
 breezy.tests.per_transport.TransportTests.test_list_dir(MemoryTransport,MemoryServer)
 breezy.tests.per_transport.TransportTests.test_list_dir(NoSmartTransportDecorator,NoSmartTransportServer)
@@ -16396,11 +16351,8 @@
 breezy.tests.per_transport.TransportTests.test_list_dir_result_is_url_escaped(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_list_dir_result_is_url_escaped(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_list_dir_result_is_url_escaped(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_list_dir_result_is_url_escaped(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_list_dir_result_is_url_escaped(HTTPS_transport,HTTPSServer)
-breezy.tests.per_transport.TransportTests.test_list_dir_result_is_url_escaped(HTTPS_urllib_transport,HTTPSServer_urllib)
 breezy.tests.per_transport.TransportTests.test_list_dir_result_is_url_escaped(HttpTransport,HttpServer)
-breezy.tests.per_transport.TransportTests.test_list_dir_result_is_url_escaped(HttpTransport_urllib,HttpServer_urllib)
 breezy.tests.per_transport.TransportTests.test_list_dir_result_is_url_escaped(LocalTransport,LocalURLServer)
 breezy.tests.per_transport.TransportTests.test_list_dir_result_is_url_escaped(MemoryTransport,MemoryServer)
 breezy.tests.per_transport.TransportTests.test_list_dir_result_is_url_escaped(NoSmartTransportDecorator,NoSmartTransportServer)
@@ -16422,7 +16374,6 @@
 breezy.tests.per_transport.TransportTests.test_local_abspath(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_local_abspath(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_local_abspath(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_local_abspath(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_local_abspath(HTTPS_transport,HTTPSServer)
 breezy.tests.per_transport.TransportTests.test_local_abspath(HttpTransport,HttpServer)
 breezy.tests.per_transport.TransportTests.test_local_abspath(LocalTransport,LocalURLServer)
@@ -16440,7 +16391,6 @@
 breezy.tests.per_transport.TransportTests.test_lock_read(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_lock_read(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_lock_read(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_lock_read(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_lock_read(HTTPS_transport,HTTPSServer)
 breezy.tests.per_transport.TransportTests.test_lock_read(HttpTransport,HttpServer)
 breezy.tests.per_transport.TransportTests.test_lock_read(LocalTransport,LocalURLServer)
@@ -16458,11 +16408,8 @@
 breezy.tests.per_transport.TransportTests.test_lock_write(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_lock_write(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_lock_write(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_lock_write(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_lock_write(HTTPS_transport,HTTPSServer)
-breezy.tests.per_transport.TransportTests.test_lock_write(HTTPS_urllib_transport,HTTPSServer_urllib)
 breezy.tests.per_transport.TransportTests.test_lock_write(HttpTransport,HttpServer)
-breezy.tests.per_transport.TransportTests.test_lock_write(HttpTransport_urllib,HttpServer_urllib)
 breezy.tests.per_transport.TransportTests.test_lock_write(LocalTransport,LocalURLServer)
 breezy.tests.per_transport.TransportTests.test_lock_write(MemoryTransport,MemoryServer)
 breezy.tests.per_transport.TransportTests.test_lock_write(NoSmartTransportDecorator,NoSmartTransportServer)
@@ -16478,11 +16425,8 @@
 breezy.tests.per_transport.TransportTests.test_mkdir(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_mkdir(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_mkdir(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_mkdir(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_mkdir(HTTPS_transport,HTTPSServer)
-breezy.tests.per_transport.TransportTests.test_mkdir(HTTPS_urllib_transport,HTTPSServer_urllib)
 breezy.tests.per_transport.TransportTests.test_mkdir(HttpTransport,HttpServer)
-breezy.tests.per_transport.TransportTests.test_mkdir(HttpTransport_urllib,HttpServer_urllib)
 breezy.tests.per_transport.TransportTests.test_mkdir(LocalTransport,LocalURLServer)
 breezy.tests.per_transport.TransportTests.test_mkdir(MemoryTransport,MemoryServer)
 breezy.tests.per_transport.TransportTests.test_mkdir(NoSmartTransportDecorator,NoSmartTransportServer)
@@ -16490,11 +16434,8 @@
 breezy.tests.per_transport.TransportTests.test_mkdir_permissions(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_mkdir_permissions(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_mkdir_permissions(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_mkdir_permissions(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_mkdir_permissions(HTTPS_transport,HTTPSServer)
-breezy.tests.per_transport.TransportTests.test_mkdir_permissions(HTTPS_urllib_transport,HTTPSServer_urllib)
 breezy.tests.per_transport.TransportTests.test_mkdir_permissions(HttpTransport,HttpServer)
-breezy.tests.per_transport.TransportTests.test_mkdir_permissions(HttpTransport_urllib,HttpServer_urllib)
 breezy.tests.per_transport.TransportTests.test_mkdir_permissions(LocalTransport,LocalURLServer)
 breezy.tests.per_transport.TransportTests.test_mkdir_permissions(MemoryTransport,MemoryServer)
 breezy.tests.per_transport.TransportTests.test_mkdir_permissions(NoSmartTransportDecorator,NoSmartTransportServer)
@@ -16518,11 +16459,8 @@
 breezy.tests.per_transport.TransportTests.test_move(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_move(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_move(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_move(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_move(HTTPS_transport,HTTPSServer)
-breezy.tests.per_transport.TransportTests.test_move(HTTPS_urllib_transport,HTTPSServer_urllib)
 breezy.tests.per_transport.TransportTests.test_move(HttpTransport,HttpServer)
-breezy.tests.per_transport.TransportTests.test_move(HttpTransport_urllib,HttpServer_urllib)
 breezy.tests.per_transport.TransportTests.test_move(LocalTransport,LocalURLServer)
 breezy.tests.per_transport.TransportTests.test_move(MemoryTransport,MemoryServer)
 breezy.tests.per_transport.TransportTests.test_move(NoSmartTransportDecorator,NoSmartTransportServer)
@@ -16538,11 +16476,8 @@
 breezy.tests.per_transport.TransportTests.test_no_segment_parameters(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_no_segment_parameters(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_no_segment_parameters(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_no_segment_parameters(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_no_segment_parameters(HTTPS_transport,HTTPSServer)
-breezy.tests.per_transport.TransportTests.test_no_segment_parameters(HTTPS_urllib_transport,HTTPSServer_urllib)
 breezy.tests.per_transport.TransportTests.test_no_segment_parameters(HttpTransport,HttpServer)
-breezy.tests.per_transport.TransportTests.test_no_segment_parameters(HttpTransport_urllib,HttpServer_urllib)
 breezy.tests.per_transport.TransportTests.test_no_segment_parameters(LocalTransport,LocalURLServer)
 breezy.tests.per_transport.TransportTests.test_no_segment_parameters(MemoryTransport,MemoryServer)
 breezy.tests.per_transport.TransportTests.test_no_segment_parameters(NoSmartTransportDecorator,NoSmartTransportServer)
@@ -16558,11 +16493,8 @@
 breezy.tests.per_transport.TransportTests.test_opening_a_file_stream_can_set_mode(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_opening_a_file_stream_can_set_mode(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_opening_a_file_stream_can_set_mode(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_opening_a_file_stream_can_set_mode(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_opening_a_file_stream_can_set_mode(HTTPS_transport,HTTPSServer)
-breezy.tests.per_transport.TransportTests.test_opening_a_file_stream_can_set_mode(HTTPS_urllib_transport,HTTPSServer_urllib)
 breezy.tests.per_transport.TransportTests.test_opening_a_file_stream_can_set_mode(HttpTransport,HttpServer)
-breezy.tests.per_transport.TransportTests.test_opening_a_file_stream_can_set_mode(HttpTransport_urllib,HttpServer_urllib)
 breezy.tests.per_transport.TransportTests.test_opening_a_file_stream_can_set_mode(LocalTransport,LocalURLServer)
 breezy.tests.per_transport.TransportTests.test_opening_a_file_stream_can_set_mode(MemoryTransport,MemoryServer)
 breezy.tests.per_transport.TransportTests.test_opening_a_file_stream_can_set_mode(NoSmartTransportDecorator,NoSmartTransportServer)
@@ -16578,11 +16510,8 @@
 breezy.tests.per_transport.TransportTests.test_opening_a_file_stream_creates_file(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_opening_a_file_stream_creates_file(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_opening_a_file_stream_creates_file(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_opening_a_file_stream_creates_file(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_opening_a_file_stream_creates_file(HTTPS_transport,HTTPSServer)
-breezy.tests.per_transport.TransportTests.test_opening_a_file_stream_creates_file(HTTPS_urllib_transport,HTTPSServer_urllib)
 breezy.tests.per_transport.TransportTests.test_opening_a_file_stream_creates_file(HttpTransport,HttpServer)
-breezy.tests.per_transport.TransportTests.test_opening_a_file_stream_creates_file(HttpTransport_urllib,HttpServer_urllib)
 breezy.tests.per_transport.TransportTests.test_opening_a_file_stream_creates_file(LocalTransport,LocalURLServer)
 breezy.tests.per_transport.TransportTests.test_opening_a_file_stream_creates_file(MemoryTransport,MemoryServer)
 breezy.tests.per_transport.TransportTests.test_opening_a_file_stream_creates_file(NoSmartTransportDecorator,NoSmartTransportServer)
@@ -16598,17 +16527,13 @@
 breezy.tests.per_transport.TransportTests.test_put_bytes(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_put_bytes(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_put_bytes(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_put_bytes(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_put_bytes(HTTPS_transport,HTTPSServer)
-breezy.tests.per_transport.TransportTests.test_put_bytes(HTTPS_urllib_transport,HTTPSServer_urllib)
 breezy.tests.per_transport.TransportTests.test_put_bytes(HttpTransport,HttpServer)
-breezy.tests.per_transport.TransportTests.test_put_bytes(HttpTransport_urllib,HttpServer_urllib)
 breezy.tests.per_transport.TransportTests.test_put_bytes(LocalTransport,LocalURLServer)
 breezy.tests.per_transport.TransportTests.test_put_bytes(MemoryTransport,MemoryServer)
 breezy.tests.per_transport.TransportTests.test_put_bytes_non_atomic(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_put_bytes_non_atomic(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_put_bytes_non_atomic(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_put_bytes_non_atomic(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_put_bytes_non_atomic(HTTPS_transport,HTTPSServer)
 breezy.tests.per_transport.TransportTests.test_put_bytes_non_atomic(HttpTransport,HttpServer)
 breezy.tests.per_transport.TransportTests.test_put_bytes_non_atomic(LocalTransport,LocalURLServer)
@@ -16618,11 +16543,8 @@
 breezy.tests.per_transport.TransportTests.test_put_bytes_non_atomic_permissions(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_put_bytes_non_atomic_permissions(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_put_bytes_non_atomic_permissions(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_put_bytes_non_atomic_permissions(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_put_bytes_non_atomic_permissions(HTTPS_transport,HTTPSServer)
-breezy.tests.per_transport.TransportTests.test_put_bytes_non_atomic_permissions(HTTPS_urllib_transport,HTTPSServer_urllib)
 breezy.tests.per_transport.TransportTests.test_put_bytes_non_atomic_permissions(HttpTransport,HttpServer)
-breezy.tests.per_transport.TransportTests.test_put_bytes_non_atomic_permissions(HttpTransport_urllib,HttpServer_urllib)
 breezy.tests.per_transport.TransportTests.test_put_bytes_non_atomic_permissions(LocalTransport,LocalURLServer)
 breezy.tests.per_transport.TransportTests.test_put_bytes_non_atomic_permissions(MemoryTransport,MemoryServer)
 breezy.tests.per_transport.TransportTests.test_put_bytes_non_atomic_permissions(NoSmartTransportDecorator,NoSmartTransportServer)
@@ -16648,11 +16570,8 @@
 breezy.tests.per_transport.TransportTests.test_put_bytes_permissions(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_put_bytes_permissions(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_put_bytes_permissions(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_put_bytes_permissions(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_put_bytes_permissions(HTTPS_transport,HTTPSServer)
-breezy.tests.per_transport.TransportTests.test_put_bytes_permissions(HTTPS_urllib_transport,HTTPSServer_urllib)
 breezy.tests.per_transport.TransportTests.test_put_bytes_permissions(HttpTransport,HttpServer)
-breezy.tests.per_transport.TransportTests.test_put_bytes_permissions(HttpTransport_urllib,HttpServer_urllib)
 breezy.tests.per_transport.TransportTests.test_put_bytes_permissions(LocalTransport,LocalURLServer)
 breezy.tests.per_transport.TransportTests.test_put_bytes_permissions(MemoryTransport,MemoryServer)
 breezy.tests.per_transport.TransportTests.test_put_bytes_permissions(NoSmartTransportDecorator,NoSmartTransportServer)
@@ -16675,11 +16594,8 @@
 breezy.tests.per_transport.TransportTests.test_put_bytes_unicode(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_put_bytes_unicode(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_put_bytes_unicode(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_put_bytes_unicode(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_put_bytes_unicode(HTTPS_transport,HTTPSServer)
-breezy.tests.per_transport.TransportTests.test_put_bytes_unicode(HTTPS_urllib_transport,HTTPSServer_urllib)
 breezy.tests.per_transport.TransportTests.test_put_bytes_unicode(HttpTransport,HttpServer)
-breezy.tests.per_transport.TransportTests.test_put_bytes_unicode(HttpTransport_urllib,HttpServer_urllib)
 breezy.tests.per_transport.TransportTests.test_put_bytes_unicode(LocalTransport,LocalURLServer)
 breezy.tests.per_transport.TransportTests.test_put_bytes_unicode(MemoryTransport,MemoryServer)
 breezy.tests.per_transport.TransportTests.test_put_bytes_unicode(NoSmartTransportDecorator,NoSmartTransportServer)
@@ -16696,21 +16612,15 @@
 breezy.tests.per_transport.TransportTests.test_put_file(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_put_file(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_put_file(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_put_file(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_put_file(HTTPS_transport,HTTPSServer)
-breezy.tests.per_transport.TransportTests.test_put_file(HTTPS_urllib_transport,HTTPSServer_urllib)
 breezy.tests.per_transport.TransportTests.test_put_file(HttpTransport,HttpServer)
-breezy.tests.per_transport.TransportTests.test_put_file(HttpTransport_urllib,HttpServer_urllib)
 breezy.tests.per_transport.TransportTests.test_put_file(LocalTransport,LocalURLServer)
 breezy.tests.per_transport.TransportTests.test_put_file(MemoryTransport,MemoryServer)
 breezy.tests.per_transport.TransportTests.test_put_file_non_atomic(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_put_file_non_atomic(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_put_file_non_atomic(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_put_file_non_atomic(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_put_file_non_atomic(HTTPS_transport,HTTPSServer)
-breezy.tests.per_transport.TransportTests.test_put_file_non_atomic(HTTPS_urllib_transport,HTTPSServer_urllib)
 breezy.tests.per_transport.TransportTests.test_put_file_non_atomic(HttpTransport,HttpServer)
-breezy.tests.per_transport.TransportTests.test_put_file_non_atomic(HttpTransport_urllib,HttpServer_urllib)
 breezy.tests.per_transport.TransportTests.test_put_file_non_atomic(LocalTransport,LocalURLServer)
 breezy.tests.per_transport.TransportTests.test_put_file_non_atomic(MemoryTransport,MemoryServer)
 breezy.tests.per_transport.TransportTests.test_put_file_non_atomic(NoSmartTransportDecorator,NoSmartTransportServer)
@@ -16718,11 +16628,8 @@
 breezy.tests.per_transport.TransportTests.test_put_file_non_atomic_permissions(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_put_file_non_atomic_permissions(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_put_file_non_atomic_permissions(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_put_file_non_atomic_permissions(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_put_file_non_atomic_permissions(HTTPS_transport,HTTPSServer)
-breezy.tests.per_transport.TransportTests.test_put_file_non_atomic_permissions(HTTPS_urllib_transport,HTTPSServer_urllib)
 breezy.tests.per_transport.TransportTests.test_put_file_non_atomic_permissions(HttpTransport,HttpServer)
-breezy.tests.per_transport.TransportTests.test_put_file_non_atomic_permissions(HttpTransport_urllib,HttpServer_urllib)
 breezy.tests.per_transport.TransportTests.test_put_file_non_atomic_permissions(LocalTransport,LocalURLServer)
 breezy.tests.per_transport.TransportTests.test_put_file_non_atomic_permissions(MemoryTransport,MemoryServer)
 breezy.tests.per_transport.TransportTests.test_put_file_non_atomic_permissions(NoSmartTransportDecorator,NoSmartTransportServer)
@@ -16748,11 +16655,8 @@
 breezy.tests.per_transport.TransportTests.test_put_file_permissions(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_put_file_permissions(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_put_file_permissions(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_put_file_permissions(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_put_file_permissions(HTTPS_transport,HTTPSServer)
-breezy.tests.per_transport.TransportTests.test_put_file_permissions(HTTPS_urllib_transport,HTTPSServer_urllib)
 breezy.tests.per_transport.TransportTests.test_put_file_permissions(HttpTransport,HttpServer)
-breezy.tests.per_transport.TransportTests.test_put_file_permissions(HttpTransport_urllib,HttpServer_urllib)
 breezy.tests.per_transport.TransportTests.test_put_file_permissions(LocalTransport,LocalURLServer)
 breezy.tests.per_transport.TransportTests.test_put_file_permissions(MemoryTransport,MemoryServer)
 breezy.tests.per_transport.TransportTests.test_put_file_permissions(NoSmartTransportDecorator,NoSmartTransportServer)
@@ -16776,7 +16680,6 @@
 breezy.tests.per_transport.TransportTests.test_readv(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_readv(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_readv(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_readv(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_readv(HTTPS_transport,HTTPSServer)
 breezy.tests.per_transport.TransportTests.test_readv(HttpTransport,HttpServer)
 breezy.tests.per_transport.TransportTests.test_readv(LocalTransport,LocalURLServer)
@@ -16785,7 +16688,6 @@
 breezy.tests.per_transport.TransportTests.test_readv_out_of_order(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_readv_out_of_order(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_readv_out_of_order(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_readv_out_of_order(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_readv_out_of_order(HTTPS_transport,HTTPSServer)
 breezy.tests.per_transport.TransportTests.test_readv_out_of_order(HttpTransport,HttpServer)
 breezy.tests.per_transport.TransportTests.test_readv_out_of_order(LocalTransport,LocalURLServer)
@@ -16809,7 +16711,6 @@
 breezy.tests.per_transport.TransportTests.test_readv_short_read(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_readv_short_read(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_readv_short_read(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_readv_short_read(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_readv_short_read(HTTPS_transport,HTTPSServer)
 breezy.tests.per_transport.TransportTests.test_readv_short_read(HttpTransport,HttpServer)
 breezy.tests.per_transport.TransportTests.test_readv_short_read(LocalTransport,LocalURLServer)
@@ -16830,7 +16731,6 @@
 breezy.tests.per_transport.TransportTests.test_readv_with_adjust_for_latency(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_readv_with_adjust_for_latency(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_readv_with_adjust_for_latency(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_readv_with_adjust_for_latency(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_readv_with_adjust_for_latency(HTTPS_transport,HTTPSServer)
 breezy.tests.per_transport.TransportTests.test_readv_with_adjust_for_latency(HttpTransport,HttpServer)
 breezy.tests.per_transport.TransportTests.test_readv_with_adjust_for_latency(LocalTransport,LocalURLServer)
@@ -16848,7 +16748,6 @@
 breezy.tests.per_transport.TransportTests.test_readv_with_adjust_for_latency_with_big_file(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_readv_with_adjust_for_latency_with_big_file(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_readv_with_adjust_for_latency_with_big_file(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_readv_with_adjust_for_latency_with_big_file(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_readv_with_adjust_for_latency_with_big_file(HTTPS_transport,HTTPSServer)
 breezy.tests.per_transport.TransportTests.test_readv_with_adjust_for_latency_with_big_file(HttpTransport,HttpServer)
 breezy.tests.per_transport.TransportTests.test_readv_with_adjust_for_latency_with_big_file(LocalTransport,LocalURLServer)
@@ -16866,11 +16765,8 @@
 breezy.tests.per_transport.TransportTests.test_recommended_page_size(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_recommended_page_size(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_recommended_page_size(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_recommended_page_size(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_recommended_page_size(HTTPS_transport,HTTPSServer)
-breezy.tests.per_transport.TransportTests.test_recommended_page_size(HTTPS_urllib_transport,HTTPSServer_urllib)
 breezy.tests.per_transport.TransportTests.test_recommended_page_size(HttpTransport,HttpServer)
-breezy.tests.per_transport.TransportTests.test_recommended_page_size(HttpTransport_urllib,HttpServer_urllib)
 breezy.tests.per_transport.TransportTests.test_recommended_page_size(LocalTransport,LocalURLServer)
 breezy.tests.per_transport.TransportTests.test_recommended_page_size(MemoryTransport,MemoryServer)
 breezy.tests.per_transport.TransportTests.test_recommended_page_size(NoSmartTransportDecorator,NoSmartTransportServer)
@@ -16886,7 +16782,6 @@
 breezy.tests.per_transport.TransportTests.test_relpath_at_root(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_relpath_at_root(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_relpath_at_root(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_relpath_at_root(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_relpath_at_root(HTTPS_transport,HTTPSServer)
 breezy.tests.per_transport.TransportTests.test_relpath_at_root(HttpTransport,HttpServer)
 breezy.tests.per_transport.TransportTests.test_relpath_at_root(LocalTransport,LocalURLServer)
@@ -16904,11 +16799,8 @@
 breezy.tests.per_transport.TransportTests.test_relpath(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_relpath(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_relpath(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_relpath(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_relpath(HTTPS_transport,HTTPSServer)
-breezy.tests.per_transport.TransportTests.test_relpath(HTTPS_urllib_transport,HTTPSServer_urllib)
 breezy.tests.per_transport.TransportTests.test_relpath(HttpTransport,HttpServer)
-breezy.tests.per_transport.TransportTests.test_relpath(HttpTransport_urllib,HttpServer_urllib)
 breezy.tests.per_transport.TransportTests.test_relpath(LocalTransport,LocalURLServer)
 breezy.tests.per_transport.TransportTests.test_relpath(MemoryTransport,MemoryServer)
 breezy.tests.per_transport.TransportTests.test_relpath(NoSmartTransportDecorator,NoSmartTransportServer)
@@ -16924,11 +16816,8 @@
 breezy.tests.per_transport.TransportTests.test_rename_across_subdirs(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_rename_across_subdirs(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_rename_across_subdirs(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_rename_across_subdirs(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_rename_across_subdirs(HTTPS_transport,HTTPSServer)
-breezy.tests.per_transport.TransportTests.test_rename_across_subdirs(HTTPS_urllib_transport,HTTPSServer_urllib)
 breezy.tests.per_transport.TransportTests.test_rename_across_subdirs(HttpTransport,HttpServer)
-breezy.tests.per_transport.TransportTests.test_rename_across_subdirs(HttpTransport_urllib,HttpServer_urllib)
 breezy.tests.per_transport.TransportTests.test_rename_across_subdirs(LocalTransport,LocalURLServer)
 breezy.tests.per_transport.TransportTests.test_rename_across_subdirs(MemoryTransport,MemoryServer)
 breezy.tests.per_transport.TransportTests.test_rename_across_subdirs(NoSmartTransportDecorator,NoSmartTransportServer)
@@ -16944,11 +16833,8 @@
 breezy.tests.per_transport.TransportTests.test_rename_dir_nonempty(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_rename_dir_nonempty(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_rename_dir_nonempty(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_rename_dir_nonempty(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_rename_dir_nonempty(HTTPS_transport,HTTPSServer)
-breezy.tests.per_transport.TransportTests.test_rename_dir_nonempty(HTTPS_urllib_transport,HTTPSServer_urllib)
 breezy.tests.per_transport.TransportTests.test_rename_dir_nonempty(HttpTransport,HttpServer)
-breezy.tests.per_transport.TransportTests.test_rename_dir_nonempty(HttpTransport_urllib,HttpServer_urllib)
 breezy.tests.per_transport.TransportTests.test_rename_dir_nonempty(LocalTransport,LocalURLServer)
 breezy.tests.per_transport.TransportTests.test_rename_dir_nonempty(MemoryTransport,MemoryServer)
 breezy.tests.per_transport.TransportTests.test_rename_dir_nonempty(NoSmartTransportDecorator,NoSmartTransportServer)
@@ -16964,11 +16850,8 @@
 breezy.tests.per_transport.TransportTests.test_rename_dir_succeeds(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_rename_dir_succeeds(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_rename_dir_succeeds(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_rename_dir_succeeds(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_rename_dir_succeeds(HTTPS_transport,HTTPSServer)
-breezy.tests.per_transport.TransportTests.test_rename_dir_succeeds(HTTPS_urllib_transport,HTTPSServer_urllib)
 breezy.tests.per_transport.TransportTests.test_rename_dir_succeeds(HttpTransport,HttpServer)
-breezy.tests.per_transport.TransportTests.test_rename_dir_succeeds(HttpTransport_urllib,HttpServer_urllib)
 breezy.tests.per_transport.TransportTests.test_rename_dir_succeeds(LocalTransport,LocalURLServer)
 breezy.tests.per_transport.TransportTests.test_rename_dir_succeeds(MemoryTransport,MemoryServer)
 breezy.tests.per_transport.TransportTests.test_rename_dir_succeeds(NoSmartTransportDecorator,NoSmartTransportServer)
@@ -16984,7 +16867,6 @@
 breezy.tests.per_transport.TransportTests.test_reuse_connection_for_various_paths(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_reuse_connection_for_various_paths(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_reuse_connection_for_various_paths(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_reuse_connection_for_various_paths(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_reuse_connection_for_various_paths(HTTPS_transport,HTTPSServer)
 breezy.tests.per_transport.TransportTests.test_reuse_connection_for_various_paths(HttpTransport,HttpServer)
 breezy.tests.per_transport.TransportTests.test_reuse_connection_for_various_paths(LocalTransport,LocalURLServer)
@@ -17002,11 +16884,8 @@
 breezy.tests.per_transport.TransportTests.test__reuse_for(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test__reuse_for(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test__reuse_for(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test__reuse_for(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test__reuse_for(HTTPS_transport,HTTPSServer)
-breezy.tests.per_transport.TransportTests.test__reuse_for(HTTPS_urllib_transport,HTTPSServer_urllib)
 breezy.tests.per_transport.TransportTests.test__reuse_for(HttpTransport,HttpServer)
-breezy.tests.per_transport.TransportTests.test__reuse_for(HttpTransport_urllib,HttpServer_urllib)
 breezy.tests.per_transport.TransportTests.test__reuse_for(LocalTransport,LocalURLServer)
 breezy.tests.per_transport.TransportTests.test__reuse_for(MemoryTransport,MemoryServer)
 breezy.tests.per_transport.TransportTests.test__reuse_for(NoSmartTransportDecorator,NoSmartTransportServer)
@@ -17023,11 +16902,8 @@
 breezy.tests.per_transport.TransportTests.test_rmdir_empty_but_similar_prefix(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_rmdir_empty_but_similar_prefix(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_rmdir_empty_but_similar_prefix(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_rmdir_empty_but_similar_prefix(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_rmdir_empty_but_similar_prefix(HTTPS_transport,HTTPSServer)
-breezy.tests.per_transport.TransportTests.test_rmdir_empty_but_similar_prefix(HTTPS_urllib_transport,HTTPSServer_urllib)
 breezy.tests.per_transport.TransportTests.test_rmdir_empty_but_similar_prefix(HttpTransport,HttpServer)
-breezy.tests.per_transport.TransportTests.test_rmdir_empty_but_similar_prefix(HttpTransport_urllib,HttpServer_urllib)
 breezy.tests.per_transport.TransportTests.test_rmdir_empty_but_similar_prefix(LocalTransport,LocalURLServer)
 breezy.tests.per_transport.TransportTests.test_rmdir_empty_but_similar_prefix(MemoryTransport,MemoryServer)
 breezy.tests.per_transport.TransportTests.test_rmdir_empty_but_similar_prefix(NoSmartTransportDecorator,NoSmartTransportServer)
@@ -17042,22 +16918,16 @@
 breezy.tests.per_transport.TransportTests.test_rmdir_empty_but_similar_prefix(UnlistableTransportDecorator,UnlistableServer)
 breezy.tests.per_transport.TransportTests.test_rmdir(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_rmdir(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_rmdir(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_rmdir(HTTPS_transport,HTTPSServer)
-breezy.tests.per_transport.TransportTests.test_rmdir(HTTPS_urllib_transport,HTTPSServer_urllib)
 breezy.tests.per_transport.TransportTests.test_rmdir(HttpTransport,HttpServer)
-breezy.tests.per_transport.TransportTests.test_rmdir(HttpTransport_urllib,HttpServer_urllib)
 breezy.tests.per_transport.TransportTests.test_rmdir(LocalTransport,LocalURLServer)
 breezy.tests.per_transport.TransportTests.test_rmdir(MemoryTransport,MemoryServer)
 breezy.tests.per_transport.TransportTests.test_rmdir(NoSmartTransportDecorator,NoSmartTransportServer)
 breezy.tests.per_transport.TransportTests.test_rmdir_not_empty(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_rmdir_not_empty(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_rmdir_not_empty(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_rmdir_not_empty(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_rmdir_not_empty(HTTPS_transport,HTTPSServer)
-breezy.tests.per_transport.TransportTests.test_rmdir_not_empty(HTTPS_urllib_transport,HTTPSServer_urllib)
 breezy.tests.per_transport.TransportTests.test_rmdir_not_empty(HttpTransport,HttpServer)
-breezy.tests.per_transport.TransportTests.test_rmdir_not_empty(HttpTransport_urllib,HttpServer_urllib)
 breezy.tests.per_transport.TransportTests.test_rmdir_not_empty(LocalTransport,LocalURLServer)
 breezy.tests.per_transport.TransportTests.test_rmdir_not_empty(MemoryTransport,MemoryServer)
 breezy.tests.per_transport.TransportTests.test_rmdir_not_empty(NoSmartTransportDecorator,NoSmartTransportServer)
@@ -17082,11 +16952,8 @@
 breezy.tests.per_transport.TransportTests.test_segment_parameters(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_segment_parameters(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_segment_parameters(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_segment_parameters(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_segment_parameters(HTTPS_transport,HTTPSServer)
-breezy.tests.per_transport.TransportTests.test_segment_parameters(HTTPS_urllib_transport,HTTPSServer_urllib)
 breezy.tests.per_transport.TransportTests.test_segment_parameters(HttpTransport,HttpServer)
-breezy.tests.per_transport.TransportTests.test_segment_parameters(HttpTransport_urllib,HttpServer_urllib)
 breezy.tests.per_transport.TransportTests.test_segment_parameters(LocalTransport,LocalURLServer)
 breezy.tests.per_transport.TransportTests.test_segment_parameters(MemoryTransport,MemoryServer)
 breezy.tests.per_transport.TransportTests.test_segment_parameters(NoSmartTransportDecorator,NoSmartTransportServer)
@@ -17102,11 +16969,8 @@
 breezy.tests.per_transport.TransportTests.test_set_segment_parameters(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_set_segment_parameters(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_set_segment_parameters(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_set_segment_parameters(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_set_segment_parameters(HTTPS_transport,HTTPSServer)
-breezy.tests.per_transport.TransportTests.test_set_segment_parameters(HTTPS_urllib_transport,HTTPSServer_urllib)
 breezy.tests.per_transport.TransportTests.test_set_segment_parameters(HttpTransport,HttpServer)
-breezy.tests.per_transport.TransportTests.test_set_segment_parameters(HttpTransport_urllib,HttpServer_urllib)
 breezy.tests.per_transport.TransportTests.test_set_segment_parameters(LocalTransport,LocalURLServer)
 breezy.tests.per_transport.TransportTests.test_set_segment_parameters(MemoryTransport,MemoryServer)
 breezy.tests.per_transport.TransportTests.test_set_segment_parameters(NoSmartTransportDecorator,NoSmartTransportServer)
@@ -17122,11 +16986,8 @@
 breezy.tests.per_transport.TransportTests.test_stat(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_stat(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_stat(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_stat(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_stat(HTTPS_transport,HTTPSServer)
-breezy.tests.per_transport.TransportTests.test_stat(HTTPS_urllib_transport,HTTPSServer_urllib)
 breezy.tests.per_transport.TransportTests.test_stat(HttpTransport,HttpServer)
-breezy.tests.per_transport.TransportTests.test_stat(HttpTransport_urllib,HttpServer_urllib)
 breezy.tests.per_transport.TransportTests.test_stat(LocalTransport,LocalURLServer)
 breezy.tests.per_transport.TransportTests.test_stat(MemoryTransport,MemoryServer)
 breezy.tests.per_transport.TransportTests.test_stat(NoSmartTransportDecorator,NoSmartTransportServer)
@@ -17139,11 +17000,8 @@
 breezy.tests.per_transport.TransportTests.test_stat_symlink(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_stat_symlink(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_stat_symlink(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_stat_symlink(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_stat_symlink(HTTPS_transport,HTTPSServer)
-breezy.tests.per_transport.TransportTests.test_stat_symlink(HTTPS_urllib_transport,HTTPSServer_urllib)
 breezy.tests.per_transport.TransportTests.test_stat_symlink(HttpTransport,HttpServer)
-breezy.tests.per_transport.TransportTests.test_stat_symlink(HttpTransport_urllib,HttpServer_urllib)
 breezy.tests.per_transport.TransportTests.test_stat_symlink(LocalTransport,LocalURLServer)
 breezy.tests.per_transport.TransportTests.test_stat_symlink(MemoryTransport,MemoryServer)
 breezy.tests.per_transport.TransportTests.test_stat_symlink(NoSmartTransportDecorator,NoSmartTransportServer)
@@ -17162,11 +17020,8 @@
 breezy.tests.per_transport.TransportTests.test_symlink(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_symlink(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_symlink(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_symlink(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_symlink(HTTPS_transport,HTTPSServer)
-breezy.tests.per_transport.TransportTests.test_symlink(HTTPS_urllib_transport,HTTPSServer_urllib)
 breezy.tests.per_transport.TransportTests.test_symlink(HttpTransport,HttpServer)
-breezy.tests.per_transport.TransportTests.test_symlink(HttpTransport_urllib,HttpServer_urllib)
 breezy.tests.per_transport.TransportTests.test_symlink(LocalTransport,LocalURLServer)
 breezy.tests.per_transport.TransportTests.test_symlink(MemoryTransport,MemoryServer)
 breezy.tests.per_transport.TransportTests.test_symlink(NoSmartTransportDecorator,NoSmartTransportServer)
@@ -17179,15 +17034,11 @@
 breezy.tests.per_transport.TransportTests.test_symlink(TransportLogDecorator,LogDecoratorServer)
 breezy.tests.per_transport.TransportTests.test_symlink(TransportTraceDecorator,TraceServer)
 breezy.tests.per_transport.TransportTests.test_symlink(UnlistableTransportDecorator,UnlistableServer)
-breezy.tests.per_transport.TransportTests.test_unicode_paths(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_win32_abspath(ChrootTransport,TestingChrootServer)
 breezy.tests.per_transport.TransportTests.test_win32_abspath(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.per_transport.TransportTests.test_win32_abspath(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.per_transport.TransportTests.test_win32_abspath(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.per_transport.TransportTests.test_win32_abspath(HTTPS_transport,HTTPSServer)
-breezy.tests.per_transport.TransportTests.test_win32_abspath(HTTPS_urllib_transport,HTTPSServer_urllib)
 breezy.tests.per_transport.TransportTests.test_win32_abspath(HttpTransport,HttpServer)
-breezy.tests.per_transport.TransportTests.test_win32_abspath(HttpTransport_urllib,HttpServer_urllib)
 breezy.tests.per_transport.TransportTests.test_win32_abspath(LocalTransport,LocalURLServer)
 breezy.tests.per_transport.TransportTests.test_win32_abspath(MemoryTransport,MemoryServer)
 breezy.tests.per_transport.TransportTests.test_win32_abspath(NoSmartTransportDecorator,NoSmartTransportServer)
@@ -18363,6 +18214,8 @@
 breezy.tests.per_tree.test_tree.TestSupportsVersionableKind.test_unknown(WorkingTreeFormat5)
 breezy.tests.per_tree.test_tree.TestSupportsVersionableKind.test_unknown(WorkingTreeFormat6)
 breezy.tests.per_tree.test_tree.TestSupportsVersionableKind.test_unknown(WorkingTreeFormat6,remote)
+breezy.tests.per_tree.test_walkdirs.TestWalkdirs.test_walkdir_root(DirStateRevisionTree,WT4)
+breezy.tests.per_tree.test_walkdirs.TestWalkdirs.test_walkdir_root(DirStateRevisionTree,WT5)
 breezy.tests.per_tree.test_walkdirs.TestWalkdirs.test_walkdir_root(GitWorkingTreeFormat)
 breezy.tests.per_tree.test_walkdirs.TestWalkdirs.test_walkdir_root(PreviewTree)
 breezy.tests.per_tree.test_walkdirs.TestWalkdirs.test_walkdir_root(PreviewTreePost)
@@ -18373,6 +18226,8 @@
 breezy.tests.per_tree.test_walkdirs.TestWalkdirs.test_walkdir_root(WorkingTreeFormat5)
 breezy.tests.per_tree.test_walkdirs.TestWalkdirs.test_walkdir_root(WorkingTreeFormat6)
 breezy.tests.per_tree.test_walkdirs.TestWalkdirs.test_walkdir_root(WorkingTreeFormat6,remote)
+breezy.tests.per_tree.test_walkdirs.TestWalkdirs.test_walkdir_subtree(DirStateRevisionTree,WT4)
+breezy.tests.per_tree.test_walkdirs.TestWalkdirs.test_walkdir_subtree(DirStateRevisionTree,WT5)
 breezy.tests.per_tree.test_walkdirs.TestWalkdirs.test_walkdir_subtree(GitWorkingTreeFormat)
 breezy.tests.per_tree.test_walkdirs.TestWalkdirs.test_walkdir_subtree(PreviewTree)
 breezy.tests.per_tree.test_walkdirs.TestWalkdirs.test_walkdir_subtree(PreviewTreePost)
@@ -19430,7 +19285,6 @@
 breezy.tests.per_workingtree.test_commit.TestCommit.test_nested_commit(GitWorkingTreeFormat)
 breezy.tests.per_workingtree.test_commit.TestCommit.test_nested_commit_second_commit_detects_changes(WorkingTreeFormat2)
 breezy.tests.per_workingtree.test_commit.TestCommit.test_nested_commit_second_commit_detects_changes(WorkingTreeFormat3)
-breezy.tests.per_workingtree.test_commit.TestCommit.test_nested_commit_second_commit_detects_changes(WorkingTreeFormat6,remote)
 breezy.tests.per_workingtree.test_commit.TestCommit.test_nested_commit(WorkingTreeFormat2)
 breezy.tests.per_workingtree.test_commit.TestCommit.test_nested_commit(WorkingTreeFormat3)
 breezy.tests.per_workingtree.test_commit.TestCommit.test_nested_commit(WorkingTreeFormat4)
@@ -20768,6 +20622,12 @@
 breezy.tests.per_workingtree.test_parents.UpdateToOneParentViaDeltaTests.test_removes(WorkingTreeFormat6)
 breezy.tests.per_workingtree.test_parents.UpdateToOneParentViaDeltaTests.test_removes(WorkingTreeFormat6,remote)
 breezy.tests.per_workingtree.test_paths2ids.TestPaths2Ids.test_find_children_of_moved_directories(GitWorkingTreeFormat)
+breezy.tests.per_workingtree.test_paths2ids.TestPaths2Ids.test_find_children_of_moved_directories(WorkingTreeFormat2)
+breezy.tests.per_workingtree.test_paths2ids.TestPaths2Ids.test_find_children_of_moved_directories(WorkingTreeFormat3)
+breezy.tests.per_workingtree.test_paths2ids.TestPaths2Ids.test_find_children_of_moved_directories(WorkingTreeFormat4)
+breezy.tests.per_workingtree.test_paths2ids.TestPaths2Ids.test_find_children_of_moved_directories(WorkingTreeFormat5)
+breezy.tests.per_workingtree.test_paths2ids.TestPaths2Ids.test_find_children_of_moved_directories(WorkingTreeFormat6)
+breezy.tests.per_workingtree.test_paths2ids.TestPaths2Ids.test_find_children_of_moved_directories(WorkingTreeFormat6,remote)
 breezy.tests.per_workingtree.test_paths2ids.TestPaths2Ids.test_find_single_root(GitWorkingTreeFormat)
 breezy.tests.per_workingtree.test_paths2ids.TestPaths2Ids.test_find_single_root(WorkingTreeFormat2)
 breezy.tests.per_workingtree.test_paths2ids.TestPaths2Ids.test_find_single_root(WorkingTreeFormat3)
@@ -21742,6 +21602,7 @@
 breezy.tests.per_workingtree.test_workingtree.TestFormatAttributes.test_versioned_directories(WorkingTreeFormat5)
 breezy.tests.per_workingtree.test_workingtree.TestFormatAttributes.test_versioned_directories(WorkingTreeFormat6)
 breezy.tests.per_workingtree.test_workingtree.TestFormatAttributes.test_versioned_directories(WorkingTreeFormat6,remote)
+breezy.tests.per_workingtree.test_workingtree.TestIllegalPaths.test_bad_fs_path(GitWorkingTreeFormat)
 breezy.tests.per_workingtree.test_workingtree.TestWorkingTree.test_add_conflicts(GitWorkingTreeFormat)
 breezy.tests.per_workingtree.test_workingtree.TestWorkingTree.test_add_conflicts(WorkingTreeFormat2)
 breezy.tests.per_workingtree.test_workingtree.TestWorkingTree.test_add_conflicts(WorkingTreeFormat3)
@@ -22261,7 +22122,6 @@
 breezy.tests.test__bencode.TestBencodeDecode.test_decoder_type_error(C)
 breezy.tests.test__bencode.TestBencodeDecode.test_decoder_type_error(python)
 breezy.tests.test__bencode.TestBencodeDecode.test_dict(C)
-breezy.tests.test__bencode.TestBencodeDecode.test_dict_deepnested(C)
 breezy.tests.test__bencode.TestBencodeDecode.test_dict_deepnested(python)
 breezy.tests.test__bencode.TestBencodeDecode.test_dict(python)
 breezy.tests.test__bencode.TestBencodeDecode.test_empty_string(C)
@@ -22273,7 +22133,6 @@
 breezy.tests.test__bencode.TestBencodeDecode.test_large_string(C)
 breezy.tests.test__bencode.TestBencodeDecode.test_large_string(python)
 breezy.tests.test__bencode.TestBencodeDecode.test_list(C)
-breezy.tests.test__bencode.TestBencodeDecode.test_list_deepnested(C)
 breezy.tests.test__bencode.TestBencodeDecode.test_list_deepnested(python)
 breezy.tests.test__bencode.TestBencodeDecode.test_list(python)
 breezy.tests.test__bencode.TestBencodeDecode.test_long(C)
@@ -22465,13 +22324,9 @@
 breezy.tests.test_btree_index.TestBTreeIndex.test_with_offset_no_size
 breezy.tests.test_btree_index.TestBTreeIndex.test_with_size_constructor
 breezy.tests.test_btree_index.TestBTreeIndex.test_with_small_offset
-breezy.tests.test_btree_index.TestBTreeNodes.test__flatten_node(C)
 breezy.tests.test_btree_index.TestBTreeNodes.test__flatten_node(python)
-breezy.tests.test_btree_index.TestBTreeNodes.test_InternalNode_1(C)
 breezy.tests.test_btree_index.TestBTreeNodes.test_InternalNode_1(python)
-breezy.tests.test_btree_index.TestBTreeNodes.test_LeafNode_1_0(C)
 breezy.tests.test_btree_index.TestBTreeNodes.test_LeafNode_1_0(python)
-breezy.tests.test_btree_index.TestBTreeNodes.test_LeafNode_2_2(C)
 breezy.tests.test_btree_index.TestBTreeNodes.test_LeafNode_2_2(python)
 breezy.tests.test_btree_index.TestCompiledBtree.test_exists
 breezy.tests.test_btree_index.TestExpandOffsets.test_cannot_fully_expand
@@ -22633,6 +22488,7 @@
 breezy.tests.test_bundle.V4_2aBundleTester.test_revision_id_with_slash
 breezy.tests.test_bundle.V4_2aBundleTester.test_single_inventory_multiple_parents_as_xml
 breezy.tests.test_bundle.V4_2aBundleTester.test_single_inv_no_parents_as_xml
+breezy.tests.test_bundle.V4_2aBundleTester.test_skip_file
 breezy.tests.test_bundle.V4_2aBundleTester.test_symlink_bundle
 breezy.tests.test_bundle.V4_2aBundleTester.test_unicode_bundle
 breezy.tests.test_bundle.V4_2aBundleTester.test_unicode_symlink_bundle
@@ -22661,6 +22517,7 @@
 breezy.tests.test_bundle.V4BundleTester.test_malformed
 breezy.tests.test_bundle.V4BundleTester.test_non_bundle
 breezy.tests.test_bundle.V4BundleTester.test_revision_id_with_slash
+breezy.tests.test_bundle.V4BundleTester.test_skip_file
 breezy.tests.test_bundle.V4BundleTester.test_symlink_bundle
 breezy.tests.test_bundle.V4BundleTester.test_unicode_bundle
 breezy.tests.test_bundle.V4BundleTester.test_unicode_symlink_bundle
@@ -22715,6 +22572,7 @@
 breezy.tests.test_bzrdir.TestBzrDirHooks.test_pre_open_called
 breezy.tests.test_bzrdir.TestBzrDirSprout.test_sprout_parent
 breezy.tests.test_bzrdir.TestBzrDirSprout.test_sprout_uses_branch_sprout
+breezy.tests.test_bzrdir.TestBzrFormat.test_as_string
 breezy.tests.test_bzrdir.TestBzrFormat.test_check_support_status_optional
 breezy.tests.test_bzrdir.TestBzrFormat.test_check_support_status_required
 breezy.tests.test_bzrdir.TestBzrFormat.test_check_support_status_unknown
@@ -22728,11 +22586,14 @@
 breezy.tests.test_bzrdir.TestBzrFormat.test_from_string_with_spaces
 breezy.tests.test_bzrdir.TestBzrFormat.test_network_name
 breezy.tests.test_bzrdir.TestDefaultFormat.test_get_set_default_format
+breezy.tests.test_bzrdir.TestDotBzrHidden.test_dot_bzr_hidden
+breezy.tests.test_bzrdir.TestDotBzrHidden.test_dot_bzr_hidden_with_url
 breezy.tests.test_bzrdir.TestFormatRegistry.test_aliases
 breezy.tests.test_bzrdir.TestFormatRegistry.test_format_registry
 breezy.tests.test_bzrdir.TestFormatRegistry.test_get_help
 breezy.tests.test_bzrdir.TestFormatRegistry.test_help_topic
 breezy.tests.test_bzrdir.TestFormatRegistry.test_set_default_repository
+breezy.tests.test_bzrdir.TestGenerateBackupName.test_exiting
 breezy.tests.test_bzrdir.TestGenerateBackupName.test_new
 breezy.tests.test_bzrdir.TestHTTPRedirections_nosmart.test_loop
 breezy.tests.test_bzrdir.TestHTTPRedirections_nosmart.test_qualifier_preserved
@@ -22779,19 +22640,12 @@
 breezy.tests.test_cethread.TestCatchingExceptionThread.test_start_and_join_smoke_test
 breezy.tests.test_cethread.TestCatchingExceptionThread.test_switch_and_set
 breezy.tests.test_cethread.TestCatchingExceptionThread.test_sync_event
-breezy.tests.test__chk_map.Test_BytesToTextKey.test_dir(C)
 breezy.tests.test__chk_map.Test_BytesToTextKey.test_dir(python)
-breezy.tests.test__chk_map.Test_BytesToTextKey.test_file(C)
 breezy.tests.test__chk_map.Test_BytesToTextKey.test_file(python)
-breezy.tests.test__chk_map.Test_BytesToTextKey.test_invalid_no_kind(C)
 breezy.tests.test__chk_map.Test_BytesToTextKey.test_invalid_no_kind(python)
-breezy.tests.test__chk_map.Test_BytesToTextKey.test_invalid_no_space(C)
 breezy.tests.test__chk_map.Test_BytesToTextKey.test_invalid_no_space(python)
-breezy.tests.test__chk_map.Test_BytesToTextKey.test_invalid_too_short_file_id(C)
 breezy.tests.test__chk_map.Test_BytesToTextKey.test_invalid_too_short_file_id(python)
-breezy.tests.test__chk_map.Test_BytesToTextKey.test_invalid_too_short_name(C)
 breezy.tests.test__chk_map.Test_BytesToTextKey.test_invalid_too_short_name(python)
-breezy.tests.test__chk_map.Test_BytesToTextKey.test_invalid_too_short_parent_id(C)
 breezy.tests.test__chk_map.Test_BytesToTextKey.test_invalid_too_short_parent_id(python)
 breezy.tests.test_chk_map.TestCHKMapDifference.test__init__
 breezy.tests.test_chk_map.TestCHKMapDifference.test__process_next_old_batched_no_dupes
@@ -22808,35 +22662,20 @@
 breezy.tests.test_chk_map.TestCHKMapDifference.test__read_all_roots_prepares_queues
 breezy.tests.test_chk_map.TestCHKMapDifference.test__read_all_roots_skips_known_old
 breezy.tests.test_chk_map.TestCHKMapDifference.test__read_all_roots_yields_extra_deep_records
-breezy.tests.test__chk_map.TestDeserialiseInternalNode.test_deserialise_one(C)
 breezy.tests.test__chk_map.TestDeserialiseInternalNode.test_deserialise_one(python)
-breezy.tests.test__chk_map.TestDeserialiseInternalNode.test_deserialise_pref_with_null(C)
 breezy.tests.test__chk_map.TestDeserialiseInternalNode.test_deserialise_pref_with_null(python)
-breezy.tests.test__chk_map.TestDeserialiseInternalNode.test_deserialise_with_null_pref(C)
 breezy.tests.test__chk_map.TestDeserialiseInternalNode.test_deserialise_with_null_pref(python)
-breezy.tests.test__chk_map.TestDeserialiseInternalNode.test_deserialise_with_prefix(C)
 breezy.tests.test__chk_map.TestDeserialiseInternalNode.test_deserialise_with_prefix(python)
-breezy.tests.test__chk_map.TestDeserialiseInternalNode.test_raises_on_non_internal(C)
 breezy.tests.test__chk_map.TestDeserialiseInternalNode.test_raises_on_non_internal(python)
-breezy.tests.test__chk_map.TestDeserialiseLeafNode.test_deserialise_empty(C)
 breezy.tests.test__chk_map.TestDeserialiseLeafNode.test_deserialise_empty(python)
-breezy.tests.test__chk_map.TestDeserialiseLeafNode.test_deserialise_items(C)
 breezy.tests.test__chk_map.TestDeserialiseLeafNode.test_deserialise_items(python)
-breezy.tests.test__chk_map.TestDeserialiseLeafNode.test_deserialise_item_with_common_prefix(C)
 breezy.tests.test__chk_map.TestDeserialiseLeafNode.test_deserialise_item_with_common_prefix(python)
-breezy.tests.test__chk_map.TestDeserialiseLeafNode.test_deserialise_item_with_null_width_1(C)
 breezy.tests.test__chk_map.TestDeserialiseLeafNode.test_deserialise_item_with_null_width_1(python)
-breezy.tests.test__chk_map.TestDeserialiseLeafNode.test_deserialise_item_with_null_width_2(C)
 breezy.tests.test__chk_map.TestDeserialiseLeafNode.test_deserialise_item_with_null_width_2(python)
-breezy.tests.test__chk_map.TestDeserialiseLeafNode.test_deserialise_multi_line(C)
 breezy.tests.test__chk_map.TestDeserialiseLeafNode.test_deserialise_multi_line(python)
-breezy.tests.test__chk_map.TestDeserialiseLeafNode.test_iteritems_selected_one_of_two_items(C)
 breezy.tests.test__chk_map.TestDeserialiseLeafNode.test_iteritems_selected_one_of_two_items(python)
-breezy.tests.test__chk_map.TestDeserialiseLeafNode.test_key_after_map(C)
 breezy.tests.test__chk_map.TestDeserialiseLeafNode.test_key_after_map(python)
-breezy.tests.test__chk_map.TestDeserialiseLeafNode.test_key_after_unmap(C)
 breezy.tests.test__chk_map.TestDeserialiseLeafNode.test_key_after_unmap(python)
-breezy.tests.test__chk_map.TestDeserialiseLeafNode.test_raises_on_non_leaf(C)
 breezy.tests.test__chk_map.TestDeserialiseLeafNode.test_raises_on_non_leaf(python)
 breezy.tests.test_chk_map.TestInternalNode.test_add_node_empty_new
 breezy.tests.test_chk_map.TestInternalNode.test_add_node_resets_key_new
@@ -22878,6 +22717,7 @@
 breezy.tests.test_chk_map.TestLeafNode.test_deserialise_item_with_null_width_2
 breezy.tests.test_chk_map.TestLeafNode.test_deserialise_multi_line
 breezy.tests.test_chk_map.TestLeafNode.test_iteritems_selected_one_of_two_items
+breezy.tests.test_chk_map.TestLeafNode.test_key_after_map
 breezy.tests.test_chk_map.TestLeafNode.test_key_after_unmap
 breezy.tests.test_chk_map.TestLeafNode.test_key_new
 breezy.tests.test_chk_map.TestLeafNode.test_map_exceeding_max_size_only_entry_new
@@ -22901,10 +22741,12 @@
 breezy.tests.test_chk_map.TestMapSearchKeys.test_search_key_with_internal_node
 breezy.tests.test_chk_map.TestMap.test_apply_ab_empty
 breezy.tests.test_chk_map.TestMap.test_apply_delete_to_internal_node
+breezy.tests.test_chk_map.TestMap.test_apply_empty_ab
 breezy.tests.test_chk_map.TestMap.test_apply_new_keys_must_be_new
 breezy.tests.test_chk_map.TestMap.test_deep_splitting
 breezy.tests.test_chk_map.TestMap.test__dump_tree
 breezy.tests.test_chk_map.TestMap.test__dump_tree_in_progress
+breezy.tests.test_chk_map.TestMap.test_from_dict_ab
 breezy.tests.test_chk_map.TestMap.test_from_dict_empty
 breezy.tests.test_chk_map.TestMap.test_init_and_save_new
 breezy.tests.test_chk_map.TestMap.test_init_root_is_LeafNode_new
@@ -22922,6 +22764,7 @@
 breezy.tests.test_chk_map.TestMap.test_iteritems_keys_prefixed_by_2_width_nodes_hashed
 breezy.tests.test_chk_map.TestMap.test_iteritems_keys_prefixed_by_2_width_one_leaf
 breezy.tests.test_chk_map.TestMap.test_iteritems_selected_one_of_two_items
+breezy.tests.test_chk_map.TestMap.test_iteritems_two_items
 breezy.tests.test_chk_map.TestMap.test___len__2
 breezy.tests.test_chk_map.TestMap.test___len__empty
 breezy.tests.test_chk_map.TestMap.test_map_double_deep_collapses
@@ -22940,11 +22783,8 @@
 breezy.tests.test_chk_map.TestNode.test_equal
 breezy.tests.test_chk_map.TestNode.test_no_common_prefix
 breezy.tests.test_chk_map.TestNode.test_not_a_prefix
-breezy.tests.test__chk_map.TestSearchKeys.test_255_does_not_include_newline(C)
 breezy.tests.test__chk_map.TestSearchKeys.test_255_does_not_include_newline(python)
-breezy.tests.test__chk_map.TestSearchKeys.test_simple_16(C)
 breezy.tests.test__chk_map.TestSearchKeys.test_simple_16(python)
-breezy.tests.test__chk_map.TestSearchKeys.test_simple_255(C)
 breezy.tests.test__chk_map.TestSearchKeys.test_simple_255(python)
 breezy.tests.test_chk_map.TestTestCaseWithExampleMaps.test_one_deep_map_16
 breezy.tests.test_chk_map.TestTestCaseWithExampleMaps.test_one_deep_map_plain
@@ -23068,6 +22908,8 @@
 breezy.tests.test_commit.TestCommit.test_commit_has_1ms_resolution
 breezy.tests.test_commit.TestCommit.test_commit_invokes_hooks
 breezy.tests.test_commit.TestCommit.test_commit_kind_changes
+breezy.tests.test_commit.TestCommit.test_commit_lossy_foreign
+breezy.tests.test_commit.TestCommit.test_commit_lossy_native
 breezy.tests.test_commit.TestCommit.test_commit_move
 breezy.tests.test_commit.TestCommit.test_commit_new_subdir_child_selective
 breezy.tests.test_commit.TestCommit.test_commit_no_author
@@ -23077,6 +22919,7 @@
 breezy.tests.test_commit.TestCommit.test_commit_rename
 breezy.tests.test_commit.TestCommit.test_commit_reporting_after_merge
 breezy.tests.test_commit.TestCommit.test_commit_saves_1ms_timestamp
+breezy.tests.test_commit.TestCommit.test_committed_ancestry
 breezy.tests.test_commit.TestCommit.test_commit_unversioned_specified
 breezy.tests.test_commit.TestCommit.test_commit_with_checkout_and_branch_sharing_repo
 breezy.tests.test_commit.TestCommit.test_missing_commit
@@ -23092,6 +22935,7 @@
 breezy.tests.test_commit.TestCommit.test_safe_master_lock
 breezy.tests.test_commit.TestCommit.test_selected_file_merge_commit
 breezy.tests.test_commit.TestCommit.test_selective_delete
+breezy.tests.test_commit.TestCommit.test_signed_commit
 breezy.tests.test_commit.TestCommit.test_simple_commit
 breezy.tests.test_commit.TestCommit.test_strict_commit
 breezy.tests.test_commit.TestCommit.test_strict_commit_without_unknowns
@@ -23142,6 +22986,7 @@
 breezy.tests.test_config.TestBaseStackGet.test_get_without_registered_default_value
 breezy.tests.test_config.TestBaseStackGet.test_get_with_registered_default_value
 breezy.tests.test_config.TestBranchConfigItems.test_BRZ_EMAIL_OVERRIDES
+breezy.tests.test_config.TestBranchConfigItems.test_config_precedence
 breezy.tests.test_config.TestBranchConfigItems.test_get_user_option_global
 breezy.tests.test_config.TestBranchConfigItems.test_user_id
 breezy.tests.test_config.TestBranchConfig.test_autonick_urlencoded
@@ -23524,7 +23369,6 @@
 breezy.tests.test_config.TestRegisteredOptions.test_help_is_set(bound_location)
 breezy.tests.test_config.TestRegisteredOptions.test_help_is_set(branch.fetch_tags)
 breezy.tests.test_config.TestRegisteredOptions.test_help_is_set(bugtracker)
-breezy.tests.test_config.TestRegisteredOptions.test_help_is_set(bzr.transform.orphan_policy)
 breezy.tests.test_config.TestRegisteredOptions.test_help_is_set(bzr.workingtree.worth_saving_limit)
 breezy.tests.test_config.TestRegisteredOptions.test_help_is_set(check_signatures)
 breezy.tests.test_config.TestRegisteredOptions.test_help_is_set(child_submit_format)
@@ -23592,7 +23436,6 @@
 breezy.tests.test_config.TestRegisteredOptions.test_proper_name(bound_location)
 breezy.tests.test_config.TestRegisteredOptions.test_proper_name(branch.fetch_tags)
 breezy.tests.test_config.TestRegisteredOptions.test_proper_name(bugtracker)
-breezy.tests.test_config.TestRegisteredOptions.test_proper_name(bzr.transform.orphan_policy)
 breezy.tests.test_config.TestRegisteredOptions.test_proper_name(bzr.workingtree.worth_saving_limit)
 breezy.tests.test_config.TestRegisteredOptions.test_proper_name(check_signatures)
 breezy.tests.test_config.TestRegisteredOptions.test_proper_name(child_submit_format)
@@ -23834,7 +23677,15 @@
 breezy.tests.test_conflicts.TestPerConflict.test_stanza_roundtrip(PathConflict)
 breezy.tests.test_conflicts.TestPerConflict.test_stanza_roundtrip(TextConflict)
 breezy.tests.test_conflicts.TestPerConflict.test_stanza_roundtrip(UnversionedParent)
+breezy.tests.test_conflicts.TestPerConflict.test_stanzification(ContentsConflict)
+breezy.tests.test_conflicts.TestPerConflict.test_stanzification(DuplicateEntry)
+breezy.tests.test_conflicts.TestPerConflict.test_stanzification(DuplicateID)
+breezy.tests.test_conflicts.TestPerConflict.test_stanzification(MissingParent)
+breezy.tests.test_conflicts.TestPerConflict.test_stanzification(NonDirectoryParent)
+breezy.tests.test_conflicts.TestPerConflict.test_stanzification(ParentLoop)
+breezy.tests.test_conflicts.TestPerConflict.test_stanzification(PathConflict)
 breezy.tests.test_conflicts.TestPerConflict.test_stanzification(TextConflict)
+breezy.tests.test_conflicts.TestPerConflict.test_stanzification(UnversionedParent)
 breezy.tests.test_conflicts.TestPerConflict.test_stringification(ContentsConflict)
 breezy.tests.test_conflicts.TestPerConflict.test_stringification(DuplicateEntry)
 breezy.tests.test_conflicts.TestPerConflict.test_stringification(DuplicateID)
@@ -23877,6 +23728,11 @@
 breezy.tests.test_conflicts.TestResolveMissingParent.test_keep_them_all
 breezy.tests.test_conflicts.TestResolveMissingParent.test_kill_them_all
 breezy.tests.test_conflicts.TestResolveMissingParent.test_resolve_taking_other
+breezy.tests.test_conflicts.TestResolveMissingParent.test_resolve_taking_this
+breezy.tests.test_conflicts.TestResolveParentLoop.test_resolve_taking_other(dir1_into_dir2,dir2_into_dir1)
+breezy.tests.test_conflicts.TestResolveParentLoop.test_resolve_taking_other(dir2_into_dir1,dir1_into_dir2)
+breezy.tests.test_conflicts.TestResolveParentLoop.test_resolve_taking_this(dir1_into_dir2,dir2_into_dir1)
+breezy.tests.test_conflicts.TestResolveParentLoop.test_resolve_taking_this(dir2_into_dir1,dir1_into_dir2)
 breezy.tests.test_conflicts.TestResolvePathConflictBefore531967.test_resolve_taking_other(dir_deleted,dir_renamed)
 breezy.tests.test_conflicts.TestResolvePathConflictBefore531967.test_resolve_taking_other(dir_renamed2,dir_renamed)
 breezy.tests.test_conflicts.TestResolvePathConflictBefore531967.test_resolve_taking_other(dir_renamed,dir_deleted)
@@ -24413,7 +24269,6 @@
 breezy.tests.test_export.TarExporterTests.test_tgz
 breezy.tests.test_export.TarExporterTests.test_tgz_ignores_dest_path
 breezy.tests.test_export.TarExporterTests.test_xz
-breezy.tests.test_export.TarExporterTests.test_xz_stdout
 breezy.tests.test_export.TestDirExport.test_empty
 breezy.tests.test_export.TestDirExport.test_empty_subdir
 breezy.tests.test_export.TestDirExport.test_existing_single_file
@@ -24502,19 +24357,15 @@
 breezy.tests.test_foreign.ForeignVcsRegistryTests.test_parse_revision_id
 breezy.tests.test_foreign.ForeignVcsRegistryTests.test_parse_revision_id_no_dash
 breezy.tests.test_foreign.ForeignVcsRegistryTests.test_parse_revision_id_unknown_mapping
-breezy.tests.test_ftp_transport.TestFTPErrorTranslation.test_translate_directory_not_empty
-breezy.tests.test_ftp_transport.TestFTPTestServer.test_basic_exists
-breezy.tests.test_ftp_transport.TestFTPTestServer.test__reconnect
-breezy.tests.test_ftp_transport.TestFTPTestServerUI.test_empty_password
-breezy.tests.test_ftp_transport.TestFTPTestServerUI.test_no_prompt_for_password_when_using_auth_config
-breezy.tests.test_ftp_transport.TestFTPTestServerUI.test_no_prompt_for_username
-breezy.tests.test_ftp_transport.TestFTPTestServerUI.test_prompt_for_password
 breezy.tests.test_generate_docs.TestGenerateDocs.test_man_page
 breezy.tests.test_generate_docs.TestGenerateDocs.test_rstx_man
+breezy.tests.test_generate_ids.TestFileIds.test_file_ids_are_ascii
+breezy.tests.test_generate_ids.TestFileIds.test_gen_file_id
 breezy.tests.test_generate_ids.TestFileIds.test_gen_root_id
 breezy.tests.test_generate_ids.TestFileIds.test__next_id_suffix_increments
 breezy.tests.test_generate_ids.TestFileIds.test__next_id_suffix_sets_suffix
 breezy.tests.test_generate_ids.TestGenRevisionId.test_gen_revision_id_email
+breezy.tests.test_generate_ids.TestGenRevisionId.test_gen_revision_id_user
 breezy.tests.test_generate_ids.TestGenRevisionId.test_revision_ids_are_ascii
 breezy.tests.test_generate_ids.TestGenRevisionId.test_timestamp
 breezy.tests.test_globbing.TestExceptionGlobster.test_exclusion_order
@@ -24830,6 +24681,21 @@
 breezy.tests.test_http_response.TestHandleResponse.test_missing_content_range
 breezy.tests.test_http_response.TestHandleResponse.test_multipart_no_content_range
 breezy.tests.test_http_response.TestHTTPConnection.test_cleanup_pipe
+breezy.tests.test_http_response.TestRangeFileMultipleRangesQuotedBoundaries.test_can_read_at_first_access
+breezy.tests.test_http_response.TestRangeFileMultipleRangesQuotedBoundaries.test_checked_read_dont_overflow_buffers
+breezy.tests.test_http_response.TestRangeFileMultipleRangesQuotedBoundaries.test_read_all_ranges
+breezy.tests.test_http_response.TestRangeFileMultipleRangesQuotedBoundaries.test_read_at_range_end
+breezy.tests.test_http_response.TestRangeFileMultipleRangesQuotedBoundaries.test_read_past_end_of_range
+breezy.tests.test_http_response.TestRangeFileMultipleRangesQuotedBoundaries.test_read_zero
+breezy.tests.test_http_response.TestRangeFileMultipleRangesQuotedBoundaries.test_seek_across_ranges
+breezy.tests.test_http_response.TestRangeFileMultipleRangesQuotedBoundaries.test_seek_at_range_end
+breezy.tests.test_http_response.TestRangeFileMultipleRangesQuotedBoundaries.test_seek_backwards
+breezy.tests.test_http_response.TestRangeFileMultipleRangesQuotedBoundaries.test_seek_from_end
+breezy.tests.test_http_response.TestRangeFileMultipleRangesQuotedBoundaries.test_seek_into_void
+breezy.tests.test_http_response.TestRangeFileMultipleRangesQuotedBoundaries.test_seek_outside_single_range
+breezy.tests.test_http_response.TestRangeFileMultipleRangesQuotedBoundaries.test_seek_read
+breezy.tests.test_http_response.TestRangeFileMultipleRangesQuotedBoundaries.test_seek_twice_between_ranges
+breezy.tests.test_http_response.TestRangeFileMultipleRangesQuotedBoundaries.test_unbounded_read_after_seek
 breezy.tests.test_http_response.TestRangeFileMultipleRanges.test_can_read_at_first_access
 breezy.tests.test_http_response.TestRangeFileMultipleRanges.test_checked_read_dont_overflow_buffers
 breezy.tests.test_http_response.TestRangeFileMultipleRanges.test_read_all_ranges
@@ -25200,6 +25066,7 @@
 breezy.tests.test_http.TestTruncatedMultipleRangeServer.test_readv_with_short_reads(urllib,HTTP/1.0)
 breezy.tests.test_http.TestTruncatedMultipleRangeServer.test_readv_with_short_reads(urllib,HTTP/1.1)
 breezy.tests.test_http.TestUrllib2AuthHandler.test_get_user_password_without_port
+breezy.tests.test_i18n.LoadPluginTranslations.test_does_not_exist
 breezy.tests.test_i18n.TestGetTextPerParagraph.test_multiline
 breezy.tests.test_i18n.TestGetTextPerParagraph.test_oneline
 breezy.tests.test_i18n.TestGetText.test_multiline
@@ -25207,7 +25074,9 @@
 breezy.tests.test_i18n.TestInstall.test_custom_languages
 breezy.tests.test_i18n.TestInstall.test_disable_i18n
 breezy.tests.test_i18n.TestInstall.test_no_env_variables
+breezy.tests.test_i18n.TestTranslate.test_error_message_translation
 breezy.tests.test_i18n.TestTranslate.test_topic_help_translation
+breezy.tests.test_i18n.TestZzzTranslation.test_translation
 breezy.tests.test_identitymap.TestIdentityMap.test_add_weave
 breezy.tests.test_identitymap.TestIdentityMap.test_construct
 breezy.tests.test_identitymap.TestIdentityMap.test_double_add_weave
@@ -25235,6 +25104,9 @@
 breezy.tests.test_ignores.TestUserIgnores.test_set
 breezy.tests.test_ignores.TestUserIgnores.test_use_empty
 breezy.tests.test_ignores.TestUserIgnores.test_use_existing
+breezy.tests.test_import_tariff.TestImportTariffs.test_help_commands
+breezy.tests.test_import_tariff.TestImportTariffs.test_import_tariffs_working
+breezy.tests.test_import_tariff.TestImportTariffs.test_simple_local
 breezy.tests.test_index.ErrorTests.test_bad_index_data
 breezy.tests.test_index.ErrorTests.test_bad_index_duplicate_key
 breezy.tests.test_index.ErrorTests.test_bad_index_format_signature
@@ -25251,6 +25123,7 @@
 breezy.tests.test_index.TestCombinedGraphIndex.test_iter_all_entries_children_empty
 breezy.tests.test_index.TestCombinedGraphIndex.test_iter_all_entries_empty
 breezy.tests.test_index.TestCombinedGraphIndex.test_iter_all_entries_no_reload
+breezy.tests.test_index.TestCombinedGraphIndex.test_iter_all_entries_reloads
 breezy.tests.test_index.TestCombinedGraphIndex.test_iter_all_entries_reloads_and_fails
 breezy.tests.test_index.TestCombinedGraphIndex.test_iter_all_entries_reloads_midway
 breezy.tests.test_index.TestCombinedGraphIndex.test_iter_all_entries_simple
@@ -25263,6 +25136,7 @@
 breezy.tests.test_index.TestCombinedGraphIndex.test_iter_entries_prefix_reloads
 breezy.tests.test_index.TestCombinedGraphIndex.test_iter_entries_prefix_reloads_and_fails
 breezy.tests.test_index.TestCombinedGraphIndex.test_iter_entries_prefix_reloads_midway
+breezy.tests.test_index.TestCombinedGraphIndex.test_iter_entries_reloads
 breezy.tests.test_index.TestCombinedGraphIndex.test_iter_entries_reloads_and_fails
 breezy.tests.test_index.TestCombinedGraphIndex.test_iter_entries_reloads_midway
 breezy.tests.test_index.TestCombinedGraphIndex.test_iter_entries_two_indices_dup_key
@@ -25484,7 +25358,6 @@
 breezy.tests.test_inv.TestCHKInventory.test_filter_change_in_renamed_subfolder
 breezy.tests.test_inv.TestCHKInventory.test_from_inventory_maximum_size
 breezy.tests.test_inv.TestCHKInventory.test_get_entry
-breezy.tests.test_inv.TestCHKInventory.test___getitem__
 breezy.tests.test_inv.TestCHKInventory.test_has_id_not
 breezy.tests.test_inv.TestCHKInventory.test_has_id_true
 breezy.tests.test_inv.TestCHKInventory.test_id2path
@@ -26642,12 +26515,10 @@
 breezy.tests.test_lockdir.TestStaleLockDir.test_auto_break_stale_lock_configured_off
 breezy.tests.test_lock.TestOSLock.test_create_read_lock(fcntl)
 breezy.tests.test_lock.TestOSLock.test_create_write_lock(fcntl)
-breezy.tests.test_lock.TestOSLock.test_read_locks_block_write_locks(fcntl)
 breezy.tests.test_lock.TestOSLock.test_read_locks_share(fcntl)
 breezy.tests.test_lock.TestOSLock.test_temporary_write_lock_fails(fcntl)
 breezy.tests.test_lock.TestOSLock.test_temporary_write_lock(fcntl)
 breezy.tests.test_lock.TestOSLock.test_write_locks_are_exclusive(fcntl)
-breezy.tests.test_lock.TestOSLock.test_write_locks_block_read_lock(fcntl)
 breezy.tests.test_log.TestFormatSignatureValidity.test_format_signature_validity_utf
 breezy.tests.test_log.TestGnuChangelogFormatter.test_gnu_changelog
 breezy.tests.test_log.TestGnuChangelogFormatter.test_verbose
@@ -26765,9 +26636,6 @@
 breezy.tests.test_lsprof.TestBzrProfiler.test_block_0
 breezy.tests.test_lsprof.TestBzrProfiler.test_block_1
 breezy.tests.test_lsprof.TestBzrProfiler.test_start_call_stuff_stop
-breezy.tests.test_lsprof.TestStatsSave.test_stats_save_to_callgrind
-breezy.tests.test_lsprof.TestStatsSave.test_stats_save_to_pickle
-breezy.tests.test_lsprof.TestStatsSave.test_stats_save_to_txt
 breezy.tests.test_lsprof.TestStats.test_save_to_callgrind
 breezy.tests.test_lsprof.TestStats.test_save_to_pickle
 breezy.tests.test_lsprof.TestStats.test_save_to_txt
@@ -26938,6 +26806,7 @@
 breezy.tests.test_merge_directive.TestParseOldMergeDirective2.test_parse_old_merge_directive
 breezy.tests.test_merge.TestConfigurableFileMerger.test_affected_files_cached
 breezy.tests.test_merge.TestConfigurableFileMerger.test_hook_called_for_text_conflicts
+breezy.tests.test_merge.TestConfigurableFileMerger.test_hook_not_called_for_kind_change
 breezy.tests.test_merge.TestConfigurableFileMerger.test_hook_not_called_for_other_files
 breezy.tests.test_merge.TestConfigurableFileMerger.test_uses_this_branch
 breezy.tests.test_merge.TestLCAMultiWay.test_all_differ
@@ -27163,6 +27032,7 @@
 breezy.tests.test_options.OptionTests.test_registry_conversion
 breezy.tests.test_options.OptionTests.test_registry_converter
 breezy.tests.test_options.OptionTests.test_set_short_name
+breezy.tests.test_options.OptionTests.test_unknown_short_opt
 breezy.tests.test_options.TestListOptions.test_list_option
 breezy.tests.test_options.TestListOptions.test_list_option_can_be_reset
 breezy.tests.test_options.TestListOptions.test_list_option_no_arguments
@@ -27548,7 +27418,6 @@
 breezy.tests.test_read_bundle.TestReadMergeableBundleFromURL.test_read_fail(ChrootTransport,TestingChrootServer)
 breezy.tests.test_read_bundle.TestReadMergeableBundleFromURL.test_read_fail(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.test_read_bundle.TestReadMergeableBundleFromURL.test_read_fail(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.test_read_bundle.TestReadMergeableBundleFromURL.test_read_fail(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.test_read_bundle.TestReadMergeableBundleFromURL.test_read_fail(HTTPS_transport,HTTPSServer)
 breezy.tests.test_read_bundle.TestReadMergeableBundleFromURL.test_read_fail(HttpTransport,HttpServer)
 breezy.tests.test_read_bundle.TestReadMergeableBundleFromURL.test_read_fail(LocalTransport,LocalURLServer)
@@ -27566,7 +27435,6 @@
 breezy.tests.test_read_bundle.TestReadMergeableBundleFromURL.test_read_mergeable_from_url(ChrootTransport,TestingChrootServer)
 breezy.tests.test_read_bundle.TestReadMergeableBundleFromURL.test_read_mergeable_from_url(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.test_read_bundle.TestReadMergeableBundleFromURL.test_read_mergeable_from_url(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.test_read_bundle.TestReadMergeableBundleFromURL.test_read_mergeable_from_url(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.test_read_bundle.TestReadMergeableBundleFromURL.test_read_mergeable_from_url(HTTPS_transport,HTTPSServer)
 breezy.tests.test_read_bundle.TestReadMergeableBundleFromURL.test_read_mergeable_from_url(HttpTransport,HttpServer)
 breezy.tests.test_read_bundle.TestReadMergeableBundleFromURL.test_read_mergeable_from_url(LocalTransport,LocalURLServer)
@@ -27584,7 +27452,6 @@
 breezy.tests.test_read_bundle.TestReadMergeableBundleFromURL.test_read_mergeable_respects_possible_transports(ChrootTransport,TestingChrootServer)
 breezy.tests.test_read_bundle.TestReadMergeableBundleFromURL.test_read_mergeable_respects_possible_transports(FakeNFSTransportDecorator,FakeNFSServer)
 breezy.tests.test_read_bundle.TestReadMergeableBundleFromURL.test_read_mergeable_respects_possible_transports(FakeVFATTransportDecorator,FakeVFATServer)
-breezy.tests.test_read_bundle.TestReadMergeableBundleFromURL.test_read_mergeable_respects_possible_transports(FtpTransport,UnavailableFTPTestServer)
 breezy.tests.test_read_bundle.TestReadMergeableBundleFromURL.test_read_mergeable_respects_possible_transports(HTTPS_transport,HTTPSServer)
 breezy.tests.test_read_bundle.TestReadMergeableBundleFromURL.test_read_mergeable_respects_possible_transports(HttpTransport,HttpServer)
 breezy.tests.test_read_bundle.TestReadMergeableBundleFromURL.test_read_mergeable_respects_possible_transports(LocalTransport,LocalURLServer)
@@ -27641,6 +27508,7 @@
 breezy.tests.test_reconfigure.TestReconfigure.test_unsynced_branch_to_lightweight_checkout_unforced
 breezy.tests.test_reconfigure.TestReconfigure.test_unsynced_checkout_to_lightweight
 breezy.tests.test_reconfigure.TestReconfigure.test_use_shared_to_standalone
+breezy.tests.test_reconfigure.TestReconfigure.test_use_shared_to_standalone_preserves_dead_heads
 breezy.tests.test_reconfigure.TestReconfigure.test_use_shared_to_use_shared
 breezy.tests.test_registry.TestRegistryIter.test_items
 breezy.tests.test_registry.TestRegistryIter.test_iteritems
@@ -27693,8 +27561,10 @@
 breezy.tests.test_remote.TestBranchGetSetConfig.test_get_branch_conf
 breezy.tests.test_remote.TestBranchGetSetConfig.test_get_multi_line_branch_conf
 breezy.tests.test_remote.TestBranchGetSetConfig.test_set_option
+breezy.tests.test_remote.TestBranchGetSetConfig.test_set_option_with_dict
 breezy.tests.test_remote.TestBranch_get_stacked_on_url.test_backwards_compatible
 breezy.tests.test_remote.TestBranch_get_stacked_on_url.test_get_stacked_on_invalid_url
+breezy.tests.test_remote.TestBranch_get_stacked_on_url.test_get_stacked_on_real_branch
 breezy.tests.test_remote.TestBranchGetTagsBytes.test_backwards_compat
 breezy.tests.test_remote.TestBranchGetTagsBytes.test_trivial
 breezy.tests.test_remote.TestBranchHeadsToFetch.test_backwards_compatible
@@ -27735,6 +27605,7 @@
 breezy.tests.test_remote.TestBzrDirDestroyBranch.test_destroy_default
 breezy.tests.test_remote.TestBzrDirDestroyRepository.test_destroy_repository
 breezy.tests.test_remote.TestBzrDirFormatInitializeEx.test_error_from_real_server
+breezy.tests.test_remote.TestBzrDirFormatInitializeEx.test_success
 breezy.tests.test_remote.TestBzrDirGetBranches.test_get_branches
 breezy.tests.test_remote.TestBzrDirGetSetConfig.test_backwards_compat_get_option
 breezy.tests.test_remote.TestBzrDirGetSetConfig.test__get_config
@@ -27890,6 +27761,8 @@
 breezy.tests.test_remote.TestWithCustomErrorHandler.test_no_context
 breezy.tests.test_remote.TestWithCustomErrorHandler.test_with_context
 breezy.tests.test_rename_map.TestRenameMap.test_add_edge_hashes
+breezy.tests.test_rename_map.TestRenameMap.test_add_file_edge_hashes
+breezy.tests.test_rename_map.TestRenameMap.test_file_match
 breezy.tests.test_rename_map.TestRenameMap.test_file_match_no_dups
 breezy.tests.test_rename_map.TestRenameMap.test_find_directory_renames
 breezy.tests.test_rename_map.TestRenameMap.test_guess_rename_handles_new_directories
@@ -27905,6 +27778,7 @@
 breezy.tests.test_repository.Test2a.test_chk_bytes_uses_custom_btree_parser
 breezy.tests.test_repository.Test2a.test_fetch_combines_groups
 breezy.tests.test_repository.Test2a.test_format_pack_compresses_True
+breezy.tests.test_repository.Test2a.test_get_stream_for_missing_keys_includes_all_chk_refs
 breezy.tests.test_repository.Test2a.test_inconsistency_fatal
 breezy.tests.test_repository.Test2a.test_inventories_use_chk_map_with_parent_base_dict
 breezy.tests.test_repository.Test2a.test_pack_with_hint
@@ -27930,6 +27804,9 @@
 breezy.tests.test_repository.TestFormatKnit1.test_attribute__fetch_uses_deltas
 breezy.tests.test_repository.TestFormatKnit1.test_deserialise_sets_root_revision
 breezy.tests.test_repository.TestFormatKnit1.test_deserialise_uses_global_revision_id
+breezy.tests.test_repository.TestFormatKnit1.test_disk_layout
+breezy.tests.test_repository.TestFormatKnit1.test_shared_disk_layout
+breezy.tests.test_repository.TestFormatKnit1.test_shared_no_tree_disk_layout
 breezy.tests.test_repository.TestFormatKnit1.test_supports_external_lookups
 breezy.tests.test_repository.TestGCCHKPacker.test_pack_with_distant_inventories
 breezy.tests.test_repository.TestGCCHKPacker.test_pack_with_missing_inventory
@@ -27986,6 +27863,8 @@
 breezy.tests.test_repository.TestRepositoryPackCollection.test_repr
 breezy.tests.test_repository.TestRepositoryPackCollection.test__save_pack_names
 breezy.tests.test_repository.TestRepositoryPackCollection.test__save_pack_names_already_obsoleted
+breezy.tests.test_repository.TestWithBrokenRepo.test_insert_from_broken_repo
+breezy.tests.test_revert.TestRevert.test_preserve_execute
 breezy.tests.test_revert.TestRevert.test_revert_deletes_files_from_revert
 breezy.tests.test_revert.TestRevert.test_revert_executable
 breezy.tests.test_revert.TestRevert.test_revert_file_in_deleted_dir
@@ -28098,27 +27977,49 @@
 breezy.tests.test_revisiontree.TestTreeWithCommits.test_get_file_revision_root
 breezy.tests.test_revisiontree.TestTreeWithCommits.test_no_conflicts
 breezy.tests.test_revisiontree.TestTreeWithCommits.test_parents
+breezy.tests.test__rio.TestReadUnicodeStanza.test_continuation_too_early(C)
 breezy.tests.test__rio.TestReadUnicodeStanza.test_continuation_too_early(python)
+breezy.tests.test__rio.TestReadUnicodeStanza.test_empty(C)
 breezy.tests.test__rio.TestReadUnicodeStanza.test_empty(python)
+breezy.tests.test__rio.TestReadUnicodeStanza.test_invalid_early_colon(C)
 breezy.tests.test__rio.TestReadUnicodeStanza.test_invalid_early_colon(python)
+breezy.tests.test__rio.TestReadUnicodeStanza.test_invalid_tag(C)
 breezy.tests.test__rio.TestReadUnicodeStanza.test_invalid_tag(python)
+breezy.tests.test__rio.TestReadUnicodeStanza.test_large(C)
 breezy.tests.test__rio.TestReadUnicodeStanza.test_large(python)
+breezy.tests.test__rio.TestReadUnicodeStanza.test_multi_line(C)
 breezy.tests.test__rio.TestReadUnicodeStanza.test_multi_line(python)
+breezy.tests.test__rio.TestReadUnicodeStanza.test_non_ascii_char(C)
 breezy.tests.test__rio.TestReadUnicodeStanza.test_non_ascii_char(python)
+breezy.tests.test__rio.TestReadUnicodeStanza.test_none(C)
 breezy.tests.test__rio.TestReadUnicodeStanza.test_none(python)
+breezy.tests.test__rio.TestReadUnicodeStanza.test_no_string(C)
 breezy.tests.test__rio.TestReadUnicodeStanza.test_no_string(python)
+breezy.tests.test__rio.TestReadUnicodeStanza.test_repeated(C)
 breezy.tests.test__rio.TestReadUnicodeStanza.test_repeated(python)
+breezy.tests.test__rio.TestReadUnicodeStanza.test_simple(C)
 breezy.tests.test__rio.TestReadUnicodeStanza.test_simple(python)
+breezy.tests.test__rio.TestReadUTF8Stanza.test_continuation_too_early(C)
 breezy.tests.test__rio.TestReadUTF8Stanza.test_continuation_too_early(python)
+breezy.tests.test__rio.TestReadUTF8Stanza.test_empty(C)
 breezy.tests.test__rio.TestReadUTF8Stanza.test_empty(python)
+breezy.tests.test__rio.TestReadUTF8Stanza.test_invalid_early_colon(C)
 breezy.tests.test__rio.TestReadUTF8Stanza.test_invalid_early_colon(python)
+breezy.tests.test__rio.TestReadUTF8Stanza.test_invalid_tag(C)
 breezy.tests.test__rio.TestReadUTF8Stanza.test_invalid_tag(python)
+breezy.tests.test__rio.TestReadUTF8Stanza.test_large(C)
 breezy.tests.test__rio.TestReadUTF8Stanza.test_large(python)
+breezy.tests.test__rio.TestReadUTF8Stanza.test_multi_line(C)
 breezy.tests.test__rio.TestReadUTF8Stanza.test_multi_line(python)
+breezy.tests.test__rio.TestReadUTF8Stanza.test_non_ascii_char(C)
 breezy.tests.test__rio.TestReadUTF8Stanza.test_non_ascii_char(python)
+breezy.tests.test__rio.TestReadUTF8Stanza.test_none(C)
 breezy.tests.test__rio.TestReadUTF8Stanza.test_none(python)
+breezy.tests.test__rio.TestReadUTF8Stanza.test_no_string(C)
 breezy.tests.test__rio.TestReadUTF8Stanza.test_no_string(python)
+breezy.tests.test__rio.TestReadUTF8Stanza.test_repeated(C)
 breezy.tests.test__rio.TestReadUTF8Stanza.test_repeated(python)
+breezy.tests.test__rio.TestReadUTF8Stanza.test_simple(C)
 breezy.tests.test__rio.TestReadUTF8Stanza.test_simple(python)
 breezy.tests.test_rio.TestRio.test_as_dict
 breezy.tests.test_rio.TestRio.test_backslash
@@ -28146,13 +28047,21 @@
 breezy.tests.test_rio.TestRio.test_tricky_quoted
 breezy.tests.test_rio.TestRio.test_whitespace_value
 breezy.tests.test_rio.TestRio.test_write_empty_stanza
+breezy.tests.test__rio.TestValidTag.test_empty(C)
 breezy.tests.test__rio.TestValidTag.test_empty(python)
+breezy.tests.test__rio.TestValidTag.test_no_colon(C)
 breezy.tests.test__rio.TestValidTag.test_no_colon(python)
+breezy.tests.test__rio.TestValidTag.test_non_ascii_char(C)
 breezy.tests.test__rio.TestValidTag.test_non_ascii_char(python)
+breezy.tests.test__rio.TestValidTag.test_no_spaces(C)
 breezy.tests.test__rio.TestValidTag.test_no_spaces(python)
+breezy.tests.test__rio.TestValidTag.test_numeric(C)
 breezy.tests.test__rio.TestValidTag.test_numeric(python)
+breezy.tests.test__rio.TestValidTag.test_ok(C)
 breezy.tests.test__rio.TestValidTag.test_ok(python)
+breezy.tests.test__rio.TestValidTag.test_type_error(C)
 breezy.tests.test__rio.TestValidTag.test_type_error(python)
+breezy.tests.test__rio.TestValidTag.test_unicode(C)
 breezy.tests.test__rio.TestValidTag.test_unicode(python)
 breezy.tests.test_rules.TestErrors.test_unknown_rules
 breezy.tests.test_rules.TestIniBasedRulesSearcher.test_get_items_file_empty
@@ -28244,6 +28153,7 @@
 breezy.tests.test_selftest.MetaTestLog.test_logging
 breezy.tests.test_selftest.TestActuallyStartBzrSubprocess.test_start_and_stop_bzr_subprocess_send_signal
 breezy.tests.test_selftest.TestBlackboxSupport.test_run_bzr_failure_not_caught
+breezy.tests.test_selftest.TestBlackboxSupport.test_run_bzr_user_error_caught
 breezy.tests.test_selftest.TestBranchScenarios.test_scenarios
 breezy.tests.test_selftest.TestBzrDirScenarios.test_scenarios
 breezy.tests.test_selftest.TestCheckTreeShape.test_check_tree_shape
@@ -28262,6 +28172,7 @@
 breezy.tests.test_selftest.TestEnvironHandling.test_overrideEnv_None_called_twice_doesnt_leak
 breezy.tests.test_selftest.TestExtraAssertions.test_assertEndsWith
 breezy.tests.test_selftest.TestExtraAssertions.test_assertEqualDiff
+breezy.tests.test_selftest.TestExtraAssertions.test_assert_isinstance
 breezy.tests.test_selftest.TestFilteredByModuleTestLoader.test_exclude_tests
 breezy.tests.test_selftest.TestFilteredByModuleTestLoader.test_load_tests
 breezy.tests.test_selftest.TestFilteredByNameStartTestLoader.test_exclude_tests
@@ -28339,6 +28250,7 @@
 breezy.tests.test_selftest.TestSelftest.test_selftest_benchmark_parameter_invokes_test_suite__benchmark__
 breezy.tests.test_selftest.TestSelftest.test_transport_memory
 breezy.tests.test_selftest.TestSelftest.test_transport_sftp
+breezy.tests.test_selftest.TestSelftestWithIdList.test_load_list
 breezy.tests.test_selftest.TestSelftestWithIdList.test_load_unknown
 breezy.tests.test_selftest.TestStartBzrSubProcess.test_allow_plugins
 breezy.tests.test_selftest.TestStartBzrSubProcess.test_env_del_missing
@@ -28424,6 +28336,7 @@
 breezy.tests.test_selftest.TestTestPrefixRegistry.test_resolve_unknown_alias
 breezy.tests.test_selftest.TestTestResult.test_add_not_supported
 breezy.tests.test_selftest.TestTestResult.test_known_failure
+breezy.tests.test_selftest.TestTestResult.test_lsprofiling
 breezy.tests.test_selftest.TestTestResult.test_startTests
 breezy.tests.test_selftest.TestTestResult.test_startTests_only_once
 breezy.tests.test_selftest.TestTestResult.test_strict_with_known_failure
@@ -28444,6 +28357,7 @@
 breezy.tests.test_selftest.TestThreadLeakDetection.test_testcase_without_addCleanups
 breezy.tests.test_selftest.TestThreadLeakDetection.test_thread_leak
 breezy.tests.test_selftest.TestTransportScenarios.test_get_transport_permutations
+breezy.tests.test_selftest.TestTransportScenarios.test_scenarios_include_all_modules
 breezy.tests.test_selftest.TestTransportScenarios.test_scenarios_include_transport_class
 breezy.tests.test_selftest.TestTreeScenarios.test_scenarios
 breezy.tests.test_selftest.TestTreeShape.test_unicode_paths
@@ -29232,6 +29146,7 @@
 breezy.tests.test_status.TestStatus.test_multiple_pending
 breezy.tests.test_status.TestStatus.test_multiple_pending_verbose
 breezy.tests.test_status.TestStatus.test_pending_none
+breezy.tests.test_status.TestStatus.test_pending_with_ghosts
 breezy.tests.test_status.TestStatus.tests_revision_to_revision
 breezy.tests.test_status.TestStatus.test_with_pending_ghost
 breezy.tests.test_strace.TestStrace.test_strace_callable_is_called
@@ -29444,6 +29359,12 @@
 breezy.tests.test_transform.TestFileMover.test_file_mover
 breezy.tests.test_transform.TestFileMover.test_file_mover_rollback
 breezy.tests.test_transform.TestFileMover.test_pre_delete_rollback
+breezy.tests.test_transform.TestFinalizeRobustness.test_rename_in_limbo_rename_raises_after_rename
+breezy.tests.test_transform.TestFinalizeRobustness.test_rename_in_limbo_rename_raises_before_rename
+breezy.tests.test_transform.TestFinalizeRobustness.test_root_create_file_open_raises_after_creation
+breezy.tests.test_transform.TestFinalizeRobustness.test_root_create_file_open_raises_before_creation
+breezy.tests.test_transform.TestFinalizeRobustness.test_subdir_create_file_open_raises_after_creation
+breezy.tests.test_transform.TestFinalizeRobustness.test_subdir_create_file_open_raises_before_creation
 breezy.tests.test_transform.TestInventoryAltered.test_inventory_altered_changed_parent_id
 breezy.tests.test_transform.TestInventoryAltered.test_inventory_altered_noop_changed_parent_id
 breezy.tests.test_transform.TestInventoryAltered.test_inventory_altered_unchanged
@@ -29465,6 +29386,7 @@
 breezy.tests.test_transform.TestSerializeTransform.test_get_parents_lines
 breezy.tests.test_transform.TestSerializeTransform.test_get_parents_texts
 breezy.tests.test_transform.TestSerializeTransform.test_serialize_add_contents
+breezy.tests.test_transform.TestSerializeTransform.test_serialize_creation
 breezy.tests.test_transform.TestSerializeTransform.test_serialize_destruction
 breezy.tests.test_transform.TestSerializeTransform.test_serialize_kind_change
 breezy.tests.test_transform.TestSerializeTransform.test_serialize_missing
@@ -29517,6 +29439,7 @@
 breezy.tests.test_transform.TestTransformPreview.test_missing_content_summary
 breezy.tests.test_transform.TestTransformPreview.test_path2id_created
 breezy.tests.test_transform.TestTransformPreview.test_path2id_deleted_unchanged
+breezy.tests.test_transform.TestTransformPreview.test_path2id_moved
 breezy.tests.test_transform.TestTransformPreview.test_path2id_renamed_parent
 breezy.tests.test_transform.TestTransformPreview.test_plan_file_merge
 breezy.tests.test_transform.TestTransformPreview.test_plan_file_merge_revision_tree
@@ -29830,6 +29753,7 @@
 breezy.tests.test_upgrade.TestUpgrade.test_upgrade_rich_root
 breezy.tests.test_upstream_import.TestImport.test_broken_tar
 breezy.tests.test_upstream_import.TestImport.test_common_directory
+breezy.tests.test_upstream_import.TestImport.test_copydir_nosub
 breezy.tests.test_upstream_import.TestImport.test_get_archive_type
 breezy.tests.test_upstream_import.TestImport.test_no_crash_with_bzrdir
 breezy.tests.test_upstream_import.TestImport.test_top_path
@@ -29862,6 +29786,8 @@
 breezy.tests.test_url_policy_open.TestOpenOnlyScheme.test_stacked_within_scheme
 breezy.tests.test_urlutils.QuoteTests.test_quote
 breezy.tests.test_urlutils.QuoteTests.test_quote_tildes
+breezy.tests.test_urlutils.QuoteTests.test_unquote
+breezy.tests.test_urlutils.QuoteTests.test_unquote_to_bytes
 breezy.tests.test_urlutils.TestCwdToURL.test_dot
 breezy.tests.test_urlutils.TestCwdToURL.test_non_ascii
 breezy.tests.test_urlutils.TestDeriveToLocation.test_to_locations_derived_from_paths
@@ -29894,6 +29820,7 @@
 breezy.tests.test_urlutils.TestURL.test_str
 breezy.tests.test_urlutils.TestUrlToPath.test_basename
 breezy.tests.test_urlutils.TestUrlToPath.test_dirname
+breezy.tests.test_urlutils.TestUrlToPath.test_escape
 breezy.tests.test_urlutils.TestUrlToPath.test_escape_tildes
 breezy.tests.test_urlutils.TestUrlToPath.test_escape_unescape
 breezy.tests.test_urlutils.TestUrlToPath.test_function_type
@@ -29914,6 +29841,7 @@
 breezy.tests.test_urlutils.TestUrlToPath.test_url_scheme_re
 breezy.tests.test_urlutils.TestUrlToPath.test_win32_extract_drive_letter
 breezy.tests.test_urlutils.TestUrlToPath.test_win32_local_path_from_url
+breezy.tests.test_urlutils.TestUrlToPath.test_win32_local_path_to_url
 breezy.tests.test_urlutils.TestUrlToPath.test_win32_strip_local_trailing_slash
 breezy.tests.test_urlutils.TestUrlToPath.test_win32_unc_path_from_url
 breezy.tests.test_urlutils.TestUrlToPath.test_win32_unc_path_to_url
@@ -29964,6 +29892,7 @@
 breezy.tests.test_version_info.TestVersionInfoRio.test_rio_version_hook
 breezy.tests.test_version_info.TestVersionInfoRio.test_simple
 breezy.tests.test_version.TestBzrlibVersioning.test_get_brz_source_tree
+breezy.tests.test_version.TestBzrlibVersioning.test_python_binary_path
 breezy.tests.test_version.TestPlatformUse.test_platform(ascii)
 breezy.tests.test_version.TestPlatformUse.test_platform(unicode)
 breezy.tests.test_vf_search.TestLimitedSearchResultFromParentMap.test_ancestry_1
@@ -29976,6 +29905,7 @@
 breezy.tests.test_vf_search.TestSearchResultFromParentMap.test_ancestry_1
 breezy.tests.test_vf_search.TestSearchResultFromParentMap.test_ancestry_2
 breezy.tests.test_vf_search.TestSearchResultFromParentMap.test_no_parents
+breezy.tests.test_vf_search.TestSearchResultFromParentMap.test_partial_search
 breezy.tests.test_vf_search.TestSearchResultRefine.test_refine
 breezy.tests.test_views.TestErrors.test_file_outside_view
 breezy.tests.test_views.TestErrors.test_no_such_view
@@ -30155,6 +30085,3 @@
 breezy.tests.test_xml.TestSerializer.test_unpack_revision_5
 breezy.tests.test_xml.TestSerializer.test_unpack_revision_5_utc
 breezy.tests.test_xml.TestSerializer.test_wrong_format_v7
-breezy.timestamp.format_highres_date
-breezy.transport.http.unhtml_roughly
-breezy.version_info_formats.format_custom.Template

=== modified file 'setup.py'
--- setup.py	2018-06-17 11:15:04 +0000
+++ setup.py	2018-08-08 02:14:32 +0000
@@ -735,16 +735,16 @@
     if not 'bdist_egg' in sys.argv:
         # generate and install brz.1 only with plain install, not the
         # easy_install one
-        DATA_FILES = [('man/man1', ['brz.1', 'breezy/plugins/git/git-remote-bzr.1'])]
+        DATA_FILES = [('man/man1', ['brz.1', 'breezy/git/git-remote-bzr.1'])]
 
     DATA_FILES = DATA_FILES + I18N_FILES
     # std setup
     ARGS = {'scripts': ['brz',
                         # TODO(jelmer): Only install the git scripts if
                         # Dulwich was found.
-                        'breezy/plugins/git/git-remote-bzr',
-                        'breezy/plugins/git/bzr-receive-pack',
-                        'breezy/plugins/git/bzr-upload-pack'],
+                        'breezy/git/git-remote-bzr',
+                        'breezy/git/bzr-receive-pack',
+                        'breezy/git/bzr-upload-pack'],
             'data_files': DATA_FILES,
             'cmdclass': command_classes,
             'ext_modules': ext_modules,

